@@ -60,9 +60,10 @@ public:
 	{
 		drawGlyph(gc);
 	}
-	void drawLine(QPointF, QPointF) override { }
+	void drawLine(const QPointF&, const QPointF&) override { }
 	void drawRect(const QRectF&) override { }
 	void drawObject(PageItem*) override { }
+	void drawObjectDecoration(PageItem* item) override { }
 };
 
 bool isPartFilledImageFrame(PageItem * currItem)
@@ -127,11 +128,11 @@ void DocumentChecker::checkPages(ScribusDoc *currDoc, const CheckerPrefs& checke
 			}
 			else
 			{
-				if (pageLoc==LeftPage && masterPageLocation==1)
+				if (pageLoc == LeftPage && masterPageLocation == 1)
 					error = false;
-				else if (pageLoc==RightPage && masterPageLocation==0)
+				else if (pageLoc == RightPage && masterPageLocation == 0)
 					error = false;
-				else if (pageLoc==MiddlePage && masterPageLocation==2)
+				else if (pageLoc == MiddlePage && masterPageLocation == 2)
 					error = false;
 				else
 					error = true;
