@@ -30,39 +30,40 @@ class SCRIBUS_API DocumentInformation
 	public:
 		DocumentInformation();
 		~DocumentInformation() = default;
-		const QString& author();
-		const QString& comments();
-		const QString& contrib();
-		const QString& cover();
-		const QString& date();
-		const QString& format();
-		const QString& ident();
-		const QString& keywords();
-		const QString& langInfo();
-		const QString& publisher();
-		const QString& relation();
-		const QString& rights();
-		const QString& source();
-		const QString& subject();
-		const QString& title();
-		const QString& type();
+
+		const QString& author() const;
+		const QString& comments() const;
+		const QString& contrib() const;
+		const QString& cover() const;
+		const QString& date() const;
+		const QString& format() const;
+		const QString& ident() const;
+		const QString& keywords() const;
+		const QString& langInfo() const;
+		const QString& publisher() const;
+		const QString& relation() const;
+		const QString& rights() const;
+		const QString& source() const;
+		const QString& subject() const;
+		const QString& title() const;
+		const QString& type() const;
 		
-		void setAuthor(const QString &_author);
-		void setComments(const QString &_comments);
-		void setContrib(const QString &_contrib);
-		void setCover(const QString &_cover);
-		void setDate(const QString &_date);
-		void setFormat(const QString &_format);
-		void setIdent(const QString &_ident);
-		void setKeywords(const QString &_keywords);
-		void setLangInfo(const QString &_langInfo);
-		void setPublisher(const QString &_publisher);
-		void setRelation(const QString &_relation);
-		void setRights(const QString &_rights);
-		void setSource(const QString &_source);
-		void setSubject(const QString &_subject);
-		void setTitle(const QString &_title);
-		void setType(const QString &_type);
+		void setAuthor(const QString &author);
+		void setComments(const QString &comments);
+		void setContrib(const QString &contrib);
+		void setCover(const QString &cover);
+		void setDate(const QString &date);
+		void setFormat(const QString &format);
+		void setIdent(const QString &ident);
+		void setKeywords(const QString &keywords);
+		void setLangInfo(const QString &langInfo);
+		void setPublisher(const QString &publisher);
+		void setRelation(const QString &relation);
+		void setRights(const QString &rights);
+		void setSource(const QString &source);
+		void setSubject(const QString &subject);
+		void setTitle(const QString &title);
+		void setType(const QString &type);
 		
 	protected:
 		QString m_author;
