@@ -19,7 +19,7 @@ class ScDLManager: public QObject
 {
 	Q_OBJECT
 	public:
-		ScDLManager(QObject *parent = 0);
+		ScDLManager(QObject *parent = nullptr);
 		~ScDLManager();
 //TODO: Add download groups so different parts of Scribus can be downloading at the same time
 
@@ -44,7 +44,7 @@ class ScDLManager: public QObject
 
 	private:
 		ScDLThread *m_thread;
-		int m_dlID;
+		int m_dlID {0};
 		QList <DownloadData> m_fileList;
 };
 
