@@ -534,7 +534,7 @@ void ExifData::ProcessExifDir ( unsigned char * DirStart, unsigned char * Offset
 
 			case TAG_USERCOMMENT:
 				// Olympus has this padded with trailing spaces.  Remove these first.
-				for ( a=ByteCount;; )
+				for (a = ByteCount;; )
 				{
 					a--;
 					if ( ( ValuePtr ) [a] == ' ' )
@@ -551,7 +551,7 @@ void ExifData::ProcessExifDir ( unsigned char * DirStart, unsigned char * Offset
 				// Copy the comment
 				if ( memcmp ( ValuePtr, "ASCII",5 ) == 0 )
 				{
-					for ( a=5;a<10;a++ )
+					for (a = 5; a < 10; a++)
 					{
 						int c;
 						c = ( ValuePtr ) [a];
@@ -870,33 +870,6 @@ int ExifData::Exif2tm ( struct tm * timeptr, char * ExifTime )
 	return false; // Wasn't in Exif date format.
 }
 
-//--------------------------------------------------------------------------
-// Constructor for initialising
-//--------------------------------------------------------------------------
-ExifData::ExifData()
-{
-	ExifData::Whitebalance = -1;
-	ExifData::MeteringMode = -1;
-	ExifData::FlashUsed = 0;
-	Orientation = 0;
-	Height = 0;
-	Width = 0;
-	IsColor = 0;
-	Process = 0;
-	FocalLength = 0;
-	ExposureTime = 0;
-	ApertureFNumber = 0;
-	Distance = 0;
-	CCDWidth = 0;
-	ExposureBias = 0;
-	ExposureProgram = 0;
-	ISOequivalent = 0;
-	CompressionLevel = 0;
-	exifDataValid = false;
-	recurseLevel = 0;
-	orientationCount = 0;
-}
-
 //--------------------------------------------------------------------------
 // process a EXIF jpeg file
 //--------------------------------------------------------------------------
@@ -965,8 +938,8 @@ QImage ExifData::getThumbnail()
 		return Thumbnail;
 	// now fix orientation
 	QTransform M;
-	QTransform flip = QTransform ( -1,0,0,1,0,0 );
-	switch ( Orientation )
+	QTransform flip(-1, 0, 0, 1, 0, 0);
+	switch (Orientation)
 	{  // notice intentional fallthroughs
 		case 2: M = flip; break;
 		case 4: M = flip; //Q_FALLTHROUGH();
