@@ -82,12 +82,12 @@ const QString FileLoader::getLoadFilterString()
 	QStringList fmts = LoadSavePlugin::fileDialogLoadFilter();
 	QString fmtString = QObject::tr("All Supported Formats")+" (";
 	int ind = -1;
-	for (int i = 0; i < fmts.count()-1; i++)
+	for (int i = 0; i < fmts.count() - 1; ++i)
 	{
 		QString fmt(fmts[i]);
 		int s = fmt.indexOf("(");
 		int e = fmt.lastIndexOf(")");
-		QString f(fmt.mid(s+1, e-s-1));
+		QString f(fmt.mid(s + 1, e - s - 1));
 #ifndef HAVE_POPPLER
 		if (f.contains("pdf"))	// for removing PDF from the list
 		{
@@ -247,7 +247,7 @@ bool FileLoader::loadFile(ScribusDoc* currDoc)
 			case FORMATID_SLA12XIMPORT:
 				{
 					it->setupTargets(currDoc, currDoc->view(), currDoc->scMW(), currDoc->scMW()->mainWindowProgressBar, &(m_prefsManager.appPrefs.fontPrefs.AvailFonts));
-					ret=it->loadFile(m_fileName, LoadSavePlugin::lfCreateDoc);
+					ret = it->loadFile(m_fileName, LoadSavePlugin::lfCreateDoc);
 // 					if (ret)
 // 						it->getReplacedFontData(newReplacement, ReplacedFonts, dummyScFaces);
 				}
@@ -257,7 +257,7 @@ bool FileLoader::loadFile(ScribusDoc* currDoc)
 			case FORMATID_SLA150IMPORT:
 				{
 					it->setupTargets(currDoc, nullptr, currDoc->scMW(), currDoc->scMW()->mainWindowProgressBar, &(m_prefsManager.appPrefs.fontPrefs.AvailFonts));
-					ret=it->loadFile(m_fileName, LoadSavePlugin::lfCreateDoc);
+					ret = it->loadFile(m_fileName, LoadSavePlugin::lfCreateDoc);
 // 					if (ret)
 // 						it->getReplacedFontData(newReplacement, ReplacedFonts, dummyScFaces);
 				}
@@ -350,8 +350,8 @@ void FileLoader::readParagraphStyle(ParagraphStyle& vg, const QDomElement& pg, S
 	vg.charStyle().setFont((*currDoc->AllFonts)[tmpf]);
 	vg.charStyle().setFontSize(qRound(ScCLocale::toDoubleC(pg.attribute("FONTSIZE"), 12.0) * 10.0));
 	vg.setHasDropCap(static_cast<bool>(pg.attribute("DROP", "0").toInt()));
-	vg.setPeCharStyleName(pg.attribute("DROPCHSTYLE", ""));
-	vg.setPeCharStyleName(pg.attribute("PECHSTYLE", ""));
+	vg.setPeCharStyleName(pg.attribute("DROPCHSTYLE", QString()));
+	vg.setPeCharStyleName(pg.attribute("PECHSTYLE", QString()));
 	vg.setDropCapLines(pg.attribute("DROPLIN", "2").toInt());
 	vg.setParEffectOffset(ScCLocale::toDoubleC(pg.attribute("DROPDIST"), 0.0));
 	vg.setParEffectOffset(ScCLocale::toDoubleC(pg.attribute("PEDIST"), 0.0));
@@ -390,29 +390,28 @@ void FileLoader::readParagraphStyle(ParagraphStyle& vg, const QDomElement& pg, S
 			tbs.append(tb);
 		}
 		vg.setTabValues(tbs);
-		tmp = "";
+		tmp.clear();
 	}
 	else
 	{
 		QList<ParagraphStyle::TabRecord> tbs;
-		QDomNode IT = pg.firstChild();
-		while (!IT.isNull())
+		QDomNode domNode = pg.firstChild();
+		while (!domNode.isNull())
 		{
-			QDomElement it = IT.toElement();
-			if (it.tagName()=="Tabs")
+			QDomElement it = domNode.toElement();
+			if (it.tagName() == "Tabs")
 			{
 				ParagraphStyle::TabRecord tb;
 				tb.tabPosition = ScCLocale::toDoubleC(it.attribute("Pos"));
 				tb.tabType = it.attribute("Type").toInt();
-				QString tbCh = "";
-				tbCh = it.attribute("Fill","");
+				QString tbCh = it.attribute("Fill", QString());
 				if (tbCh.isEmpty())
 					tb.tabFillChar = QChar();
 				else
 					tb.tabFillChar = tbCh[0];
 				tbs.append(tb);
 			}
-			IT=IT.nextSibling();
+			domNode = domNode.nextSibling();
 		}
 		vg.setTabValues(tbs);
 	}
@@ -440,41 +439,41 @@ bool FileLoader::postLoad(ScribusDoc* currDoc)
 	if (!dia.exec())
 		return false;
 
-	QMap<QString, QString>::Iterator itfsu;
-	for (itfsu = m_ReplacedFonts.begin(); itfsu != m_ReplacedFonts.end(); ++itfsu)
+	if (dia.stickyReplacements->isChecked())
 	{
-		if (dia.stickyReplacements->isChecked())
-			m_prefsManager.appPrefs.fontPrefs.GFontSub[itfsu.key()] = itfsu.value();
+		for (auto it = m_ReplacedFonts.begin(); it != m_ReplacedFonts.end(); ++it)
+			m_prefsManager.appPrefs.fontPrefs.GFontSub[it.key()] = it.value();
 	}
 	currDoc->AllFonts->setSubstitutions(m_ReplacedFonts, currDoc);
+
 	ResourceCollection repl;
 	repl.availableFonts = currDoc->AllFonts;
 	repl.mapFonts(m_ReplacedFonts);
+	PrefsManager::replaceToolResources(currDoc->itemToolPrefs(), repl);
 	currDoc->replaceNamedResources(repl);
 	return true;
 }
 
 void FileLoader::informReplacementFonts()
 {
-	if (m_ReplacedFonts.count() != 0)
+	if (m_ReplacedFonts.count() == 0)
+		return;
+
+	qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+	QString mess = tr("Some fonts used by this document have been substituted:") + "\n\n";
+	for (auto it = m_ReplacedFonts.begin(); it != m_ReplacedFonts.end(); ++it)
 	{
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
-		QString mess = tr("Some fonts used by this document have been substituted:")+"\n\n";
-		QMap<QString, QString>::Iterator it;
-		for (it = m_ReplacedFonts.begin(); it != m_ReplacedFonts.end(); ++it)
-		{
-			mess += it.key() + tr(" was replaced by: ")+ it.value() +"\n";
-		}
-		ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning, mess);
+		mess += it.key() + tr(" was replaced by: ") + it.value() +"\n";
 	}
+	ScMessageBox::warning(ScCore->primaryMainWindow(), CommonStrings::trWarning, mess);
 }
 
 bool FileLoader::findFormat(uint formatId, QList<FileFormat>::const_iterator &it)
 {
 	QList<FileFormat> fileFormats(LoadSavePlugin::supportedFormats());
-	it=fileFormats.constBegin();
+	it = fileFormats.constBegin();
 	QList<FileFormat>::const_iterator itEnd(fileFormats.constEnd());
-	for ( ; it != itEnd ; ++it )
+	for ( ; it != itEnd ; ++it)
 	{
 		if (formatId == it->formatId)
 			return true;
