@@ -5,23 +5,23 @@ a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
 /***************************************************************************
- *   Copyright (C) 2004 by Riku Leino                                      *
- *   tsoots@gmail.com                                                      *
+ * Copyright (C) 2004 by Riku Leino                                        *
+ * tsoots@gmail.com                                                        *
  *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
+ * This program is free software; you can redistribute it and/or modify    *
+ * it under the terms of the GNU General Public License as published by    *
+ * the Free Software Foundation; either version 2 of the License, or       *
+ * (at your option) any later version.                                     *
  *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
+ * This program is distributed in the hope that it will be useful,         *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
+ * GNU General Public License for more details.                            *
  *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
+ * You should have received a copy of the GNU General Public License       *
+ * along with this program; if not, write to the                           *
+ * Free Software Foundation, Inc.,                                         *
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.            *
  ***************************************************************************/
 
 #ifndef GTFONT_H
@@ -90,42 +90,10 @@ enum FontWidth {
 */
 class SCRIBUS_API gtFont
 {
-private:
-	int     m_setflags;
-	QString m_name;
-	QString m_family;
-	QString m_weight;
-	QString m_slant;
-	QString m_width;
-	QString m_append;
-	int     m_size;
-	bool    m_fontEffects[FontEffectMAX];
-	QString m_color;
-	int     m_shade;
-	QString m_strokeColor;
-	int     m_strokeShade;
-	/* Width of a character in percentages to it's "real width" */
-	int     m_hscale;
-	int  m_kerning;
-	bool m_useFullName;
-	int  m_weightIndex;
-	int  m_slantIndex;
-	int  m_widthIndex;
-	int m_smallestIndex;
-	int m_biggestIndex;
-	int m_index;
-	int m_tmpWeightIndex;
-	int m_tmpSlantIndex;
-	int m_tmpWidthIndex;
-	void initArrays();
-	void parseName();
-	void parseWeight();
-	void parseSlant();
-	void parseWidth();
-	void parseFamily();
-	int  find(const QString& where, const QString& what);
-
 public:
+	gtFont();
+	gtFont(const gtFont& f);
+	~gtFont();
 
 	typedef enum
 	{
@@ -133,13 +101,13 @@ public:
 		weightWasSet = 2,
 		slantWasSet = 4,
 		widthWasSet = 8,
-		sizeWasSet  = 16,
+		sizeWasSet = 16,
 		effectWasSet = 32,
 		fillColorWasSet = 64,
 		fillShadeWasSet = 128,
 		strokeColorWasSet = 256,
 		strokeShadeWasSet = 512,
-		hscaleWasSet  = 1024,
+		hscaleWasSet = 1024,
 		kerningWasSet = 2048
 	} wasSetFlags;
 
@@ -182,9 +150,42 @@ public:
 	void    setHscale(int newHscale);
 	int     getKerning();
 	void    setKerning(int newKerning);
-	gtFont();
-	gtFont(const gtFont& f);
-	~gtFont();
+
+private:
+	int     m_setflags {0};
+	QString m_name;
+	QString m_family;
+	QString m_weight;
+	QString m_slant;
+	QString m_width;
+	QString m_append;
+	int     m_size {120};
+	bool    m_fontEffects[FontEffectMAX];
+	QString m_color {"Black"};
+	int     m_shade {100};
+	QString m_strokeColor {"Black"};
+	int     m_strokeShade {100};
+	/* Width of a character in percentages to it's "real width" */
+	int  m_hscale {1000};
+	int  m_kerning {0};
+	bool m_useFullName {true};
+	int  m_weightIndex {0};
+	int  m_slantIndex {1};
+	int  m_widthIndex {2};
+	int  m_smallestIndex {-1};
+	int  m_biggestIndex {-1};
+	int  m_index {-1};
+	int  m_tmpWeightIndex {-1};
+	int  m_tmpSlantIndex {-1};
+	int  m_tmpWidthIndex {-1};
+
+	void initArrays();
+	void parseName();
+	void parseWeight();
+	void parseSlant();
+	void parseWidth();
+	void parseFamily();
+	int  find(const QString& where, const QString& what);
 };
 
 #endif // GTFONT_H
