@@ -31,45 +31,45 @@ for which a new license (GPL+exception) is in place.
 #include "scribusview.h"
 #include "util_ghostscript.h"
 
-Navigator::Navigator(QWidget *parent, int Size, int Seite, ScribusView* vie, const QString& fn) : QLabel(parent)
+Navigator::Navigator(QWidget *parent, int size, int pageNr, ScribusView* view, const QString& fn) : QLabel(parent),
+	m_view(view)
 {
 	setScaledContents(false);
 	setAlignment(Qt::AlignLeft | Qt::AlignTop);
 	if (!fn.isEmpty())
 	{
-		QPixmap img = LoadPDF(fn, Seite, Size, &Width, &Height);
+		QPixmap img = loadPDF(fn, pageNr, size, &Width, &Height);
 		if (!img.isNull())
 			pmx = img;
 		else
-			pmx = LoadPDF(fn, 1, Size, &Width, &Height);
+			pmx = loadPDF(fn, 1, size, &Width, &Height);
 	}
 	else
-		pmx=QPixmap::fromImage(vie->PageToPixmap(Seite, Size));
+		pmx = QPixmap::fromImage(view->PageToPixmap(pageNr, size));
 	resize(pmx.width(), pmx.height());
 	Xp = 0;
 	Yp = 0;
 	drawMark(0, 0);
-	view = vie;
 }
 
 void Navigator::mouseMoveEvent(QMouseEvent *m)
 {
 	drawMark(m->x(), m->y());
-	emit Coords(static_cast<double>(m->x())/static_cast<double>(pmx.width()),
-			    static_cast<double>(m->y())/static_cast<double>(pmx.height()));
+	emit Coords(static_cast<double>(m->x()) / static_cast<double>(pmx.width()),
+			    static_cast<double>(m->y()) / static_cast<double>(pmx.height()));
 }
 
 void Navigator::mousePressEvent(QMouseEvent *m)
 {
 	drawMark(m->x(), m->y());
-	emit Coords(static_cast<double>(m->x())/static_cast<double>(pmx.width()),
-			    static_cast<double>(m->y())/static_cast<double>(pmx.height()));
+	emit Coords(static_cast<double>(m->x()) / static_cast<double>(pmx.width()),
+			    static_cast<double>(m->y()) / static_cast<double>(pmx.height()));
 }
 
 void Navigator::mouseReleaseEvent(QMouseEvent *m)
 {
-	emit Coords(static_cast<double>(m->x())/static_cast<double>(pmx.width()),
-			    static_cast<double>(m->y())/static_cast<double>(pmx.height()));
+	emit Coords(static_cast<double>(m->x()) / static_cast<double>(pmx.width()),
+			    static_cast<double>(m->y()) / static_cast<double>(pmx.height()));
 }
 
 void Navigator::paintEvent(QPaintEvent *e)
@@ -81,10 +81,10 @@ void Navigator::paintEvent(QPaintEvent *e)
 	p.setClipRect(pmx.rect());
 	p.drawPixmap(0, 0, pmx);
 	p.setPen(QPen(QColor(Qt::black), 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-	p.drawLine(Xp-5, Yp-5, Xp-1, Yp-1);
-	p.drawLine(Xp-5, Yp+5, Xp-1, Yp+1);
-	p.drawLine(Xp+2, Yp+2, Xp+6, Yp+6);
-	p.drawLine(Xp+2, Yp-2, Xp+6, Yp-6);
+	p.drawLine(Xp - 5, Yp - 5, Xp - 1, Yp - 1);
+	p.drawLine(Xp - 5, Yp + 5, Xp - 1, Yp + 1);
+	p.drawLine(Xp + 2, Yp + 2, Xp + 6, Yp + 6);
+	p.drawLine(Xp + 2, Yp - 2, Xp + 6, Yp - 6);
 	p.end();
 }
 
@@ -95,23 +95,23 @@ void Navigator::drawMark(int x, int y)
 	repaint();
 }
 
-bool Navigator::SetSeite(int Seite, int Size, const QString& fn)
+bool Navigator::setPage(int pageNr, int size, const QString& fn)
 {
 	bool ret = false;
 	if (!fn.isEmpty())
 	{
-		QPixmap img = LoadPDF(fn, Seite, Size, &Width, &Height);
+		QPixmap img = loadPDF(fn, pageNr, size, &Width, &Height);
 		if (!img.isNull())
 		{
 			pmx = img;
 			ret = true;
 		}
 		else
-			pmx = LoadPDF(fn, 1, Size, &Width, &Height);
+			pmx = loadPDF(fn, 1, size, &Width, &Height);
 	}
 	else
 	{
-		pmx=QPixmap::fromImage(view->PageToPixmap(Seite, Size));
+		pmx = QPixmap::fromImage(m_view->PageToPixmap(pageNr, size));
 		ret = true;
 	}
 	resize(pmx.width(), pmx.height());
