@@ -27,6 +27,7 @@ for which a new license (GPL+exception) is in place.
 #include <QObject>
 #include <QWidget>
 #include <QPolygon>
+#include <QSizeF>
 #include <QStack>
 #include <QList>
 #include <QKeyEvent>
@@ -47,6 +48,7 @@ for which a new license (GPL+exception) is in place.
 #include "pagestructs.h"
 #include "scimage.h"
 #include "margins.h"
+#include "scpatterntransform.h"
 #include "sctextstruct.h"
 #include "text/storytext.h"
 #include "text/textlayout.h"
@@ -253,6 +255,22 @@ public: // Start public functions
 	virtual PageItem_Table * asTable()						{ return nullptr; } ///< Return self if Table item, otherwise null
 	virtual PageItem_TextFrame * asTextFrame()				{ return nullptr; } ///< Return self if Text item, otherwise null
 
+	virtual const PageItem_Arc * asArc() const					{ return nullptr; } ///< Return self if Arc item, otherwise null
+	virtual const PageItem_Group * asGroupFrame() const			{ return nullptr; } ///< Return self if Group item, otherwise null
+	virtual const PageItem_ImageFrame * asImageFrame() const	{ return nullptr; } ///< Return self if Image item, otherwise null
+	virtual const PageItem_LatexFrame * asLatexFrame() const	{ return nullptr; } ///< Return self if Render frame item, otherwise null
+	virtual const PageItem_Line * asLine() const				{ return nullptr; } ///< Return self if Line item, otherwise null
+	virtual const PageItem_NoteFrame * asNoteFrame() const		{ return nullptr; } ///< Return self if Note item, otherwise null
+	virtual const PageItem_OSGFrame * asOSGFrame()  const		{ return nullptr; } ///< Return self if OSG item, otherwise null
+	virtual const PageItem_PathText * asPathText() const		{ return nullptr; } ///< Return self if Path Text item, otherwise null
+	virtual const PageItem_PolyLine * asPolyLine() const		{ return nullptr; } ///< Return self if Poly Line item, otherwise null
+	virtual const PageItem_Polygon * asPolygon() const			{ return nullptr; } ///< Return self if Polygon item, otherwise null
+	virtual const PageItem_RegularPolygon * asRegularPolygon() const { return nullptr; } ///< Return self if Regular Polygon item, otherwise null
+	virtual const PageItem_Spiral * asSpiral() const			{ return nullptr; } ///< Return self if Spiral item, otherwise null
+	virtual const PageItem_Symbol * asSymbol() const			{ return nullptr; } ///< Return self if Symbol item, otherwise null
+	virtual const PageItem_Table * asTable() const				{ return nullptr; } ///< Return self if Table item, otherwise null
+	virtual const PageItem_TextFrame * asTextFrame() const		{ return nullptr; } ///< Return self if Text item, otherwise null
+
 	virtual bool isArc()			const { return false; } ///< Return true if Arc item, otherwise false
 	virtual bool isAutoNoteFrame()	const { return false; } ///< Return true if Auto Note item, otherwise false
 	virtual bool isGroup()			const { return false; } ///< Return true if Group item, otherwise false
@@ -291,8 +309,8 @@ public: // Start public functions
 	virtual void DrawObj_Item(ScPainter *p, const QRectF& e) = 0;
 	QImage DrawObj_toImage(double maxSize, int options = 0);
 	QImage DrawObj_toImage(QList<PageItem*> &emG, double scaling);
-	void DrawObj_Embedded(ScPainter *p, QRectF cullingArea, const CharStyle& style, PageItem* cembedded);
-	void DrawStrokePattern(ScPainter *p, QPainterPath &path);
+	void DrawObj_Embedded(ScPainter *p, const QRectF& cullingArea, const CharStyle& style, PageItem* cembedded);
+	void DrawStrokePattern(ScPainter *p, const QPainterPath &path);
 	void DrawSoftShadow(ScPainter *p);
 	/**
 	 * @brief Set or get the redraw bounding box of the item, moved from the View
@@ -392,7 +410,7 @@ public: // Start public functions
 	 * brief Returns a complete ObjectAttribute struct if 1 is found, or ObjectAttribute.name will be QString::null if 0 or >1 are found
 	 */
 	ObjectAttribute getObjectAttribute(const QString&) const;
-	void setObjectAttributes(ObjAttrVector*);
+	void setObjectAttributes(const ObjAttrVector*);
 
 	void SetFrameShape(int count, const double *vals);
 	void SetRectFrame();
@@ -451,7 +469,7 @@ public: // Start public functions
 	void setUseEmbeddedImageProfile(bool val) { UseEmbedded = val; }
 	QString embeddedImageProfile() const { return EmbeddedProfile; }
 	void setEmbeddedImageProfile(const QString& val) { EmbeddedProfile = val; }
-	bool drawFrame() { return ((m_itemType == TextFrame && !m_sampleItem) || (m_itemType == ImageFrame) || (m_itemType == PathText)); }
+	bool drawFrame() const { return ((m_itemType == TextFrame && !m_sampleItem) || (m_itemType == ImageFrame) || (m_itemType == PathText)); }
 	QString externalFile() const { return Pfile; }
 	void setExternalFile(const QString& filename, const QString& baseDir = QString());
 	void setImagePagenumber(int num) { pixm.imgInfo.actualPageNumber = num; }
@@ -488,7 +506,7 @@ public: // Start public functions
 	void dropLinks();
 	void unlinkWithText();
 
-	void setSampleItem(bool b) {m_sampleItem=b;}
+	void setSampleItem(bool b) { m_sampleItem = b; }
 	const QVector<double>& dashes() const { return DashValues; }
 	QVector<double>& dashes() { return DashValues; }
 	void setDashes(const QVector<double>& val) { DashValues = val; }
@@ -507,15 +525,16 @@ public: // Start public functions
 	virtual double visualXPos() const;
 	virtual double visualYPos() const;
 	FPoint xyPos() const { return FPoint(m_xPos, m_yPos); }
-	void setXPos(double, bool drawingOnly=false);
-	void setYPos(double, bool drawingOnly=false);
-	void setXYPos(double, double, bool drawingOnly=false);
-	void moveBy(double, double, bool drawingOnly=false);
+	void setXPos(double, bool drawingOnly = false);
+	void setYPos(double, bool drawingOnly = false);
+	void setXYPos(double, double, bool drawingOnly = false);
+	void moveBy(double, double, bool drawingOnly = false);
 	//Size
 	double width() const override { return m_width; }
 	double height() const override { return m_height; }
 	virtual double visualWidth() const;
 	virtual double visualHeight() const;
+	virtual QSizeF visualSize() const;
 	double visualLineWidth() const;
 	void setWidth(double);
 	void setHeight(double);
@@ -663,8 +682,8 @@ public: // Start public functions
 
 	void setGradientExtend(VGradient::VGradientRepeatMethod val);
 	void setStrokeGradientExtend(VGradient::VGradientRepeatMethod val);
-	VGradient::VGradientRepeatMethod getGradientExtend();
-	VGradient::VGradientRepeatMethod getStrokeGradientExtend();
+	VGradient::VGradientRepeatMethod getGradientExtend() const;
+	VGradient::VGradientRepeatMethod getStrokeGradientExtend() const;
 
 	//>> ********* Attributes of the item *********
 
@@ -673,7 +692,7 @@ public: // Start public functions
 	void setMaskGradient(const VGradient& grad);
 	void setFillGradient(const VGradient& grad);
 	void setStrokeGradient(const VGradient& grad);
-	void set4ColorGeometry(FPoint c1, FPoint c2, FPoint c3, FPoint c4);
+	void set4ColorGeometry(const FPoint& c1, const FPoint& c2, const FPoint& c3, const FPoint& c4);
 	void set4ColorTransparency(double t1, double t2, double t3, double t4);
 	void set4ColorShade(int t1, int t2, int t3, int t4);
 	void set4ColorColors(const QString& col1, const QString& col2, const QString& col3, const QString& col4);
@@ -686,7 +705,7 @@ public: // Start public functions
 	void resetGradientMesh();
 	void meshToShape();
 	void createConicalMesh();
-	VColorStop computeInBetweenStop(VColorStop* last, VColorStop* actual, double t);
+	VColorStop computeInBetweenStop(const VColorStop* last, const VColorStop* actual, double t) const;
 	void gradientVector(double& startX, double& startY, double& endX, double& endY, double &focalX, double &focalY, double &scale, double &skew) const;
 	void setGradientVector(double startX, double startY, double endX, double endY, double focalX, double focalY, double scale, double skew);
 
@@ -703,10 +722,11 @@ public: // Start public functions
 	QString patternMask() const { return patternMaskVal; }
 	void maskVector(double& startX, double& startY, double& endX, double& endY, double &focalX, double &focalY, double &scale, double &skew) const;
 	void setMaskVector(double startX, double startY, double endX, double endY, double focalX, double focalY, double scale, double skew);
-	void maskTransform(double &scaleX, double &scaleY, double &offsetX, double &offsetY, double &rotation, double &skewX, double &skewY) const;
+	const ScMaskTransform& maskTransform() const { return patternMaskTransfrm; }
+	void setMaskTransform(const ScMaskTransform& maskTrans);
 	void setMaskTransform(double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY);
 	void setMaskFlip(bool flipX, bool flipY);
-	void maskFlip(bool &flipX, bool &flipY);
+	void maskFlip(bool &flipX, bool &flipY) const;
 	//
 	bool fillEvenOdd() const { return fillRule; }
 	void setFillEvenOdd(bool val) { fillRule = val; }
@@ -737,13 +757,13 @@ public: // Start public functions
 	double softShadowOpacity() const { return m_softShadowOpacity; }
 
 	void setSoftShadowBlendMode(int val);
-	double softShadowBlendMode() const { return m_softShadowBlendMode; }
+	int softShadowBlendMode() const { return m_softShadowBlendMode; }
 
 	void setSoftShadowErasedByObject(bool val);
 	bool softShadowErasedByObject() const { return m_softShadowErasedByObject; }
 
 	void setSoftShadowHasObjectTransparency(bool val);
-	bool softShadowHasObjectTransparency() { return m_softShadowHasObjectTransparency; }
+	bool softShadowHasObjectTransparency() const { return m_softShadowHasObjectTransparency; }
 
 	int frameType() const { return FrameType; } ///< rect / oval / round / other
 	void setFrameType(int val) { FrameType = val; }
@@ -775,7 +795,7 @@ public: // Start public functions
 	double columnGap() const { return m_columnGap; }
 	double gridOffset() const;
 	double gridDistance() const;
-	int verticalAlignment();
+	int verticalAlignment() const;
 	void setTextToFrameDistLeft(double);
 	void setTextToFrameDistRight(double);
 	void setTextToFrameDistTop(double);
@@ -855,7 +875,7 @@ public: // Start public functions
 	QString pattern() const { return m_patternName; }
 
 	/** @brief Get the pattern transformation matrix of the object */
-	void patternTransform(double &scaleX, double &scaleY, double &offsetX, double &offsetY, double &rotation, double &skewX, double &skewY) const;
+	const ScPatternTransform& patternTransform() const { return m_patternTransform; }
 
 	/**
 	 * @brief Set the fill pattern of the object.
@@ -866,9 +886,10 @@ public: // Start public functions
 	/**
 	 * @brief Set the fill pattern transformation of the object.
 	 */
+	void setPatternTransform(const ScPatternTransform& trans);
 	void setPatternTransform(double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY);
 	void setPatternFlip(bool flipX, bool flipY);
-	void patternFlip(bool &flipX, bool &flipY);
+	void patternFlip(bool &flipX, bool &flipY) const;
 
 	/** @brief Get the (name of the) fill color of the object */
 	QString fillColor() const { return m_fillColor; }
@@ -940,7 +961,7 @@ public: // Start public functions
 	QString strokePattern() const { return patternStrokeVal; }
 
 	/** @brief Get the stroke pattern transformation matrix of the object */
-	void strokePatternTransform(double &scaleX, double &scaleY, double &offsetX, double &offsetY, double &rotation, double &skewX, double &skewY, double &space) const;
+	const ScStrokePatternTransform& strokePatternTransform() const { return patternStrokeTransfrm; }
 
 	/**
 	 * @brief Set the stroke pattern of the object.
@@ -951,11 +972,12 @@ public: // Start public functions
 	/**
 	 * @brief Set the stroke pattern transformation of the object.
 	 */
+	void setStrokePatternTransform(const ScStrokePatternTransform& trans);
 	void setStrokePatternTransform(double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, double space);
 	void setStrokePatternFlip(bool flipX, bool flipY);
-	void strokePatternFlip(bool &flipX, bool &flipY);
+	void strokePatternFlip(bool &flipX, bool &flipY) const;
 	void setStrokePatternToPath(bool enable);
-	bool isStrokePatternToPath();
+	bool isStrokePatternToPath() const;
 
 	/** @brief Set the QColor for the line */
 	void setLineQColor();
@@ -1252,20 +1274,22 @@ public: // Start public functions
 	void setImageVisible(bool);
 
 	void updateConstants();
-	bool isWelded()  {return !weldList.isEmpty(); }  //true if to this item some other items are welded (weldList is list of these items)
+	bool isWelded() const {return !weldList.isEmpty(); }  //true if to this item some other items are welded (weldList is list of these items)
 	void weldTo(PageItem* item);
 	QList<PageItem*> itemsWeldedTo(PageItem* except = nullptr);
 	void unWeld();
 	void addWelded(PageItem* item);
 	void moveWelded(double dX, double dY, int weld);
-	void moveWelded(double dX, double dY, PageItem* except = nullptr);
+	void moveWelded(double dX, double dY, const PageItem* except = nullptr);
 	void rotateWelded(double dR, double oldRot);
-	void setWeldPoint(double dX, double dY, PageItem *pItem); 	///< added for autowelding feature of notes frames, setting welding point with given pItem to given coords
+	void setWeldPoint(double dX, double dY, const PageItem *pItem); 	///< added for autowelding feature of notes frames, setting welding point with given pItem to given coords
 	QString getItemTextSaxed(int selStart, int selLength); ///< used by notes frames to get content of notes from itemText
-	bool groupClipping() { return m_groupClips; }
+	
+	bool groupClipping() const { return m_groupClips; }
 	void setGroupClipping(bool val) { m_groupClips = val; }
-	bool hasFill() { return ((fillColor() != CommonStrings::None) || (GrType != 0)); }
-	bool hasStroke() { return ((lineColor() != CommonStrings::None) || (GrTypeStroke != 0) || (!NamedLStyle.isEmpty()) || (!patternStrokeVal.isEmpty())); }
+
+	virtual bool hasFill() const { return ((fillColor() != CommonStrings::None) || (GrType != 0)); }
+	virtual bool hasStroke() const { return ((lineColor() != CommonStrings::None) || (GrTypeStroke != 0) || (!NamedLStyle.isEmpty()) || (!patternStrokeVal.isEmpty())); }
 
 		// End public functions
 
@@ -1433,14 +1457,7 @@ public:	// Start public variables
 	/**
 		* @brief Stroke pattern transformation matrix
 		*/
-	double patternStrokeScaleX {100.0};
-	double patternStrokeScaleY {100.0};
-	double patternStrokeOffsetX {0};
-	double patternStrokeOffsetY {0};
-	double patternStrokeRotation {0};
-	double patternStrokeSkewX {0};
-	double patternStrokeSkewY {0};
-	double patternStrokeSpace {1.0};
+	ScStrokePatternTransform patternStrokeTransfrm;
 	bool patternStrokeMirrorX {false};
 	bool patternStrokeMirrorY {false};
 	bool patternStrokePath {false};
@@ -1478,13 +1495,7 @@ public:	// Start public variables
 	double GrMaskFocalY {0.0};
 	double GrMaskScale {1.0};
 	double GrMaskSkew {0.0};
-	double patternMaskScaleX {100.0};
-	double patternMaskScaleY {100.0};
-	double patternMaskOffsetX {0.0};
-	double patternMaskOffsetY {0.0};
-	double patternMaskRotation {0.0};
-	double patternMaskSkewX {0.0};
-	double patternMaskSkewY {0.0};
+	ScMaskTransform patternMaskTransfrm;
 	bool patternMaskMirrorX {false};
 	bool patternMaskMirrorY {false};
 	QString patternMaskVal;
@@ -1554,7 +1565,10 @@ protected: // Start protected functions
 	void restoreEndArrowScale(SimpleState *state, bool isUndo);
 	void restoreFill(SimpleState *state, bool isUndo);
 	void restoreFillGradient(SimpleState *state, bool isUndo);
-	void restoreFillTP(SimpleState *state, bool isUndo);
+	void restoreFillPattern(SimpleState *state, bool isUndo);
+	void restoreFillPatternFlip(SimpleState *state, bool isUndo);
+	void restoreFillPatternTransform(SimpleState *state, bool isUndo);
+	void restoreFillTransparency(SimpleState *state, bool isUndo);
 	void restoreFirstLineOffset(SimpleState *state, bool isUndo);
 	void restoreGetImage(UndoState *state, bool isUndo);
 	void restoreGradPos(SimpleState *state,bool isUndo);
@@ -1597,6 +1611,8 @@ protected: // Start protected functions
 	void restoreGradientTrans4(SimpleState *state, bool isUndo);
 	void restoreGradientType(SimpleState *state, bool isUndo);
 	void restoreGradientTypeStroke(SimpleState *state, bool isUndo);
+	void restoreGradientExtent(SimpleState *state, bool isUndo);
+	void restoreGradientExtentStroke(SimpleState *state, bool isUndo);
 	void restoreImageEffects(UndoState *state, bool isUndo);
 	void restoreImageNbr(SimpleState *state,bool isUndo);
 	void restoreImageOffsetChange(SimpleState *state, bool isUndo);
@@ -1617,6 +1633,9 @@ protected: // Start protected functions
 	void restoreLinkTextFrame(UndoState *state, bool isUndo);
 	void restoreMarkString(SimpleState *state, bool isUndo);
 	void restoreMaskGradient(SimpleState *state, bool isUndo);
+	void restoreMaskPattern(SimpleState *state, bool isUndo);
+	void restoreMaskFlip(SimpleState *state, bool isUndo);
+	void restoreMaskTransform(SimpleState *state, bool isUndo);
 	void restoreMaskType(SimpleState *state,bool isUndo);
 	void restoreMove(SimpleState *state, bool isUndo);
 	void restoreMoveMeshGrad(SimpleState *state, bool isUndo);
@@ -1647,6 +1666,11 @@ protected: // Start protected functions
 	void restoreSplitItem(SimpleState *state, bool isUndo);
 	void restoreStartArrowScale(SimpleState *state, bool isUndo);
 	void restoreStrokeGradient(SimpleState *state, bool isUndo);
+	void restoreStrokeGradientName(SimpleState *state, bool isUndo);
+	void restoreStrokePattern(SimpleState *state, bool isUndo);
+	void restoreStrokePatternFlip(SimpleState *state, bool isUndo);
+	void restoreStrokePatternTransform(SimpleState *state, bool isUndo);
+	void restoreStrokePatternToPath(SimpleState *state, bool isUndo);
 	void restoreTextFlowing(SimpleState *state, bool isUndo);
 	void restoreTopTextFrameDist(SimpleState *state, bool isUndo);
 	void restoreTransform(SimpleState *state,bool isUndo);
@@ -1679,7 +1703,7 @@ protected: // Start protected functions
 	 * @return true if the actions should be sent to the UndoManager based on the
 	 * state of arrow keys and mouse buttons else returns false.
 	 */
-	bool shouldCheck();
+	bool shouldCheck() const;
 	void select(); ///< Clears the current selection and selects this PageItem.
 
 		// End protected functions
@@ -1731,15 +1755,9 @@ protected: // Start protected variables
 	/**
 	 * @brief Fill pattern transformation matrix
 	 */
-	double patternScaleX {100.0};
-	double patternScaleY {100.0};
-	double patternOffsetX {0.0};
-	double patternOffsetY {0.0};
-	double patternRotation {0.0};
-	double patternSkewX {0.0};
-	double patternSkewY {0.0};
-	bool   patternMirrorX {false};
-	bool   patternMirrorY {false};
+	ScPatternTransform m_patternTransform;
+	bool   m_patternMirrorX {false};
+	bool   m_patternMirrorY {false};
 
 	/**
 	 * @brief Fill color name
