@@ -52,7 +52,7 @@ PageItem_LatexFrame::PageItem_LatexFrame(ScribusDoc *pa, double x, double y, dou
 
 	latex = new QProcess();
 	connect(latex, SIGNAL(finished(int,QProcess::ExitStatus)), this, SLOT(updateImage(int,QProcess::ExitStatus)));
-	connect(latex, SIGNAL(error(QProcess::ProcessError)), this, SLOT(latexError(QProcess::ProcessError)));
+	connect(latex, SIGNAL(errorOccurred(QProcess::ProcessError)), this, SLOT(latexError(QProcess::ProcessError)));
 	latex->setProcessChannelMode(QProcess::MergedChannels);
 	
 	QTemporaryFile *tempfile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_render_XXXXXX");
@@ -572,7 +572,7 @@ void PageItem_LatexFrame::applicableActions(QStringList & actionList)
 		actionList << "editClearContents";
 		actionList << "editCopyContents";
 	}
-	if (doc()->scMW()->contentsBuffer.sourceType==PageItem::LatexFrame)
+	if (doc()->scMW()->contentsBuffer.sourceType == PageItem::LatexFrame)
 	{
 		actionList << "editPasteContents";
 		actionList << "editPasteContentsAbs";
