@@ -61,6 +61,7 @@ void PageItem_Line::DrawObj_Item(ScPainter *p, const QRectF& /*e*/)
 		p->drawLine(FPoint(0, 0), FPoint(m_width, 0));
 	else
 	{
+		p->setBlendModeStroke(lineBlendmode());
 		if (NamedLStyle.isEmpty())
 		{
 			ScPattern *strokePattern = m_Doc->checkedPattern(patternStrokeVal);
@@ -75,7 +76,7 @@ void PageItem_Line::DrawObj_Item(ScPainter *p, const QRectF& /*e*/)
 				}
 				else
 				{
-					p->setPattern(strokePattern, patternStrokeScaleX, patternStrokeScaleY, patternStrokeOffsetX, patternStrokeOffsetY, patternStrokeRotation, patternStrokeSkewX, patternStrokeSkewY, patternStrokeMirrorX, patternStrokeMirrorY);
+					p->setPattern(strokePattern, patternStrokeTransfrm, patternStrokeMirrorX, patternStrokeMirrorY);
 					p->setStrokeMode(ScPainter::Pattern);
 					p->drawLine(FPoint(0, 0), FPoint(m_width, 0));
 				}
@@ -133,6 +134,7 @@ void PageItem_Line::DrawObj_Item(ScPainter *p, const QRectF& /*e*/)
 				}
 			}
 		}
+		p->setBlendModeStroke(0);
 	}
 	if (m_startArrowIndex != 0)
 	{
@@ -481,3 +483,9 @@ double PageItem_Line::visualHeight() const
 	double extraSpace = visualLineWidth();
 	return extraSpace;
 }
+
+QSizeF PageItem_Line::visualSize() const
+{
+	double extraSpace = visualLineWidth();
+	return QSizeF(m_width, extraSpace);
+}
