@@ -98,7 +98,7 @@ void PageItem_PathText::DrawObj_Item(ScPainter *p, const QRectF& cullingArea)
 					}
 					else
 					{
-						p->setPattern(&m_Doc->docPatterns[patternStrokeVal], patternStrokeScaleX, patternStrokeScaleY, patternStrokeOffsetX, patternStrokeOffsetY, patternStrokeRotation, patternStrokeSkewX, patternStrokeSkewY, patternStrokeMirrorX, patternStrokeMirrorY);
+						p->setPattern(&m_Doc->docPatterns[patternStrokeVal], patternStrokeTransfrm, patternStrokeMirrorX, patternStrokeMirrorY);
 						p->setStrokeMode(ScPainter::Pattern);
 						p->strokePath();
 					}
