@@ -99,6 +99,7 @@ void SVGExportPlugin::languageChange()
 	// Menu
 	m_actionInfo.menu = "FileExport";
 	m_actionInfo.enabledOnStartup = false;
+	m_actionInfo.exportPlugin = true;
 	m_actionInfo.needsNumObjects = -1;
 }
 
@@ -128,7 +129,7 @@ bool SVGExportPlugin::run(ScribusDoc* doc, const QString& filename)
 {
 	Q_ASSERT(filename.isEmpty());
 	QString fileName;
-	if (doc!=nullptr)
+	if (doc != nullptr)
 	{
 		PrefsContext* prefs = PrefsManager::instance().prefsFile->getPluginContext("svgex");
 		QString wdir = prefs->get("wdir", ".");
@@ -650,7 +651,7 @@ void SVGExPlug::paintBorder(const TableBorder& border, const QPointF& start, con
 		lineEnd.setY(end.y() + line.width() * endOffsetFactors.y());
 		QDomElement cl = m_domDoc.createElement("path");
 		cl.setAttribute("d", "M " + FToStr(lineStart.x()) + " " + FToStr(lineStart.y()) + " L " + FToStr(lineEnd.x()) + " " + FToStr(lineEnd.y()));
-		QString stroke = "";
+		QString stroke;
 		if (line.color() != CommonStrings::None)
 			cl.setAttribute("stroke", setColor(line.color(), line.shade()));
 		if (line.width() != 0.0)
@@ -740,7 +741,7 @@ QDomElement SVGExPlug::processHatchFill(PageItem *item, const QString& transl)
 		ob2.setAttribute("fill", setColor(item->hatchBackground, 100));
 		ob.appendChild(ob2);
 	}
-	QString stroke = "";
+	QString stroke;
 	stroke += "stroke-width:1;";
 	stroke += " stroke-linecap:butt;";
 	stroke += " stroke-linejoin:miter;";
@@ -834,9 +835,9 @@ QDomElement SVGExPlug::processSymbolStroke(PageItem *item, const QString& trans)
 	ob.setAttribute("transform", trans);
 	QPainterPath path = item->PoLine.toQPainterPath(false);
 	ScPattern pat = m_Doc->docPatterns[item->strokePattern()];
-	double pLen = path.length() - ((pat.width / 2.0) * (item->patternStrokeScaleX / 100.0));
-	double adv = pat.width * item->patternStrokeScaleX / 100.0 * item->patternStrokeSpace;
-	double xpos = item->patternStrokeOffsetX * item->patternStrokeScaleX / 100.0;
+	double pLen = path.length() - ((pat.width / 2.0) * item->patternStrokeTransfrm.scaleX);
+	double adv = pat.width * item->patternStrokeTransfrm.scaleX * item->patternStrokeTransfrm.space;
+	double xpos = item->patternStrokeTransfrm.offsetX * item->patternStrokeTransfrm.scaleX;
 	while (xpos < pLen)
 	{
 		double currPerc = path.percentAtLength(xpos);
@@ -849,10 +850,10 @@ QDomElement SVGExPlug::processSymbolStroke(PageItem *item, const QString& trans)
 		QTransform trans;
 		trans.translate(currPoint.x(), currPoint.y());
 		trans.rotate(-currAngle);
-		trans.translate(0.0, item->patternStrokeOffsetY);
-		trans.rotate(-item->patternStrokeRotation);
-		trans.shear(item->patternStrokeSkewX, -item->patternStrokeSkewY);
-		trans.scale(item->patternStrokeScaleX / 100.0, item->patternStrokeScaleY / 100.0);
+		trans.translate(0.0, item->patternStrokeTransfrm.offsetY);
+		trans.rotate(-item->patternStrokeTransfrm.rotation);
+		trans.shear(item->patternStrokeTransfrm.skewX, -item->patternStrokeTransfrm.skewY);
+		trans.scale(item->patternStrokeTransfrm.scaleX, item->patternStrokeTransfrm.scaleY);
 		trans.translate(-pat.width / 2.0, -pat.height / 2.0);
 		QDomElement obS;
 		obS = m_domDoc.createElement("use");
@@ -1216,7 +1217,7 @@ public:
 		}
 	}
 
-	void drawLine(QPointF start, QPointF end) override
+	void drawLine(const QPointF& start, const QPointF& end) override
 	{
 		QTransform transform = matrix();
 		transform.translate(x(), y());
@@ -1252,7 +1253,7 @@ public:
 	void drawObject(PageItem* item) override
 	{
 		QTransform transform = matrix();
-		transform.translate(x() + item->gXpos, y() + item->gYpos);
+		transform.translate(x(), y());
 		transform.rotate(item->rotation());
 		transform.scale(scaleH(), scaleV());
 		QDomElement Group = m_svg->m_domDoc.createElement("g");
@@ -1261,6 +1262,8 @@ public:
 		Group.setAttribute("transform", m_svg->matrixToStr(transform));
 		m_elem.appendChild(Group);
 	}
+
+	void drawObjectDecoration(PageItem* item) override {}
 };
 
 QDomElement SVGExPlug::processTextItem(PageItem *item, const QString& trans, const QString& fill, const QString& stroke)
@@ -1388,7 +1391,7 @@ QDomElement SVGExPlug::processInlineItem(PageItem* embItem, const QString& trans
 		QString fill = getFillStyle(embedded);
 		QString stroke = "stroke:none";
 		stroke = getStrokeStyle(embedded);
-		QString transE = "";
+		QString transE;
 		if (embItem->isGroup())
 		{
 			transE = "translate(" + FToStr(embedded->gXpos) + ", " + FToStr(embedded->gYpos) + ")";
@@ -1567,17 +1570,16 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 				patt.setAttribute("height", pa.height);
 				patt.setAttribute("width", pa.width);
 				patt.setAttribute("patternUnits", "userSpaceOnUse");
-				double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternSpace;
-				item->strokePatternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternSpace);
+				const ScStrokePatternTransform& strokePatTrans = item->strokePatternTransform();
 				bool mirrorX, mirrorY;
 				item->strokePatternFlip(mirrorX, mirrorY);
 				QTransform mpa;
 				mpa.translate(-item->lineWidth() / 2.0, -item->lineWidth() / 2.0);
-				mpa.translate(patternOffsetX, patternOffsetY);
-				mpa.rotate(patternRotation);
-				mpa.shear(-patternSkewX, patternSkewY);
+				mpa.translate(strokePatTrans.offsetX, strokePatTrans.offsetY);
+				mpa.rotate(strokePatTrans.rotation);
+				mpa.shear(-strokePatTrans.skewX, strokePatTrans.skewY);
 				mpa.scale(pa.scaleX, pa.scaleY);
-				mpa.scale(patternScaleX / 100.0 , patternScaleY / 100.0);
+				mpa.scale(strokePatTrans.scaleX, strokePatTrans.scaleY);
 				if (mirrorX)
 					mpa.scale(-1, 1);
 				if (mirrorY)
@@ -1732,17 +1734,16 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 				patt.setAttribute("height", pa.height);
 				patt.setAttribute("width", pa.width);
 				patt.setAttribute("patternUnits", "userSpaceOnUse");
-				double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternSpace;
-				item->strokePatternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternSpace);
+				const ScStrokePatternTransform& strokePatTrans = item->strokePatternTransform();
 				bool mirrorX, mirrorY;
 				item->strokePatternFlip(mirrorX, mirrorY);
 				QTransform mpa;
 				mpa.translate(-item->lineWidth() / 2.0, -item->lineWidth() / 2.0);
-				mpa.translate(patternOffsetX, patternOffsetY);
-				mpa.rotate(patternRotation);
-				mpa.shear(-patternSkewX, patternSkewY);
+				mpa.translate(strokePatTrans.offsetX, strokePatTrans.offsetY);
+				mpa.rotate(strokePatTrans.rotation);
+				mpa.shear(-strokePatTrans.skewX, strokePatTrans.skewY);
 				mpa.scale(pa.scaleX, pa.scaleY);
-				mpa.scale(patternScaleX / 100.0 , patternScaleY / 100.0);
+				mpa.scale(strokePatTrans.scaleX, strokePatTrans.scaleY);
 				if (mirrorX)
 					mpa.scale(-1, 1);
 				if (mirrorY)
@@ -1839,7 +1840,7 @@ QDomElement SVGExPlug::processArrows(PageItem *item, const QDomElement& line, co
 QString SVGExPlug::handleMask(PageItem *item, double xOffset, double yOffset)
 {
 	QDomElement grad;
-	QString retVal = "";
+	QString retVal;
 	if (item->GrMask == 0)
 		return retVal;
 
@@ -1866,16 +1867,15 @@ QString SVGExPlug::handleMask(PageItem *item, double xOffset, double yOffset)
 		patt.setAttribute("height", FToStr(pa.height));
 		patt.setAttribute("width", FToStr(pa.width));
 		patt.setAttribute("patternUnits", "userSpaceOnUse");
-		double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY;
-		item->maskTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY);
+		const ScMaskTransform& maskTrans = item->maskTransform();
 		bool mirrorX, mirrorY;
 		item->maskFlip(mirrorX, mirrorY);
 		QTransform mpa;
-		mpa.translate(patternOffsetX, patternOffsetY);
-		mpa.rotate(patternRotation);
-		mpa.shear(-patternSkewX, patternSkewY);
+		mpa.translate(maskTrans.offsetX, maskTrans.offsetY);
+		mpa.rotate(maskTrans.rotation);
+		mpa.shear(-maskTrans.skewX, maskTrans.skewY);
 		mpa.scale(pa.scaleX, pa.scaleY);
-		mpa.scale(patternScaleX / 100.0 , patternScaleY / 100.0);
+		mpa.scale(maskTrans.scaleX, maskTrans.scaleY);
 		if (mirrorX)
 			mpa.scale(-1, 1);
 		if (mirrorY)
@@ -1989,16 +1989,15 @@ QString SVGExPlug::getFillStyle(PageItem *item)
 				patt.setAttribute("height", FToStr(pa.height));
 				patt.setAttribute("width", FToStr(pa.width));
 				patt.setAttribute("patternUnits", "userSpaceOnUse");
-				double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY;
-				item->patternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY);
+				const ScPatternTransform& patternTrans = item->patternTransform();
 				bool mirrorX, mirrorY;
 				item->patternFlip(mirrorX, mirrorY);
 				QTransform mpa;
-				mpa.translate(patternOffsetX, patternOffsetY);
-				mpa.rotate(patternRotation);
-				mpa.shear(-patternSkewX, patternSkewY);
+				mpa.translate(patternTrans.offsetX, patternTrans.offsetY);
+				mpa.rotate(patternTrans.rotation);
+				mpa.shear(-patternTrans.skewX, patternTrans.skewY);
 				mpa.scale(pa.scaleX, pa.scaleY);
-				mpa.scale(patternScaleX / 100.0 , patternScaleY / 100.0);
+				mpa.scale(patternTrans.scaleX, patternTrans.scaleY);
 				if (mirrorX)
 					mpa.scale(-1, 1);
 				if (mirrorY)
@@ -2134,7 +2133,7 @@ void SVGExPlug::writeBaseSymbols()
 
 QString SVGExPlug::getStrokeStyle(PageItem *item)
 {
-	QString stroke = "";
+	QString stroke;
 	if (item->lineTransparency() != 0)
 		stroke = "stroke-opacity:" + FToStr(1.0 - item->lineTransparency()) + ";";
 	if (item->lineWidth() != 0.0)
@@ -2205,17 +2204,16 @@ QString SVGExPlug::getStrokeStyle(PageItem *item)
 		patt.setAttribute("height", FToStr(pa.height));
 		patt.setAttribute("width", FToStr(pa.width));
 		patt.setAttribute("patternUnits", "userSpaceOnUse");
-		double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternSpace;
-		item->strokePatternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternSpace);
+		const ScStrokePatternTransform& strokePatTrans = item->strokePatternTransform();
 		bool mirrorX, mirrorY;
 		item->strokePatternFlip(mirrorX, mirrorY);
 		QTransform mpa;
 		mpa.translate(-item->lineWidth() / 2.0, -item->lineWidth() / 2.0);
-		mpa.translate(patternOffsetX, patternOffsetY);
-		mpa.rotate(patternRotation);
-		mpa.shear(-patternSkewX, patternSkewY);
+		mpa.translate(strokePatTrans.offsetX, strokePatTrans.offsetY);
+		mpa.rotate(strokePatTrans.rotation);
+		mpa.shear(-strokePatTrans.skewX, strokePatTrans.skewY);
 		mpa.scale(pa.scaleX, pa.scaleY);
-		mpa.scale(patternScaleX / 100.0 , patternScaleY / 100.0);
+		mpa.scale(strokePatTrans.scaleX, strokePatTrans.scaleY);
 		if (mirrorX)
 			mpa.scale(-1, 1);
 		if (mirrorY)
