@@ -171,7 +171,7 @@ QString Scribus12Format::readSLA(const QString & fileName)
 		// Not gzip encoded, just load it
 		loadRawText(fileName, docBytes);
 	}
-	QString docText("");
+	QString docText;
 	if (docBytes.left(16) != "<SCRIBUSUTF8NEW ") // Not a 1.3.x doc
 	{
 		if (docBytes.left(12) == "<SCRIBUSUTF8") // 1.2.x UTF8 doc
@@ -280,7 +280,7 @@ void Scribus12Format::PasteItem(struct CopyPasteBuffer *Buffer, bool drag, bool
 				it++;
 				nstyle.setFont((*m_Doc->AllFonts)[*it]);
 				it++;
-				nstyle.setFontSize(qRound(ScCLocale::toDoubleC((*it)) * 10));
+				nstyle.setFontSize(qRound(ScCLocale::toDoubleC(*it) * 10));
 				it++;
 				nstyle.setFillColor(*it);
 				it++;
@@ -700,7 +700,7 @@ void Scribus12Format::PasteItem(struct CopyPasteBuffer *Buffer, bool drag, bool
 
 void Scribus12Format::getReplacedFontData(bool& getNewReplacement, QMap<QString,QString> &getReplacedFonts, QList<ScFace> &getDummyScFaces)
 {
-	getNewReplacement=false;
+	getNewReplacement = false;
 	getReplacedFonts.clear();
 	getDummyScFaces.clear();
 }
@@ -712,9 +712,9 @@ static long long scribus12itemID(int itemNr, int pageNr)
 
 bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fmt */, int /* flags */, int /* index */)
 {
-	if (m_Doc==nullptr || m_View==nullptr || m_AvailableFonts==nullptr)
+	if (m_Doc == nullptr || m_View == nullptr || m_AvailableFonts == nullptr)
 	{
-		Q_ASSERT(m_Doc==nullptr || m_View==nullptr || m_AvailableFonts==nullptr);
+		Q_ASSERT(m_Doc == nullptr || m_View == nullptr || m_AvailableFonts == nullptr);
 		return false;
 	}
 // 	ReplacedFonts.clear();
@@ -765,14 +765,14 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 	// and begin loading the doc
 	m_Doc->PageColors.clear();
 	m_Doc->Layers.clear();
-	ScColor lf = ScColor();
-	QDomElement elem=docu.documentElement();
+	ScColor lf;
+	QDomElement elem = docu.documentElement();
 	if ((elem.tagName() != "SCRIBUS") && (elem.tagName() != "SCRIBUSUTF8"))
 		return false;
 	if (elem.hasAttribute("Version"))
 		newVersion = true;
 	QDomNode docNode = elem.firstChild();
-	if (m_mwProgressBar!=nullptr)
+	if (m_mwProgressBar != nullptr)
 	{
 		m_mwProgressBar->setMaximum(docNode.childNodes().count());
 		m_mwProgressBar->setValue(0);
@@ -809,8 +809,8 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 			fp = 0;
 		m_Doc->setPageSetFirstPage(m_Doc->pagePositioning(), fp);
 		m_Doc->setUsesAutomaticTextFrames(dc.attribute("AUTOTEXT").toInt());
-		m_Doc->PageSp=dc.attribute("AUTOSPALTEN").toInt();
-		m_Doc->PageSpa=ScCLocale::toDoubleC(dc.attribute("ABSTSPALTEN"));
+		m_Doc->PageSp = dc.attribute("AUTOSPALTEN").toInt();
+		m_Doc->PageSpa = ScCLocale::toDoubleC(dc.attribute("ABSTSPALTEN"));
 		m_Doc->setUnitIndex(dc.attribute("UNITS", "0").toInt());
 		m_Doc->guidesPrefs().gridShown = prefsManager.appPrefs.guidesPrefs.gridShown;
 		m_Doc->guidesPrefs().guidesShown = prefsManager.appPrefs.guidesPrefs.guidesShown;
@@ -826,7 +826,7 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 		m_Doc->guidesPrefs().renderStackOrder << 0 << 1 << 2 << 3 << 4;
 		m_Doc->guidesPrefs().gridType = 0;
 // 		DoFonts.clear();
-		m_Doc->itemToolPrefs().textSize=qRound(ScCLocale::toDoubleC(dc.attribute("DSIZE")) * 10);
+		m_Doc->itemToolPrefs().textSize = qRound(ScCLocale::toDoubleC(dc.attribute("DSIZE")) * 10);
 		Defont = dc.attribute("DFONT");
 		m_Doc->itemToolPrefs().textFont = prefsManager.appPrefs.itemToolPrefs.textFont;
 		m_AvailableFonts->findFont(Defont, m_Doc);
@@ -906,7 +906,7 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 		while (!pageNode.isNull())
 		{
 			ObCount++;
-			if (m_mwProgressBar!=nullptr)
+			if (m_mwProgressBar != nullptr)
 				m_mwProgressBar->setValue(ObCount);
 			QDomElement pg = pageNode.toElement();
 			// 10/25/2004 pv - None is "reserved" color. cannot be defined in any file...
@@ -968,8 +968,7 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 				a = pg.attribute("NUM").toInt();
 				pageName = "";
 				pageName = pg.attribute("NAM", "");
-				QString Mus = "";
-				Mus = pg.attribute("MNAM","Normal");
+				QString Mus(pg.attribute("MNAM", "Normal"));
 				if (pageName.isEmpty())
 				{
 					//We store the pages master page but do not apply it now
@@ -990,7 +989,7 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 				//1.2.x docs!
 				m_View->addPage(a);
 				//emit NewPage(a);
-				m_Doc->Pages->at(a)->LeftPg=pg.attribute("LEFT", "0").toInt();
+				m_Doc->Pages->at(a)->LeftPg = pg.attribute("LEFT", "0").toInt();
 				m_Doc->Pages->at(a)->marginPreset = pg.attribute("PRESET", "0").toInt();
 
 				// guides reading
@@ -1106,7 +1105,7 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 						node = node.nextSibling();
 					}
 					delete lastS;
-					newItem->isAutoText=static_cast<bool>(obj.attribute("AUTOTEXT").toInt());
+					newItem->isAutoText = static_cast<bool>(obj.attribute("AUTOTEXT").toInt());
 					if (newItem->isAutoText)
 						m_Doc->LastAuto = newItem;
 //					newItem->NextIt = obj.attribute("NEXTITEM").toInt();
@@ -1376,7 +1375,7 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 	}
 	
 	setCurrentComboItem(m_ScMW->unitSwitcher, unitGetStrFromIndex(m_Doc->unitIndex()));
-	if (m_mwProgressBar!=nullptr)
+	if (m_mwProgressBar != nullptr)
 		m_mwProgressBar->setValue(docNode.childNodes().count());
 
 	ScMessageBox::warning(ScCore->primaryMainWindow(),
@@ -1386,9 +1385,6 @@ bool Scribus12Format::loadFile(const QString& fileName, const FileFormat & /* fm
 	
 	return true;
 //end old ReadDoc
-	
-	
-	//return false;
 }
 
 bool Scribus12Format::saveFile(const QString & /* fileName */, const FileFormat & /* fmt */)
@@ -1402,12 +1398,12 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 	int x, y;
 	double xf, yf, xf2;
 	OB->PType = static_cast<PageItem::ItemType>(obj->attribute("PTYPE").toInt());
-	OB->Width=ScCLocale::toDoubleC(obj->attribute("WIDTH"));
-	OB->Height=ScCLocale::toDoubleC(obj->attribute("HEIGHT"));
+	OB->Width = ScCLocale::toDoubleC(obj->attribute("WIDTH"));
+	OB->Height = ScCLocale::toDoubleC(obj->attribute("HEIGHT"));
 	OB->RadRect = ScCLocale::toDoubleC(obj->attribute("RADRECT"), 0.0);
 	OB->ClipEdited = obj->attribute("CLIPEDIT", "0").toInt();
 	OB->FrameType = obj->attribute("FRTYPE", "0").toInt();
-	OB->Pwidth=ScCLocale::toDoubleC(obj->attribute("PWIDTH"));
+	OB->Pwidth = ScCLocale::toDoubleC(obj->attribute("PWIDTH"));
 	OB->Pcolor = obj->attribute("PCOLOR");
 	if ((!newVersion) && (OB->PType == 4))
 	{
@@ -1424,20 +1420,20 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 	OB->Shade = obj->attribute("SHADE").toInt();
 	OB->Shade2 = obj->attribute("SHADE2").toInt();
 	OB->FillRule = obj->attribute("fillRule", "1").toInt();
-	OB->TxtStroke=obj->attribute("TXTSTROKE", CommonStrings::None);
-	OB->ShTxtFill=obj->attribute("TXTFILLSH", "100").toInt();
-	OB->ShTxtStroke=obj->attribute("TXTSTRSH", "100").toInt();
-	OB->TxtScale=qRound(ScCLocale::toDoubleC(obj->attribute("TXTSCALE"), 100.0) * 10);
-	OB->TxtScaleV=qRound(ScCLocale::toDoubleC(obj->attribute("TXTSCALEV"), 100.0) * 10);
-	OB->TxTBase=qRound(ScCLocale::toDoubleC(obj->attribute("TXTBASE"), 0.0) * 10);
-	OB->TxTStyle=obj->attribute("TXTSTYLE", "0").toInt();
-	OB->TxtShadowX=qRound(ScCLocale::toDoubleC(obj->attribute("TXTSHX"), 5.0) * 10);
-	OB->TxtShadowY=qRound(ScCLocale::toDoubleC(obj->attribute("TXTSHY"), -5.0) * 10);
-	OB->TxtOutline=qRound(ScCLocale::toDoubleC(obj->attribute("TXTOUT"), 1.0) * 10);
-	OB->TxtUnderPos=qRound(ScCLocale::toDoubleC(obj->attribute("TXTULP"), -0.1) * 10);
-	OB->TxtUnderWidth=qRound(ScCLocale::toDoubleC(obj->attribute("TXTULW"), -0.1) * 10);
-	OB->TxtStrikePos=qRound(ScCLocale::toDoubleC(obj->attribute("TXTSTP"), -0.1) * 10);
-	OB->TxtStrikeWidth=qRound(ScCLocale::toDoubleC(obj->attribute("TXTSTW"), -0.1) * 10);
+	OB->TxtStroke = obj->attribute("TXTSTROKE", CommonStrings::None);
+	OB->ShTxtFill = obj->attribute("TXTFILLSH", "100").toInt();
+	OB->ShTxtStroke = obj->attribute("TXTSTRSH", "100").toInt();
+	OB->TxtScale = qRound(ScCLocale::toDoubleC(obj->attribute("TXTSCALE"), 100.0) * 10);
+	OB->TxtScaleV = qRound(ScCLocale::toDoubleC(obj->attribute("TXTSCALEV"), 100.0) * 10);
+	OB->TxTBase = qRound(ScCLocale::toDoubleC(obj->attribute("TXTBASE"), 0.0) * 10);
+	OB->TxTStyle = obj->attribute("TXTSTYLE", "0").toInt();
+	OB->TxtShadowX = qRound(ScCLocale::toDoubleC(obj->attribute("TXTSHX"), 5.0) * 10);
+	OB->TxtShadowY = qRound(ScCLocale::toDoubleC(obj->attribute("TXTSHY"), -5.0) * 10);
+	OB->TxtOutline = qRound(ScCLocale::toDoubleC(obj->attribute("TXTOUT"), 1.0) * 10);
+	OB->TxtUnderPos = qRound(ScCLocale::toDoubleC(obj->attribute("TXTULP"), -0.1) * 10);
+	OB->TxtUnderWidth = qRound(ScCLocale::toDoubleC(obj->attribute("TXTULW"), -0.1) * 10);
+	OB->TxtStrikePos = qRound(ScCLocale::toDoubleC(obj->attribute("TXTSTP"), -0.1) * 10);
+	OB->TxtStrikeWidth = qRound(ScCLocale::toDoubleC(obj->attribute("TXTSTW"), -0.1) * 10);
 	OB->Cols = obj->attribute("COLUMNS", "1").toInt();
 	OB->ColGap = ScCLocale::toDoubleC(obj->attribute("COLGAP"), 0.0);
 	OB->GrType = obj->attribute("GRTYP", "0").toInt();
@@ -1447,8 +1443,8 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 		if (OB->GrType == Gradient_Pattern)
 		{
 			OB->pattern = obj->attribute("pattern", "");
-			OB->patternScaleX = ScCLocale::toDoubleC(obj->attribute("pScaleX"), 100.0);
-			OB->patternScaleY = ScCLocale::toDoubleC(obj->attribute("pScaleY"), 100.0);
+			OB->patternScaleX = ScCLocale::toDoubleC(obj->attribute("pScaleX"), 100.0) / 100.0;
+			OB->patternScaleY = ScCLocale::toDoubleC(obj->attribute("pScaleY"), 100.0) / 100.0;
 			OB->patternOffsetX = ScCLocale::toDoubleC(obj->attribute("pOffsetX"), 0.0);
 			OB->patternOffsetY = ScCLocale::toDoubleC(obj->attribute("pOffsetY"), 0.0);
 			OB->patternRotation = ScCLocale::toDoubleC(obj->attribute("pRotation"), 0.0);
@@ -1535,15 +1531,15 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 	OB->LocalX     = ScCLocale::toDoubleC(obj->attribute("LOCALX"));
 	OB->LocalY     = ScCLocale::toDoubleC(obj->attribute("LOCALY"));
 	OB->LocalRot   = 0.0;
-	OB->PicArt=obj->attribute("PICART").toInt();
+	OB->PicArt = obj->attribute("PICART").toInt();
 	OB->flippedH = obj->attribute("FLIPPEDH").toInt() % 2;
 	OB->flippedV = obj->attribute("FLIPPEDV").toInt() % 2;
-/*	OB->BBoxX=ScCLocale::toDoubleC(obj->attribute("BBOXX"));
-	OB->BBoxH=ScCLocale::toDoubleC(obj->attribute("BBOXH")); */
+/*	OB->BBoxX = ScCLocale::toDoubleC(obj->attribute("BBOXX"));
+	OB->BBoxH = ScCLocale::toDoubleC(obj->attribute("BBOXH")); */
 	OB->ScaleType = obj->attribute("SCALETYPE", "1").toInt();
 	OB->AspectRatio = obj->attribute("RATIO", "0").toInt();
-	OB->isPrintable=obj->attribute("PRINTABLE").toInt();
-	OB->m_isAnnotation=obj->attribute("ANNOTATION", "0").toInt();
+	OB->isPrintable = obj->attribute("PRINTABLE").toInt();
+	OB->m_isAnnotation = obj->attribute("ANNOTATION", "0").toInt();
 	OB->m_annotation.setType(obj->attribute("ANTYPE", "0").toInt());
 	OB->m_annotation.setAction(obj->attribute("ANACTION",""));
 	OB->m_annotation.setE_act(obj->attribute("ANEACT",""));
@@ -1563,7 +1559,7 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 		OB->m_annotation.setExtern(efp.absoluteFilePath());
 	}
 	OB->m_annotation.setZiel(obj->attribute("ANZIEL", "0").toInt());
-	OB->itemName=obj->attribute("ANNAME","");
+	OB->itemName = obj->attribute("ANNAME", "");
 	OB->m_annotation.setToolTip(obj->attribute("ANTOOLTIP",""));
 	OB->m_annotation.setRollOver(obj->attribute("ANROLL",""));
 	OB->m_annotation.setDown(obj->attribute("ANDOWN",""));
@@ -1586,7 +1582,7 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 	OB->m_annotation.setScaleW(obj->attribute("ANSCALE", "0").toInt());
 	if (obj->attribute("TRANSPARENT", "0").toInt() == 1)
 		OB->Pcolor = CommonStrings::None;
-	OB->textAlignment=obj->attribute("ALIGN", "0").toInt();
+	OB->textAlignment = obj->attribute("ALIGN", "0").toInt();
 	if ( obj->hasAttribute("TEXTFLOWMODE") )
 		OB->TextflowMode = (PageItem::TextFlowMode) obj->attribute("TEXTFLOWMODE", "0").toInt();
 	else if ( obj->attribute("TEXTFLOW").toInt() )
@@ -1600,10 +1596,10 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 	}
 	else
 		OB->TextflowMode = PageItem::TextFlowDisabled;
-	OB->Extra=ScCLocale::toDoubleC(obj->attribute("EXTRA"));
-	OB->TExtra=ScCLocale::toDoubleC(obj->attribute("TEXTRA"), 1.0);
-	OB->BExtra=ScCLocale::toDoubleC(obj->attribute("BEXTRA"), 1.0);
-	OB->RExtra=ScCLocale::toDoubleC(obj->attribute("REXTRA"), 1.0);
+	OB->Extra = ScCLocale::toDoubleC(obj->attribute("EXTRA"));
+	OB->TExtra = ScCLocale::toDoubleC(obj->attribute("TEXTRA"), 1.0);
+	OB->BExtra = ScCLocale::toDoubleC(obj->attribute("BEXTRA"), 1.0);
+	OB->RExtra = ScCLocale::toDoubleC(obj->attribute("REXTRA"), 1.0);
 	OB->PoShow = obj->attribute("PLTSHOW", "0").toInt();
 	OB->BaseOffs = ScCLocale::toDoubleC(obj->attribute("BASEOF"), 0.0);
 	OB->textPathType =  obj->attribute("textPathType", "0").toInt();
@@ -1662,7 +1658,7 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 	{
 		OB->PoLine.resize(obj->attribute("NUMPO").toUInt());
 		tmp = obj->attribute("POCOOR");
-		double maxVal = std::numeric_limits<double>::max() / 2.0;
+		constexpr double maxVal = std::numeric_limits<double>::max() / 2.0;
 		ScTextStream fp(&tmp, QIODevice::ReadOnly);
 		for (uint cx=0; cx<obj->attribute("NUMPO").toUInt(); ++cx)
 		{
@@ -1682,7 +1678,7 @@ void Scribus12Format::GetItemProps(QDomElement *obj, struct CopyPasteBuffer *OB,
 	{
 		OB->ContourLine.resize(obj->attribute("NUMCO").toUInt());
 		tmp = obj->attribute("COCOOR");
-		double maxVal = std::numeric_limits<double>::max() / 2.0;
+		constexpr double maxVal = std::numeric_limits<double>::max() / 2.0;
 		ScTextStream fp(&tmp, QIODevice::ReadOnly);
 		for (uint cx=0; cx<obj->attribute("NUMCO").toUInt(); ++cx)
 		{
@@ -1827,9 +1823,9 @@ void Scribus12Format::GetItemText(QDomElement *it, ScribusDoc *doc, bool VorLFou
 bool Scribus12Format::loadPage(const QString & fileName, int pageNumber, bool Mpage, const QString& /*renamedPageName*/)
 {
 //	qDebug() << QString("loading page %2 from file '%1' from 1.2.x plugin").arg(fileName).arg(pageNumber);
-	if (m_Doc==nullptr || m_View==nullptr || m_AvailableFonts==nullptr)
+	if (m_Doc == nullptr || m_View == nullptr || m_AvailableFonts == nullptr)
 	{
-		Q_ASSERT(m_Doc==nullptr || m_View==nullptr|| m_AvailableFonts==nullptr);
+		Q_ASSERT(m_Doc == nullptr || m_View == nullptr || m_AvailableFonts == nullptr);
 		return false;
 	}
 
@@ -1850,7 +1846,7 @@ bool Scribus12Format::loadPage(const QString & fileName, int pageNumber, bool Mp
 	int maxLayer = 0;
 	int maxLevel = 0;
 	layerTrans.clear();
-	uint layerCount=m_Doc->layerCount();
+	uint layerCount = m_Doc->layerCount();
 	for (uint la2 = 0; la2 < layerCount; ++la2)
 	{
 		maxLayer = qMax(m_Doc->Layers[la2].ID, maxLayer);
@@ -1878,8 +1874,8 @@ bool Scribus12Format::loadPage(const QString & fileName, int pageNumber, bool Mp
 		return false;
 	}
 	QString fileDir = QFileInfo(fileName).absolutePath();
-	ScColor lf = ScColor();
-	QDomElement elem=docu.documentElement();
+	ScColor lf;
+	QDomElement elem = docu.documentElement();
 	if ((elem.tagName() != "SCRIBUS") && (elem.tagName() != "SCRIBUSUTF8"))
 		return false;
 	if (elem.hasAttribute("Version"))
@@ -1984,7 +1980,7 @@ bool Scribus12Format::loadPage(const QString & fileName, int pageNumber, bool Mp
 				} */
 				if (Mpage)
 				{
-					m_Doc->Pages->at(a)->LeftPg=pg.attribute("LEFT", "0").toInt();
+					m_Doc->Pages->at(a)->LeftPg = pg.attribute("LEFT", "0").toInt();
 					m_Doc->Pages->at(a)->setPageName(pg.attribute("NAM",""));
 				}
 				TableItems.clear();
@@ -2023,8 +2019,8 @@ bool Scribus12Format::loadPage(const QString & fileName, int pageNumber, bool Mp
 						}
 					}
 					GetItemProps(&obj, &OB, fileDir, newVersion);
-					OB.Xpos = ScCLocale::toDoubleC(obj.attribute("XPOS"))+m_Doc->Pages->at(a)->xOffset();
-					OB.Ypos=ScCLocale::toDoubleC(obj.attribute("YPOS"))+m_Doc->Pages->at(a)->yOffset();
+					OB.Xpos = ScCLocale::toDoubleC(obj.attribute("XPOS")) + m_Doc->Pages->at(a)->xOffset();
+					OB.Ypos = ScCLocale::toDoubleC(obj.attribute("YPOS")) + m_Doc->Pages->at(a)->yOffset();
 					OB.NamedLStyle = obj.attribute("NAMEDLST", "");
 					if (!m_Doc->docLineStyles.contains(OB.NamedLStyle))
 						OB.NamedLStyle = "";
@@ -2272,14 +2268,14 @@ void Scribus12Format::GetStyle(QDomElement *pg, ParagraphStyle *vg, StyleSet<Par
 	tmpf = pg->attribute("FONT", doc->itemToolPrefs().textFont);
 	if (tmpf.isEmpty())
 		tmpf = doc->itemToolPrefs().textFont;
-	PrefsManager& prefsManager=PrefsManager::instance();
+	PrefsManager& prefsManager = PrefsManager::instance();
 	prefsManager.appPrefs.fontPrefs.AvailFonts.findFont(tmpf, doc);
 	vg->charStyle().setFont(prefsManager.appPrefs.fontPrefs.AvailFonts[tmpf]);
 	vg->charStyle().setFontSize(qRound(ScCLocale::toDoubleC(pg->attribute("FONTSIZE"), 12.0) * 10.0));
 	vg->setHasDropCap(static_cast<bool>(pg->attribute("DROP", "0").toInt()));
 	vg->setDropCapLines(pg->attribute("DROPLIN", "2").toInt());
 	vg->setParEffectOffset(ScCLocale::toDoubleC(pg->attribute("DROPDIST"), 0.0));
-	vg->charStyle().setFeatures(static_cast<StyleFlag>((pg->attribute("EFFECT", "0").toInt())).featureList());
+	vg->charStyle().setFeatures(static_cast<StyleFlag>( pg->attribute("EFFECT", "0").toInt() ).featureList());
 	fColor = pg->attribute("FCOLOR", doc->itemToolPrefs().shapeFillColor);
 	fShade = pg->attribute("FSHADE", "100").toInt();
 	handleOldColorShade(doc, fColor, fShade);
@@ -2334,8 +2330,7 @@ void Scribus12Format::GetStyle(QDomElement *pg, ParagraphStyle *vg, StyleSet<Par
 				ParagraphStyle::TabRecord tb;
 				tb.tabPosition = ScCLocale::toDoubleC(it.attribute("Pos"));
 				tb.tabType = it.attribute("Type").toInt();
-				QString tbCh = "";
-				tbCh = it.attribute("Fill","");
+				QString tbCh(it.attribute("Fill", ""));
 				if (tbCh.isEmpty())
 					tb.tabFillChar = QChar();
 				else
@@ -2444,7 +2439,7 @@ bool Scribus12Format::readLineStyles(const QString& fileName, QHash<QString,mult
 		return false;
 	if (!docu.setContent(f))
 		return false;
-	QDomElement elem=docu.documentElement();
+	QDomElement elem = docu.documentElement();
 	if ((elem.tagName() != "SCRIBUS") && (elem.tagName() != "SCRIBUSUTF8"))
 		return false;
 	QDomNode docNode = elem.firstChild();
@@ -2503,8 +2498,8 @@ bool Scribus12Format::readColors(const QString& fileName, ColorList & colors)
 	if (!docu.setContent(f))
 		return false;
 	colors.clear();
-	ScColor lf = ScColor();
-	QDomElement elem=docu.documentElement();
+	ScColor lf;
+	QDomElement elem = docu.documentElement();
 	if ((elem.tagName() != "SCRIBUS") && (elem.tagName() != "SCRIBUSUTF8"))
 		return false;
 	QDomNode docNode = elem.firstChild();
@@ -2550,7 +2545,7 @@ bool Scribus12Format::readPageCount(const QString& fileName, int *num1, int *num
 		return false;
 	if (!docu.setContent(f))
 		return false;
-	QDomElement elem=docu.documentElement();
+	QDomElement elem = docu.documentElement();
 	if ((elem.tagName() != "SCRIBUS") && (elem.tagName() != "SCRIBUSUTF8"))
 		return false;
 	QDomNode docNode = elem.firstChild();
