@@ -20,13 +20,13 @@ class PLUGIN_API FontPreviewPlugin : public ScActionPlugin
 		// Standard plugin implementation
 		FontPreviewPlugin();
 		virtual ~FontPreviewPlugin();
-		virtual bool run(ScribusDoc* doc, const QString& target = QString());
-		virtual bool run(QWidget *parent, ScribusDoc* doc, const QString& target = QString());
-		virtual const QString fullTrName() const;
-		virtual const AboutData* getAboutData() const;
-		virtual void deleteAboutData(const AboutData* about) const;
-		virtual void languageChange();
-		virtual void addToMainWindowMenu(ScribusMainWindow *) {};
+		bool run(ScribusDoc* doc, const QString& target = QString()) override;
+		bool run(QWidget *parent, ScribusDoc* doc, const QString& target = QString()) override;
+		QString fullTrName() const override;
+		const AboutData* getAboutData() const override;
+		void deleteAboutData(const AboutData* about) const override;
+		void languageChange() override;
+		void addToMainWindowMenu(ScribusMainWindow *) override {};
 
 		// Special features (none)
 };
