@@ -39,19 +39,19 @@ QStringList FileExtensions()
 	return ret;
 }
 
-void GetText2(const QString& filename, const QString& encoding, bool textOnly, bool prefix, bool append, PageItem *textItem)
+void GetText2(const QString& filename, const QString& /*encoding*/, bool textOnly, bool prefix, bool append, PageItem *textItem)
 {
 	ODTIm* docxim = new ODTIm(filename, textItem, textOnly, prefix, append);
 	delete docxim;
 }
 
 ODTIm::ODTIm(const QString& fileName, PageItem *textItem, bool textOnly, bool prefix, bool append)
+	: m_Doc(textItem->doc()),
+	  m_item(textItem),
+	  m_prefixName(prefix),
+	  m_append(append)
 {
-	m_Doc = textItem->doc();
-	m_item = textItem;
-	m_prefixName = prefix;
-	m_append = append;
-	QFileInfo fi = QFileInfo(fileName);
+	QFileInfo fi(fileName);
 	QString ext = fi.suffix().toLower();
 	if (ext == "fodt")
 	{
@@ -105,22 +105,19 @@ ODTIm::ODTIm(const QString& fileName, PageItem *textItem, bool textOnly, bool pr
 					if (uz->contains("content.xml"))
 						parseRawDocReference("content.xml");
 				}
-				else
+				else if (uz->contains("styles.xml"))
 				{
-					if (uz->contains("styles.xml"))
-					{
-						if (parseStyleSheets("styles.xml"))
-						{
-							if (uz->contains("content.xml"))
-								parseDocReference("content.xml");
-						}
-					}
-					else
+					if (parseStyleSheets("styles.xml"))
 					{
 						if (uz->contains("content.xml"))
 							parseDocReference("content.xml");
 					}
 				}
+				else
+				{
+					if (uz->contains("content.xml"))
+						parseDocReference("content.xml");
+				}
 				uz->close();
 				delete uz;
 			}
@@ -130,10 +127,6 @@ ODTIm::ODTIm(const QString& fileName, PageItem *textItem, bool textOnly, bool pr
 	textItem->itemText.invalidateLayout();
 }
 
-ODTIm::~ODTIm()
-{
-}
-
 /* Raw Text import */
 
 bool ODTIm::parseRawDocReference(const QString& designMap)
@@ -154,7 +147,7 @@ bool ODTIm::parseRawDocReference(const QString& designMap)
 	return parseRawDocReferenceXML(designMapDom);
 }
 
-bool ODTIm::parseRawDocReferenceXML(QDomDocument &designMapDom)
+bool ODTIm::parseRawDocReferenceXML(const QDomDocument &designMapDom)
 {
 	QDomElement docElem = designMapDom.documentElement();
 	for (QDomElement drawPag = docElem.firstChildElement(); !drawPag.isNull(); drawPag = drawPag.nextSiblingElement())
@@ -173,14 +166,14 @@ bool ODTIm::parseRawDocReferenceXML(QDomDocument &designMapDom)
 	return true;
 }
 
-void ODTIm::parseRawTextSpan(QDomElement &elem, PageItem* item, ParagraphStyle &tmpStyle, CharStyle &tmpCStyle, int &posC)
+void ODTIm::parseRawTextSpan(const QDomElement &elem, PageItem* item, ParagraphStyle &tmpStyle, CharStyle &tmpCStyle, int &posC)
 {
 	if (!elem.hasChildNodes())
 		return;
 
 	for (QDomNode spn = elem.firstChild(); !spn.isNull(); spn = spn.nextSibling())
 	{
-		QString txt = "";
+		QString txt;
 		QDomElement spEl = spn.toElement();
 		if (spn.nodeName() == "#text")
 			txt = spn.nodeValue();
@@ -213,14 +206,14 @@ void ODTIm::parseRawTextSpan(QDomElement &elem, PageItem* item, ParagraphStyle &
 	}
 }
 
-void ODTIm::parseRawTextParagraph(QDomNode &elem, PageItem* item, ParagraphStyle &newStyle, int &posC)
+void ODTIm::parseRawTextParagraph(const QDomNode &elem, PageItem* item, ParagraphStyle &newStyle, int &posC)
 {
 	CharStyle tmpCStyle = newStyle.charStyle();
 	if (elem.hasChildNodes())
 	{
 		for (QDomNode spn = elem.firstChild(); !spn.isNull(); spn = spn.nextSibling())
 		{
-			QString txt = "";
+			QString txt;
 			QDomElement spEl = spn.toElement();
 			if (spn.nodeName() == "#text")
 				txt = spn.nodeValue();
@@ -257,7 +250,7 @@ void ODTIm::parseRawTextParagraph(QDomNode &elem, PageItem* item, ParagraphStyle
 	posC = item->itemText.length();
 }
 
-void ODTIm::parseRawText(QDomElement &elem, PageItem* item)
+void ODTIm::parseRawText(const QDomElement &elem, PageItem* item)
 {
 	QString pStyleD = CommonStrings::DefaultParagraphStyle;
 	ParagraphStyle newStyle;
@@ -328,7 +321,7 @@ bool ODTIm::parseStyleSheets(const QString& designMap)
 	return parseStyleSheetsXML(designMapDom);
 }
 
-bool ODTIm::parseStyleSheetsXML(QDomDocument &designMapDom)
+bool ODTIm::parseStyleSheetsXML(const QDomDocument &designMapDom)
 {
 	QDomElement docElem = designMapDom.documentElement();
 	for (QDomElement sp = docElem.firstChildElement(); !sp.isNull(); sp = sp.nextSiblingElement() )
@@ -359,7 +352,7 @@ bool ODTIm::parseStyleSheetsXML(QDomDocument &designMapDom)
 	return true;
 }
 
-void ODTIm::parseStyles(QDomElement &sp, const QString& type)
+void ODTIm::parseStyles(const QDomElement &sp, const QString& type)
 {
 	for (QDomElement spd = sp.firstChildElement(); !spd.isNull(); spd = spd.nextSiblingElement() )
 	{
@@ -387,8 +380,8 @@ void ODTIm::parseStyles(QDomElement &sp, const QString& type)
 						{
 							if (spt.tagName() == "style:tab-stops")
 							{
-								QString tabDists = "";
-								QString tabTypes = "";
+								QString tabDists;
+								QString tabTypes;
 								for (QDomElement spte = spt.firstChildElement(); !spte.isNull(); spte = spte.nextSiblingElement() )
 								{
 									if (spte.tagName() == "style:tab-stop")
@@ -467,8 +460,8 @@ void ODTIm::parseStyles(QDomElement &sp, const QString& type)
 						{
 							if (spt.tagName() == "style:tab-stops")
 							{
-								QString tabDists = "";
-								QString tabTypes = "";
+								QString tabDists;
+								QString tabTypes;
 								for (QDomElement spte = spt.firstChildElement(); !spte.isNull(); spte = spte.nextSiblingElement() )
 								{
 									if (spte.tagName() == "style:tab-stop")
@@ -589,7 +582,7 @@ bool ODTIm::parseDocReference(const QString& designMap)
 	return parseDocReferenceXML(designMapDom);
 }
 
-bool ODTIm::parseDocReferenceXML(QDomDocument &designMapDom)
+bool ODTIm::parseDocReferenceXML(const QDomDocument &designMapDom)
 {
 	QDomElement docElem = designMapDom.documentElement();
 	for (QDomElement drawPag = docElem.firstChildElement(); !drawPag.isNull(); drawPag = drawPag.nextSiblingElement())
@@ -632,8 +625,11 @@ bool ODTIm::parseDocReferenceXML(QDomDocument &designMapDom)
 	return true;
 }
 
-void ODTIm::parseTextSpan(QDomElement &elem, PageItem* item, ParagraphStyle &tmpStyle, CharStyle &tmpCStyle, ObjStyleODT &tmpOStyle, int &posC)
+void ODTIm::parseTextSpan(const QDomElement &elem, PageItem* item, const ParagraphStyle &tmpStyle, const CharStyle &tmpCStyle, const ObjStyleODT &tmpOStyle, int &posC)
 {
+	if (!elem.hasChildNodes())
+		return;
+
 	ObjStyleODT odtStyle = tmpOStyle;
 	CharStyle cStyle = tmpCStyle;
 
@@ -645,12 +641,10 @@ void ODTIm::parseTextSpan(QDomElement &elem, PageItem* item, ParagraphStyle &tmp
 	}
 	
 	applyCharacterStyle(cStyle, odtStyle);
-	if (!elem.hasChildNodes())
-		return;
 
 	for (QDomNode spn = elem.firstChild(); !spn.isNull(); spn = spn.nextSibling())
 	{
-		QString txt = "";
+		QString txt;
 		QDomElement spEl = spn.toElement();
 		if (spn.nodeName() == "#text")
 			txt = spn.nodeValue();
@@ -686,12 +680,12 @@ void ODTIm::parseTextSpan(QDomElement &elem, PageItem* item, ParagraphStyle &tmp
 		m_textStylesStack.pop();
 }
 
-void ODTIm::parseTextParagraph(QDomNode &elem, PageItem* item, ParagraphStyle &newStyle, ObjStyleODT &tmpOStyle, int &posC)
+void ODTIm::parseTextParagraph(const QDomNode &elem, PageItem* item, const ParagraphStyle &newStyle, const ObjStyleODT &tmpOStyle, int &posC)
 {
 	ParagraphStyle tmpStyle = newStyle;
 	CharStyle tmpCStyle = tmpStyle.charStyle();
 	ObjStyleODT pStyle = tmpOStyle;
-	QString parStyleName = "";
+	QString parStyleName;
 
 	QString pStyleName = elem.toElement().attribute("text:style-name");
 	if (pStyleName.length() > 0)
@@ -747,7 +741,7 @@ void ODTIm::parseTextParagraph(QDomNode &elem, PageItem* item, ParagraphStyle &n
 				tmpCStyle = tmpStyle.charStyle();
 				applyCharacterStyle(tmpCStyle, pStyle);
 			}
-			QString txt = "";
+			QString txt;
 			ObjStyleODT cStyle = pStyle;
 			QDomElement spEl = spn.toElement();
 			if (spn.nodeName() == "#text")
@@ -808,7 +802,7 @@ void ODTIm::parseTextParagraph(QDomNode &elem, PageItem* item, ParagraphStyle &n
 		m_textStylesStack.pop();
 }
 
-void ODTIm::parseText(QDomElement &elem, PageItem* item, ObjStyleODT &tmpOStyle)
+void ODTIm::parseText(const QDomElement &elem, PageItem* item, const ObjStyleODT &tmpOStyle)
 {
 	QString pStyleD = CommonStrings::DefaultParagraphStyle;
 	ParagraphStyle newStyle;
@@ -864,7 +858,7 @@ void ODTIm::parseText(QDomElement &elem, PageItem* item, ObjStyleODT &tmpOStyle)
 	}
 }
 
-void ODTIm::insertChars(PageItem *item, QString &txt, ParagraphStyle &tmpStyle, CharStyle &tmpCStyle, int &posC)
+void ODTIm::insertChars(PageItem *item, QString &txt, const ParagraphStyle &tmpStyle, const CharStyle &tmpCStyle, int &posC)
 {
 	if (txt.length() > 0)
 	{
@@ -872,11 +866,11 @@ void ODTIm::insertChars(PageItem *item, QString &txt, ParagraphStyle &tmpStyle,
 		item->itemText.applyStyle(posC, tmpStyle);
 		item->itemText.applyCharStyle(posC, txt.length(), tmpCStyle);
 		posC = item->itemText.length();
-		txt = "";
+		txt.clear();
 	}
 }
 
-void ODTIm::applyCharacterStyle(CharStyle &tmpCStyle, ObjStyleODT &oStyle)
+void ODTIm::applyCharacterStyle(CharStyle &tmpCStyle, const ObjStyleODT &oStyle)
 {
 	tmpCStyle.setFont((*m_Doc->AllFonts)[oStyle.fontName]);
 	tmpCStyle.setFontSize(oStyle.fontSize * 10);
@@ -938,7 +932,7 @@ void ODTIm::applyCharacterStyle(CharStyle &tmpCStyle, ObjStyleODT &oStyle)
 		setFontstyle(tmpCStyle, 2);
 }
 
-void ODTIm::applyParagraphStyle(ParagraphStyle &tmpStyle, ObjStyleODT &oStyle)
+void ODTIm::applyParagraphStyle(ParagraphStyle &tmpStyle, const ObjStyleODT &oStyle)
 {
 	tmpStyle.setAlignment(oStyle.textAlign);
 	tmpStyle.setLeftMargin(oStyle.margin_left);
@@ -1228,7 +1222,7 @@ void ODTIm::resolveStyle(ObjStyleODT &tmpOStyle, const QString& pAttrs)
 
 double ODTIm::parseUnit(const QString &unit)
 {
-	QString unitval=unit;
+	QString unitval = unit;
 	if (unit.isEmpty())
 		return 0.0;
 	if (unit.right( 2 ) == "pt")
@@ -1263,7 +1257,7 @@ QString ODTIm::parseColor( const QString &s )
 {
 	QColor c;
 	QString ret = CommonStrings::None;
-	if ((s == "") || s.isEmpty())
+	if (s.isEmpty())
 		return ret;
 	if (s.startsWith( "rgb(" ))
 	{
@@ -1275,17 +1269,17 @@ QString ODTIm::parseColor( const QString &s )
 		if (r.contains( "%" ))
 		{
 			r.chop(1);
-			r = QString::number( static_cast<int>( ( static_cast<double>( 255 * ScCLocale::toDoubleC(r) ) / 100.0 ) ) );
+			r = QString::number( static_cast<int>( ( 255.0 * ScCLocale::toDoubleC(r) ) / 100.0 ) );
 		}
 		if (g.contains( "%" ))
 		{
 			g.chop(1);
-			g = QString::number( static_cast<int>( ( static_cast<double>( 255 * ScCLocale::toDoubleC(g) ) / 100.0 ) ) );
+			g = QString::number( static_cast<int>( ( 255.0 * ScCLocale::toDoubleC(g)) / 100.0 ) );
 		}
 		if (b.contains( "%" ))
 		{
 			b.chop(1);
-			b = QString::number( static_cast<int>( ( static_cast<double>( 255 * ScCLocale::toDoubleC(b) ) / 100.0 ) ) );
+			b = QString::number( static_cast<int>( ( 255.0 * ScCLocale::toDoubleC(b)) / 100.0 ) );
 		}
 		c = QColor(r.toInt(), g.toInt(), b.toInt());
 	}
@@ -1343,14 +1337,14 @@ QString ODTIm::constructFontName(const QString& fontBaseName, const QString& fon
 		return fontName;
 	}
 
-	qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+	QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 	QScopedPointer<MissingFont> dia(new MissingFont(nullptr, family, m_Doc));
 	if (dia->exec())
 		fontName = dia->getReplacementFont();
 	else
 		fontName = m_Doc->itemToolPrefs().textFont;
 	PrefsManager::instance().appPrefs.fontPrefs.GFontSub[family] = fontName;
-	qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
+	QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 
 	return fontName;
 }
