@@ -300,6 +300,57 @@ protected:
 	Qt::PenJoinStyle m_lineJoin { Qt::MiterJoin };
 	QList<PageItem*>* m_Elements;
 
+	class GraphicState
+	{
+	public:
+		QString fillColor { "Black" };
+		int     fillShade { 100 };
+		QString strokeColor { "Black "};
+		int     strokeShade { 100 };
+
+		// The currently visible area. If it is empty, everything is visible.
+		// QPainterPath has the drawback that it sometimes approximates Bezier curves
+		// by line segments for numerical stability. If available, a better class
+		// should be used. However, it is important that the used class knows which
+		// areas are covered and does not rely on external information about the fill
+		// rule to use.
+		QPainterPath clipPath;
+	};
+
+	class GraphicStack
+	{
+	public:
+		GraphicStack()
+		{
+			m_stack.push(GraphicState());
+		}
+
+		void clear()
+		{
+			m_stack.clear();
+			m_stack.push(GraphicState());
+		}
+
+		void save()
+		{
+			m_stack.push(m_stack.top());
+		}
+
+		void restore()
+		{
+			if (m_stack.count() > 0)
+				m_stack.pop();
+			if (m_stack.count() == 0)
+				m_stack.push(GraphicState());
+		}
+
+		GraphicState& top() { return m_stack.top(); }
+		const GraphicState& top() const  { return m_stack.top(); }
+
+	private:
+		QStack<GraphicState> m_stack;
+	};
+
 	struct groupEntry
 	{
 		QList<PageItem*> Items;
@@ -312,10 +363,7 @@ protected:
 	};
 
 	QStack<groupEntry> m_groupStack;
-	QString m_currColorFill;
-	QString m_currColorStroke;
-	int m_currFillShade { 100 };
-	int m_currStrokeShade { 100 };
+	GraphicStack m_graphicStack;
 
 private:
 	void getPenState(GfxState *state);
@@ -337,24 +385,17 @@ private:
 
 	void createImageFrame(QImage& image, GfxState *state, int numColorComponents);
 
-	bool pathIsClosed { false };
-	QVector<double> DashValues;
-	double DashOffset { 0.0 };
-	QString Coords;
-	// The currently visible area. If it is empty, everything is visible.
-	// QPainterPath has the drawback that it sometimes approximates Bezier curves
-	// by line segments for numerical stability. If available, a better class
-	// should be used. However, it is important that the used class knows which
-	// areas are covered and does not rely on external information about the fill
-	// rule to use.
-	QPainterPath m_currentClipPath;
-	QStack<QPainterPath> m_clipPaths;
+	bool m_pathIsClosed { false };
+	QVector<double> m_dashValues;
+	double m_dashOffset { 0.0 };
+	QString m_coords;
+
 	// Collect the paths of character glyphs for clipping of a whole text group.
 	QPainterPath  m_clipTextPath;
 
 	QString m_currentMask;
 	QPointF m_currentMaskPosition;
-	Selection* tmpSel { nullptr };
+	Selection* m_tmpSel { nullptr };
 	QStringList *m_importedColors;
 	QTransform m_ctm;
 	struct F3Entry
@@ -368,15 +409,15 @@ private:
 		QString ocgName;
 	};
 	QStack<mContent> m_mcStack;
-	int inPattern {0};
-	int layerNum {1};
-	int currentLayer { 0 };
-	bool firstLayer {true};
-	int importerFlags;
-	int updateGUICounter {0};
-	XRef *xref {nullptr};		// xref table for current document
-	PDFDoc *pdfDoc {nullptr};
-	Catalog *catalog {nullptr};
+	int m_inPattern {0};
+	int m_layerNum {1};
+	int m_currentLayer { 0 };
+	bool m_firstLayer {true};
+	int m_importerFlags;
+	int m_updateGUICounter {0};
+	XRef *m_xref {nullptr};		// xref table for current document
+	PDFDoc *m_pdfDoc {nullptr};
+	Catalog *m_catalog {nullptr};
 	SplashFontEngine *m_fontEngine {nullptr};
 	SplashFont *m_font {nullptr};
 #if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(21, 4, 0)
