@@ -4,6 +4,9 @@ to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
+
+#include <QQueue>
+
 #include "cmdmani.h"
 #include "cmdutil.h"
 #include "scribuscore.h"
@@ -70,7 +73,7 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 	// Now restore the selection.
 	currentView->deselectItems();
 	if (hadOrigSelection)
-		*currentDoc->m_Selection=tempSelection;
+		*currentDoc->m_Selection = tempSelection;
 
 	Py_RETURN_NONE;
 }
@@ -114,7 +117,7 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 	// Now restore the selection.
 	currentView->deselectItems();
 	if (hadOrigSelection)
-		*currentDoc->m_Selection=tempSelection;
+		*currentDoc->m_Selection = tempSelection;
 
 	Py_RETURN_NONE;
 }
@@ -157,7 +160,7 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 	// Now restore the selection.
 	currentView->deselectItems();
 	if (hadOrigSelection)
-		*currentDoc->m_Selection=tempSelection;
+		*currentDoc->m_Selection = tempSelection;
 
 	Py_RETURN_NONE;
 }
@@ -226,7 +229,7 @@ PyObject *scribus_moveobjectrel(PyObject* /* self */, PyObject* args)
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
-	if (item==nullptr)
+	if (item == nullptr)
 		return nullptr;
 
 	// Grab the old selection - but use it only where is there any
@@ -248,13 +251,14 @@ PyObject *scribus_moveobjectrel(PyObject* /* self */, PyObject* args)
 		currentDoc->moveGroup(ValueToPoint(x), ValueToPoint(y));
 		currentView->endGroupTransaction();
 	}
-	else {
+	else
+	{
 		currentDoc->moveItem(ValueToPoint(x), ValueToPoint(y), item);
-		}
+	}
 	// Now restore the selection.
 	currentView->deselectItems();
 	if (hadOrigSelection)
-		*currentDoc->m_Selection=tempSelection;
+		*currentDoc->m_Selection = tempSelection;
 	Py_RETURN_NONE;
 }
 
@@ -295,7 +299,7 @@ PyObject *scribus_moveobjectabs(PyObject* /* self */, PyObject* args)
 	// Now restore the selection.
 	currentView->deselectItems();
 	if (hadOrigSelection)
-		*currentDoc->m_Selection=tempSelection;
+		*currentDoc->m_Selection = tempSelection;
 
 	Py_RETURN_NONE;
 }
@@ -315,18 +319,39 @@ PyObject *scribus_rotateobjectrel(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-PyObject *scribus_rotateobjectabs(PyObject* /* self */, PyObject* args)
+PyObject *scribus_setrotation(PyObject* /* self */, PyObject* args, PyObject* kw)
 {
-	char *Name = const_cast<char*>("");
-	double x;
-	if (!PyArg_ParseTuple(args, "d|es", &x, "utf-8", &Name))
+	double rotation;
+	char* name = const_cast<char*>("");
+	int basepoint = 0;
+	char *kwargs[] = {
+					  const_cast<char *>("rotation"),
+					  const_cast<char *>("name"),
+					  const_cast<char *>("basepoint"),
+					  nullptr};
+	if (!PyArg_ParseTupleAndKeywords(args, kw, "d|esi", kwargs, &rotation, "utf-8", &name, &basepoint))
 		return nullptr;
+
 	if (!checkHaveDocument())
 		return nullptr;
-	PageItem *item = GetUniqueItem(QString::fromUtf8(Name));
+	PageItem *item = GetUniqueItem(QString::fromUtf8(name));
 	if (item == nullptr)
 		return nullptr;
-	ScCore->primaryMainWindow()->doc->rotateItem(x * -1.0, item);
+
+	int oldBasePoint = 0;
+	if (basepoint != 0)
+	{
+		oldBasePoint = ScCore->primaryMainWindow()->doc->rotationMode();
+		ScCore->primaryMainWindow()->doc->setRotationMode(basepoint);
+	}
+
+	ScCore->primaryMainWindow()->doc->rotateItem(rotation * -1.0, item);
+
+	if (basepoint != 0)
+	{
+		ScCore->primaryMainWindow()->doc->setRotationMode(oldBasePoint);
+	}
+
 	Py_RETURN_NONE;
 }
 
@@ -388,13 +413,13 @@ PyObject *scribus_groupobjects(PyObject* /* self */, PyObject* args)
 	{
 		// We can't very well group only one item
 		PyErr_SetString(NoValidObjectError, QObject::tr("Cannot group less than two items", "python error").toLocal8Bit().constData());
-		finalSelection=nullptr;
+		finalSelection = nullptr;
 		delete tempSelection;
 		return nullptr;
 	}
 
 	const PageItem* group = ScCore->primaryMainWindow()->doc->itemSelection_GroupObjects(false, false, finalSelection);
-	finalSelection=nullptr;
+	finalSelection = nullptr;
 	delete tempSelection;
 	
 	return (group ? PyUnicode_FromString(group->itemName().toUtf8()) : nullptr);
@@ -450,6 +475,52 @@ PyObject *scribus_scalegroup(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
+PyObject *scribus_getGroupItems(PyObject * /*self*/, PyObject* args, PyObject* kw)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	char *name = const_cast<char*>("");
+	unsigned int recursive = 0;
+	unsigned int type = 0;
+	char* kwargs[] = {const_cast<char*>("name"), const_cast<char*>("recursive"), const_cast<char*>("type"), nullptr};
+	if (!PyArg_ParseTupleAndKeywords(args, kw, "|espi", kwargs, "utf-8", &name, &recursive, &type))
+		return nullptr;
+
+	PageItem *pageItem = GetUniqueItem(QString::fromUtf8(name));
+	if (pageItem == nullptr)
+		return nullptr;
+
+	if (!pageItem->isGroup())
+		return nullptr;
+
+	auto items = PyList_New(0);
+
+	QQueue<PageItem*> queue;
+	queue.enqueue(pageItem);
+
+	while (!queue.isEmpty())
+	{
+		const auto pageItem = queue.dequeue();
+		for (auto groupItem: pageItem->groupItemList)
+		{
+			if (type == 0 || groupItem->itemType() == type)
+			{
+				auto itemObj = Py_BuildValue("(sii)",
+					groupItem->itemName().toUtf8().constData(),
+					groupItem->itemType(),
+					groupItem->uniqueNr
+				);
+				PyList_Append(items, itemObj);
+			}
+			if (recursive && groupItem->isGroup())
+				queue.enqueue(groupItem);
+		}
+	}
+
+	return items;
+}
+
 PyObject *scribus_getselectedobject(PyObject* /* self */, PyObject* args)
 {
 	int i = 0;
@@ -647,6 +718,56 @@ PyObject *scribus_combinepolygons(PyObject * /* self */)
 	Py_RETURN_NONE;
 }
 
+PyObject *scribus_seteditmode(PyObject * /* self */)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
+
+	if (currentDoc->m_Selection->count() < 1)
+	{
+		PyErr_SetString(NoValidObjectError, QString("No item selected.").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	auto currItem = currentDoc->m_Selection->itemAt(0);
+	if (!currItem->isTextFrame() && !currItem->isImageFrame())
+	{
+		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	ScCore->primaryMainWindow()->view->requestMode(modeEdit);
+
+	Py_RETURN_NONE;
+}
+
+PyObject *scribus_setnormalmode(PyObject * /* self */)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
+
+	if (currentDoc->m_Selection->count() < 1)
+	{
+		PyErr_SetString(NoValidObjectError, QString("No item selected.").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	auto currItem = currentDoc->m_Selection->itemAt(0);
+	if (!currItem->isTextFrame() && !currItem->isImageFrame())
+	{
+		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	ScCore->primaryMainWindow()->view->requestMode(modeNormal);
+
+	Py_RETURN_NONE;
+}
+
 /*! HACK: this removes "warning: 'blah' defined but not used" compiler warnings
 with header files structure untouched (docstrings are kept near declarations)
 PV */
@@ -656,6 +777,7 @@ void cmdmanidocwarnings()
 	s << scribus_combinepolygons__doc__
 	  << scribus_deselectall__doc__
 	  << scribus_flipobject__doc__
+	  << scribus_getGroupItems__doc__
 	  << scribus_getselectedobject__doc__
 	  << scribus_groupobjects__doc__
 	  << scribus_islocked__doc__
@@ -669,10 +791,13 @@ void cmdmanidocwarnings()
 	  << scribus_scaleimage__doc__
 	  << scribus_selectioncount__doc__
 	  << scribus_selectobject__doc__
+	  << scribus_seteditmode__doc__
 	  << scribus_setimagebrightness__doc__
 	  << scribus_setimagegrayscale__doc__
 	  << scribus_setimageoffset__doc__
 	  << scribus_setimagescale__doc__
+	  << scribus_setnormalmode__doc__
+	  << scribus_setrotation__doc__
 	  << scribus_setscaleframetoimage__doc__
 	  << scribus_setscaleimagetoframe__doc__
 	  << scribus_sizeobject__doc__ 
