@@ -11,6 +11,7 @@ for which a new license (GPL+exception) is in place.
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
+#include "selection.h"
 
 #include <QApplication>
 
@@ -21,6 +22,15 @@ PyObject *scribus_currentpage(PyObject* /* self */)
 	return PyLong_FromLong(static_cast<long>(ScCore->primaryMainWindow()->doc->currentPageNumber() + 1));
 }
 
+
+PyObject *scribus_currentpagenumberforsection(PyObject* /* self */)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+	int i = ScCore->primaryMainWindow()->doc->currentPageNumber();
+	return PyUnicode_FromString(ScCore->primaryMainWindow()->doc->getSectionPageNumberForPageIndex(i).toUtf8());
+}
+
 PyObject *scribus_redraw(PyObject* /* self */)
 {
 	if (!checkHaveDocument())
@@ -238,7 +248,7 @@ PyObject *scribus_getpageitems(PyObject* /* self */)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 
 	if (currentDoc->Items->count() == 0)
-		return Py_BuildValue((char*)"[]");
+		return Py_BuildValue("[]");
 	uint counter = 0;
 	int pageNr = currentDoc->currentPageNumber();
 	for (int lam2 = 0; lam2 < currentDoc->Items->count(); ++lam2)
@@ -253,7 +263,7 @@ PyObject *scribus_getpageitems(PyObject* /* self */)
 	{
 		if (pageNr == currentDoc->Items->at(i)->OwnPage)
 		{
-			row = Py_BuildValue((char*)"(sii)",
+			row = Py_BuildValue("(sii)",
 			                    currentDoc->Items->at(i)->itemName().toUtf8().constData(),
 			                    currentDoc->Items->at(i)->itemType(),
 								currentDoc->Items->at(i)->uniqueNr
@@ -272,7 +282,7 @@ PyObject *scribus_getHguides(PyObject* /* self */)
 	Guides g = ScCore->primaryMainWindow()->doc->currentPage()->guides.horizontals(GuideManagerCore::Standard);
 	int n = g.count();//ScCore->primaryMainWindow()->doc->currentPage->YGuides.count();
 	if (n == 0)
-		return Py_BuildValue((char*)"[]");
+		return Py_BuildValue("[]");
 	int i;
 	double tmp;
 	PyObject *l, *guide;
@@ -324,7 +334,7 @@ PyObject *scribus_getVguides(PyObject* /* self */)
 	Guides g = ScCore->primaryMainWindow()->doc->currentPage()->guides.verticals(GuideManagerCore::Standard);
 	int n = g.count();//ScCore->primaryMainWindow()->doc->currentPage->XGuides.count();
 	if (n == 0)
-		return Py_BuildValue((char*)"[]");
+		return Py_BuildValue("[]");
 	int i;
 	double tmp;
 	PyObject *l, *guide;
@@ -369,6 +379,176 @@ PyObject *scribus_setVguides(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
+PyObject *scribus_getColumnGuides(PyObject* /* self */)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+	auto guides = PyDict_New();
+
+	auto page = ScCore->primaryMainWindow()->doc->currentPage();
+
+	{
+		const char keyString[] = "number";
+		PyObject *key = PyUnicode_FromString(keyString);
+		PyDict_SetItem(guides, key, PyLong_FromLong((long) page->guides.verticalAutoCount()));
+	}
+	{
+		const char keyString[] = "gap";
+		PyObject *key = PyUnicode_FromString(keyString);
+		PyDict_SetItem(guides, key, Py_BuildValue("d", PointToValue(page->guides.verticalAutoGap())));
+	}
+	{
+		const char keyString[] = "refer_to";
+		PyObject *key = PyUnicode_FromString(keyString);
+		PyDict_SetItem(guides, key, PyLong_FromLong((long) page->guides.verticalAutoRefer()));
+	}
+	{
+		auto rowsList = PyList_New(0);
+		for (auto column: page->guides.getAutoVerticals(page)) // QList<double> Guides
+		{
+			PyList_Append(rowsList, Py_BuildValue("d", PointToValue(column)));
+		}
+		const char keyString[] = "guides";
+		PyObject *key = PyUnicode_FromString(keyString);
+		PyDict_SetItem(guides, key, rowsList);
+	}
+
+	return guides;
+}
+
+PyObject *scribus_getRowGuides(PyObject* /* self */)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+	auto guides = PyDict_New();
+
+	auto page = ScCore->primaryMainWindow()->doc->currentPage();
+
+	{
+		const char keyString[] = "number";
+		PyObject *key = PyUnicode_FromString(keyString);
+		PyDict_SetItem(guides, key, PyLong_FromLong((long) page->guides.horizontalAutoCount()));
+	}
+	{
+		const char keyString[] = "gap";
+		PyObject *key = PyUnicode_FromString(keyString);
+		PyDict_SetItem(guides, key, Py_BuildValue("d", PointToValue(page->guides.horizontalAutoGap())));
+	}
+	{
+		const char keyString[] = "refer_to";
+		PyObject *key = PyUnicode_FromString(keyString);
+		PyDict_SetItem(guides, key, PyLong_FromLong((long) page->guides.horizontalAutoRefer()));
+	}
+	{
+		auto rowsList = PyList_New(0);
+		for (auto row: page->guides.getAutoHorizontals(page)) // QList<double> Guides
+		{
+			PyList_Append(rowsList, Py_BuildValue("d", PointToValue(row)));
+		}
+		const char keyString[] = "guides";
+		PyObject *key = PyUnicode_FromString(keyString);
+		PyDict_SetItem(guides, key, rowsList);
+	}
+	return guides;
+}
+
+PyObject *scribus_setColumnGuides(PyObject* /* self */, PyObject* args, PyObject* kw)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	int number;
+	double gap = 0.0;
+	int referTo = 0;
+	char* kwargs[] = {const_cast<char*>("number"), const_cast<char*>("gap"), const_cast<char*>("refer_to"), nullptr};
+	if (!PyArg_ParseTupleAndKeywords(args, kw, "i|di", kwargs, &number, &gap, &referTo))
+		return nullptr;
+
+	auto doc = ScCore->primaryMainWindow()->doc;
+
+	if (referTo < 0 || referTo > 2)
+	{
+		QString message = QObject::tr("refer_to=0|1|2.","python error");
+		PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+		return nullptr;
+	}
+	else if (referTo == 2)
+	{
+		// refertTo a selection is only active, when there is a selection in the document
+		if (doc->m_Selection->isEmpty())
+		{
+			QString message = QObject::tr("setColumnGuides() with refer_to=2 needs a selection.","python error");
+			PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+			return nullptr;
+		}
+		doc->currentPage()->guides.resetSelectionForPage(doc->currentPage());
+	}
+
+
+	// If there are no guides, reset the values for the gap and for the reference
+	if (number == 0)
+	{
+		doc->currentPage()->guides.setVerticalAutoGap(0);
+		doc->currentPage()->guides.setVerticalAutoRefer(0);
+		doc->currentPage()->guides.setVerticalAutoCount(0);
+		Py_RETURN_NONE;
+	}
+
+	doc->currentPage()->guides.setVerticalAutoGap(ValueToPoint(gap));
+	doc->currentPage()->guides.setVerticalAutoRefer(referTo);
+	doc->currentPage()->guides.setVerticalAutoCount(number);
+
+	Py_RETURN_NONE;
+}
+
+PyObject *scribus_setRowGuides(PyObject* /* self */, PyObject* args, PyObject* kw)
+{
+	if (!checkHaveDocument())
+		return nullptr;
+
+	int number;
+	double gap = 0.0;
+	int referTo = 0;
+	char* kwargs[] = {const_cast<char*>("number"), const_cast<char*>("gap"), const_cast<char*>("refer_to"), nullptr};
+	if (!PyArg_ParseTupleAndKeywords(args, kw, "i|di", kwargs, &number, &gap, &referTo))
+		return nullptr;
+
+	auto doc = ScCore->primaryMainWindow()->doc;
+
+	if (referTo < 0 || referTo > 2)
+	{
+		QString message = QObject::tr("refer_to=0|1|2.","python error");
+		PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+		return nullptr;
+	}
+	else if (referTo == 2)
+	{
+		if (doc->m_Selection->isEmpty())
+		{
+			// refertTo a selection is only active, when there is a selection in the document
+			QString message = QObject::tr("setRowGuides() with refer_to=2 needs a selection.","python error");
+			PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+			return nullptr;
+		}
+		doc->currentPage()->guides.resetSelectionForPage(doc->currentPage());
+	}
+
+	doc->currentPage()->guides.setHorizontalAutoCount(number);
+
+	// If there are no guides, reset the values for the gap and for the reference
+	if (number == 0)
+	{
+		doc->currentPage()->guides.setHorizontalAutoGap(0);
+		doc->currentPage()->guides.setHorizontalAutoRefer(0);
+		Py_RETURN_NONE;
+	}
+
+	doc->currentPage()->guides.setHorizontalAutoGap(ValueToPoint(gap));
+	doc->currentPage()->guides.setHorizontalAutoRefer(referTo);
+
+	Py_RETURN_NONE;
+}
+
 PyObject *scribus_getpagemargins(PyObject* /* self */)
 {
 	PyObject *margins = nullptr;
@@ -471,7 +651,8 @@ PyObject *scribus_importpage(PyObject* /* self */, PyObject* args)
 	QString fromDoc = QString(doc);
 	bool createPage = (createPageI != 0);
 
-	int startPage=0, nrToImport=pageNs.size();
+	int startPage = 0;
+	int nrToImport = pageNs.size();
 	bool doIt = true;
 
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
@@ -497,7 +678,7 @@ PyObject *scribus_importpage(PyObject* /* self */, PyObject* args)
 		startPage = currentDoc->currentPage()->pageNr() + 1;
 		if (nrToImport > (currentDoc->DocPages.count() - currentDoc->currentPage()->pageNr()))
 		{
-			int tmp=nrToImport - (currentDoc->DocPages.count() - currentDoc->currentPage()->pageNr());
+			int tmp = nrToImport - (currentDoc->DocPages.count() - currentDoc->currentPage()->pageNr());
 			import_addpages(tmp, currentDoc->DocPages.count());
 		}
 	}
@@ -528,20 +709,24 @@ void cmdpagedocwarnings()
 	QStringList s;
 	s << scribus_currentpage__doc__
 	  << scribus_deletepage__doc__
+	  << scribus_getColumnGuides__doc__
 	  << scribus_getHguides__doc__
-	  << scribus_getVguides__doc__
 	  << scribus_getpageitems__doc__
 	  << scribus_getpagemargins__doc__
+	  << scribus_getpagenmargins__doc__ 
 	  << scribus_getpagensize__doc__ 
+	  << scribus_getpagesize__doc__
 	  << scribus_getpagetype__doc__
+	  << scribus_getRowGuides__doc__
+	  << scribus_getVguides__doc__
 	  << scribus_gotopage__doc__
 	  << scribus_importpage__doc__
 	  << scribus_newpage__doc__
 	  << scribus_pagecount__doc__
-	  << scribus_getpagesize__doc__
-	  << scribus_getpagenmargins__doc__ 
 	  << scribus_redraw__doc__
 	  << scribus_savepageeps__doc__           
+	  << scribus_setColumnGuides__doc__
 	  << scribus_setHguides__doc__
+	  << scribus_setRowGuides__doc__
 	  << scribus_setVguides__doc__;
 }
