@@ -28,7 +28,7 @@ PyObject *scribus_gettablerows(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get table row count of non-table item.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	return PyInt_FromLong(static_cast<long>(table->rows()));
+	return PyLong_FromLong(static_cast<long>(table->rows()));
 }
 
 PyObject *scribus_gettablecolumns(PyObject* /* self */, PyObject* args)
@@ -48,7 +48,7 @@ PyObject *scribus_gettablecolumns(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get table column count of non-table item.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	return PyInt_FromLong(static_cast<long>(table->columns()));
+	return PyLong_FromLong(static_cast<long>(table->columns()));
 }
 
 PyObject *scribus_inserttablerows(PyObject* /* self */, PyObject* args)
@@ -338,7 +338,7 @@ PyObject *scribus_gettablestyle(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get table style on a non-table item.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	return PyString_FromString(table->styleName().toUtf8());
+	return PyUnicode_FromString(table->styleName().toUtf8());
 }
 
 PyObject *scribus_settablestyle(PyObject* /* self */, PyObject* args)
@@ -378,7 +378,7 @@ PyObject *scribus_gettablefillcolor(PyObject* /* self */, PyObject* args)
 		PyErr_SetString(WrongFrameTypeError, QObject::tr("Cannot get table fill color on a non-table item.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
-	return PyString_FromString(table->fillColor().toUtf8());
+	return PyUnicode_FromString(table->fillColor().toUtf8());
 }
 
 PyObject *scribus_settablefillcolor(PyObject* /* self */, PyObject* args)
@@ -520,14 +520,23 @@ PV */
 void cmdtabledocwarnings()
 {
 	QStringList s;
-	s << scribus_gettablecolumns__doc__ << scribus_gettablerows__doc__
-	  << scribus_inserttablerows__doc__ << scribus_removetablerows__doc__
-	  << scribus_inserttablecolumns__doc__ << scribus_removetablecolumns__doc__
-	  << scribus_gettablerowheight__doc__ << scribus_gettablecolumnwidth__doc__
-	  << scribus_resizetablerow__doc__ << scribus_resizetablecolumn__doc__
-	  << scribus_mergetablecells__doc__ << scribus_settablestyle__doc__
-	  << scribus_gettablestyle__doc__ << scribus_settablefillcolor__doc__
-	  << scribus_gettablefillcolor__doc__ << scribus_settableleftborder__doc__
-	  << scribus_settablerightborder__doc__ << scribus_settabletopborder__doc__
-	  << scribus_settablebottomborder__doc__;
+	s << scribus_gettablecolumns__doc__
+	  << scribus_gettablecolumnwidth__doc__
+	  << scribus_gettablefillcolor__doc__
+	  << scribus_gettablerowheight__doc__
+	  << scribus_gettablerows__doc__
+	  << scribus_gettablestyle__doc__
+	  << scribus_inserttablecolumns__doc__ 
+	  << scribus_inserttablerows__doc__
+	  << scribus_mergetablecells__doc__
+	  << scribus_removetablerows__doc__
+	  << scribus_removetablecolumns__doc__
+	  << scribus_resizetablecolumn__doc__
+	  << scribus_resizetablerow__doc__ 
+	  << scribus_settablebottomborder__doc__
+	  << scribus_settablefillcolor__doc__
+	  << scribus_settableleftborder__doc__
+	  << scribus_settablerightborder__doc__
+	  << scribus_settablestyle__doc__
+	  << scribus_settabletopborder__doc__;
 }
