@@ -154,9 +154,9 @@ void LensItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
 	QPainterPath p;
 	p.addEllipse(rect());
 	if ((p.contains(event->pos())) && (isSelected()))
-		qApp->changeOverrideCursor(QCursor(Qt::SizeAllCursor));
+		QApplication::changeOverrideCursor(QCursor(Qt::SizeAllCursor));
 	else
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 }
 
 void LensItem::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
@@ -166,30 +166,30 @@ void LensItem::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
 	if (isSelected())
 	{
 		if (p.contains(event->pos()))
-			qApp->changeOverrideCursor(QCursor(Qt::SizeAllCursor));
+			QApplication::changeOverrideCursor(QCursor(Qt::SizeAllCursor));
 		else
 		{
 			QRectF br = boundingRect();
 			double siz = 6.0 / scaling;
 			if (QRectF(br.x(), br.y(), siz, siz).contains(event->pos()))
-				qApp->changeOverrideCursor(QCursor(Qt::SizeFDiagCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::SizeFDiagCursor));
 			else if (QRectF(br.x() + br.width(), br.y(), -siz, siz).contains(event->pos()))
-				qApp->changeOverrideCursor(QCursor(Qt::SizeBDiagCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::SizeBDiagCursor));
 			else if (QRectF(br.x() + br.width(), br.y() + br.height(), -siz, -siz).contains(event->pos()))
-				qApp->changeOverrideCursor(QCursor(Qt::SizeFDiagCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::SizeFDiagCursor));
 			else if (QRectF(br.x(), br.y() + br.height(), siz, -siz).contains(event->pos()))
-				qApp->changeOverrideCursor(QCursor(Qt::SizeBDiagCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::SizeBDiagCursor));
 			else
-				qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+				QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 		}
 	}
 	else
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 }
 
 void LensItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *)
 {
-	qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+	QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 }
 
 void LensItem::setStrength(double s)
@@ -258,7 +258,6 @@ LensDialog::LensDialog(QWidget* parent, ScribusDoc *doc) : QDialog(parent)
 	addItemsToScene(doc->m_Selection, doc, nullptr, nullptr);
 	previewWidget->setRenderHint(QPainter::Antialiasing);
 	previewWidget->setScene(&scene);
-	isFirst = true;
 	addLens();
 	connect(spinXPos, SIGNAL(valueChanged(double)), this, SLOT(setNewLensX(double)));
 	connect(spinYPos, SIGNAL(valueChanged(double)), this, SLOT(setNewLensY(double)));
@@ -355,13 +354,12 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 				}
 				else if ((currItem->GrType == Gradient_Pattern) && (!currItem->pattern().isEmpty()) && (doc->docPatterns.contains(currItem->pattern())))
 				{
-					double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY;
-					currItem->patternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY);
+					const ScPatternTransform& patternTrans = currItem->patternTransform();
 					QTransform qmatrix;
-					qmatrix.translate(patternOffsetX, patternOffsetY);
-					qmatrix.rotate(patternRotation);
-					qmatrix.shear(patternSkewX, patternSkewY);
-					qmatrix.scale(patternScaleX / 100.0, patternScaleY / 100.0);
+					qmatrix.translate(patternTrans.offsetX, patternTrans.offsetY);
+					qmatrix.rotate(patternTrans.rotation);
+					qmatrix.shear(patternTrans.skewX, patternTrans.skewY);
+					qmatrix.scale(patternTrans.scaleX, patternTrans.scaleY);
 					bool mirrorX, mirrorY;
 					currItem->patternFlip(mirrorX, mirrorY);
 					if (mirrorX)
@@ -369,7 +367,7 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 					if (mirrorY)
 						qmatrix.scale(1, -1);
 					QImage pat = *doc->docPatterns[currItem->pattern()].getPattern();
-					QBrush brush = QBrush(pat);
+					QBrush brush(pat);
 					brush.setTransform(qmatrix);
 					pItem->setBrush(brush);
 				}
@@ -387,14 +385,13 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 		{
 			if ((!currItem->strokePattern().isEmpty()) && (doc->docPatterns.contains(currItem->strokePattern())))
 			{
-				double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternSpace;
-				currItem->strokePatternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternSpace);
+				const ScStrokePatternTransform& strokePatTrans = currItem->strokePatternTransform();
 				QTransform qmatrix;
 				qmatrix.translate(-currItem->lineWidth() / 2.0, -currItem->lineWidth() / 2.0);
-				qmatrix.translate(patternOffsetX, patternOffsetY);
-				qmatrix.rotate(patternRotation);
-				qmatrix.shear(patternSkewX, patternSkewY);
-				qmatrix.scale(patternScaleX / 100.0, patternScaleY / 100.0);
+				qmatrix.translate(strokePatTrans.offsetX, strokePatTrans.offsetY);
+				qmatrix.rotate(strokePatTrans.rotation);
+				qmatrix.shear(strokePatTrans.skewX, strokePatTrans.skewY);
+				qmatrix.scale(strokePatTrans.scaleX, strokePatTrans.scaleY);
 				bool mirrorX, mirrorY;
 				currItem->strokePatternFlip(mirrorX, mirrorY);
 				if (mirrorX)
@@ -402,7 +399,7 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 				if (mirrorY)
 					qmatrix.scale(1, -1);
 				QImage pat = *doc->docPatterns[currItem->strokePattern()].getPattern();
-				QBrush brush = QBrush(pat);
+				QBrush brush(pat);
 				brush.setTransform(qmatrix);
 				pItem->setPen(QPen(brush, currItem->lineWidth(), currItem->lineStyle(), currItem->lineEnd(), currItem->lineJoin()));
 			}
