@@ -95,8 +95,8 @@ struct WindowPrefs
 {
 	int xPosition {0};
 	int yPosition {0};
-	int width {640};
-	int height {480};
+	int width {800};
+	int height {600};
 	bool visible {true};
 	bool docked {false};
 	bool maximized {false};
@@ -303,7 +303,7 @@ struct HyphenatorPrefs
 struct FontPrefs
 {
 	SCFonts AvailFonts; //! Fonts that Scribus has available to it, or the current document has available to use
-	bool askBeforeSubstitute; //! Request that the user confirms a font substituion or not
+	bool askBeforeSubstitute; //! Request that the user confirms a font substitution or not
 	QMap<QString,QString> GFontSub;
 };
 
@@ -467,6 +467,11 @@ struct ImageCachePrefs
 	int compressionLevel; //!< Cache image compression level (see QImage)
 };
 
+struct ExperimentalFeaturePrefs
+{
+	bool notesEnabled; //!< Enable Notes
+};
+
 struct ApplicationPrefs
 {
 	ColorPrefs colorPrefs;
@@ -497,6 +502,7 @@ struct ApplicationPrefs
 	TypoPrefs typoPrefs;
 	UIPrefs uiPrefs;
 	VerifierPrefs verifierPrefs;
+	ExperimentalFeaturePrefs experimentalFeaturePrefs;
 
 	QList<ArrowDesc> arrowStyles;
 	QHash<QString, VGradient> defaultGradients;
