@@ -88,25 +88,27 @@ SCFonts::SCFonts()
 void SCFonts::updateFontMap()
 {
 	fontMap.clear();
+
 	SCFontsIterator it( *this );
 	for ( ; it.hasNext(); it.next())
 	{
-		if (it.current().usable())
+		ScFace& currentFace = it.current();
+		if (!currentFace.usable())
+			continue;
+
+		if (fontMap.contains(currentFace.family()))
 		{
-			if (fontMap.contains(it.current().family()))
+			if (!fontMap[currentFace.family()].contains(currentFace.style()))
 			{
-				if (!fontMap[it.current().family()].contains(it.current().style()))
-				{
-					fontMap[it.current().family()].append(it.current().style());
-				}
-			}
-			else
-			{
-				QStringList styles;
-				styles.append(it.current().style());
-				fontMap.insert(it.current().family(), styles);
+				fontMap[currentFace.family()].append(currentFace.style());
 			}
 		}
+		else
+		{
+			QStringList styles;
+			styles.append(currentFace.style());
+			fontMap.insert(currentFace.family(), styles);
+		}
 	}
 }
 
@@ -194,7 +196,7 @@ void SCFonts::addScalableFonts(const QString &path, const QString& DocName)
 			{
 				addScalableFont(pathfile, library, DocName);
 			}
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 			else if (ext.isEmpty() && DocName.isEmpty())
 			{
 				bool error = addScalableFont(pathfile, library, DocName);
@@ -968,8 +970,7 @@ const ScFace& SCFonts::findFont(const QString& fontFamily, const QString& fontSt
 QMap<QString,QString> SCFonts::getSubstitutions(const QList<QString>& skip) const
 {
 	QMap<QString,QString> result;
-	QMap<QString,ScFace>::ConstIterator it;
-	for (it = begin(); it != end(); ++it)
+	for (auto it = begin(); it != end(); ++it)
 	{
 		if (it.value().isReplacement() && !skip.contains(it.key()))
 			result[it.key()] = it.value().replacementName();
@@ -980,8 +981,7 @@ QMap<QString,QString> SCFonts::getSubstitutions(const QList<QString>& skip) cons
 
 void SCFonts::setSubstitutions(const QMap<QString,QString>& substitutes, ScribusDoc* doc)
 {
-	QMap<QString,QString>::ConstIterator it;
-	for (it = substitutes.begin(); it != substitutes.end(); ++it)
+	for (auto it = substitutes.begin(); it != substitutes.end(); ++it)
 	{
 		if (it.key() == it.value())
 			continue;
@@ -1296,7 +1296,7 @@ void SCFonts::writeFontCache(const QString& pf)
 
 void SCFonts::getFonts(const QString& pf, bool showFontInfo)
 {
-	m_showFontInfo=showFontInfo;
+	m_showFontInfo = showFontInfo;
 	m_fontPaths.clear();
 	readFontCache(pf);
 	ScCore->setSplashStatus( QObject::tr("Searching for Fonts") );
