@@ -42,7 +42,7 @@ class SCRIBUS_API SCFonts : public QMap<QString,ScFace>
 		~SCFonts() = default;
 
 		void updateFontMap();
-		void getFonts(const QString& pf, bool showFontInfo=false);
+		void getFonts(const QString& pf, bool showFontInfo = false);
 		ScFace loadScalableFont(const QString &filename);
 		void addScalableFonts(const QString& path, const QString& DocName = "");
 
@@ -95,7 +95,7 @@ struct SCFontsIterator
 	ScFace& current()          { return *m_it; }
 	QString currentKey() const { return m_it.key(); }
 	bool hasNext()       const { return m_it != m_end_it; }
-	ScFace& next()             { ++m_it; return current(); }
+	void next()                { ++m_it; }
 
 private:
 	QMap<QString, ScFace>::Iterator m_it;
