@@ -79,35 +79,43 @@ void ScPageOutput::drawPage(ScPage* page, ScPainterExBase* painter)
 	int clipy = static_cast<int>(page->yOffset());
 	int clipw = qRound(page->width());
 	int cliph = qRound(page->height());
-	ScLayer layer;
-	layer.isViewable = false;
-	uint layerCount = m_doc->layerCount();
-	for (uint la = 0; la < layerCount; ++la)
+
+	int layerCount = m_doc->layerCount();
+	for (int i = 0; i < layerCount; ++i)
 	{
-		m_doc->Layers.levelToLayer(layer, la);
-		drawMasterItems(painter, page, layer, QRect(clipx, clipy, clipw, cliph));
-		drawPageItems(painter, page, layer, QRect(clipx, clipy, clipw, cliph));
+		const ScLayer* pLayer = m_doc->Layers.layerByLevel(i);
+		if (!pLayer)
+			continue;
+
+		if ((layerCount > 1) && ((pLayer->blendMode != 0) || (pLayer->transparency != 1.0)))
+			painter->beginLayer(pLayer->transparency, pLayer->blendMode);
+
+		drawMasterItems(painter, page, *pLayer, QRect(clipx, clipy, clipw, cliph));
+		drawPageItems(painter, page, *pLayer, QRect(clipx, clipy, clipw, cliph));
+
+		if ((layerCount > 1) && ((pLayer->blendMode != 0) || (pLayer->transparency != 1.0)))
+			painter->endLayer();
 	}
 	drawMarks(page, painter, m_marksOptions);
 }
 
-void ScPageOutput::drawMasterItems(ScPainterExBase *painter, ScPage *page, ScLayer& layer, QRect clip)
+void ScPageOutput::drawMasterItems(ScPainterExBase *painter, ScPage *page, const ScLayer& layer, const QRect& clip)
 {
-	PageItem* currItem;
 	if (page->masterPageNameEmpty())
 		return;
 	if (page->FromMaster.count() <= 0)
 		return;
 	if (!layer.isViewable || !layer.isPrintable)
 		return;
-	ScPage* Mp = m_doc->MasterPages.at(m_doc->MasterNames[page->masterPageName()]);
+
+	ScPage* masterPage = m_doc->MasterPages.at(m_doc->MasterNames[page->masterPageName()]);
 	int pageFromMasterCount = page->FromMaster.count();
 	for (int i = 0; i < pageFromMasterCount; ++i)
 	{
-		currItem = page->FromMaster.at(i);
+		PageItem* currItem = page->FromMaster.at(i);
 		if (currItem->m_layerID != layer.ID)
 			continue;
-		if ((currItem->OwnPage != -1) && (currItem->OwnPage != static_cast<int>(Mp->pageNr())))
+		if ((currItem->OwnPage != -1) && (currItem->OwnPage != masterPage->pageNr()))
 			continue;
 		if (!currItem->printEnabled())
 			continue;
@@ -119,9 +127,9 @@ void ScPageOutput::drawMasterItems(ScPainterExBase *painter, ScPage *page, ScLay
 		currItem->OwnPage = page->pageNr();
 		if (!currItem->ChangedMasterItem)
 		{
-			currItem->moveBy(-Mp->xOffset() + page->xOffset(), -Mp->yOffset() + page->yOffset(), true);
-			currItem->BoundingX = OldBX - Mp->xOffset() + page->xOffset();
-			currItem->BoundingY = OldBY - Mp->yOffset() + page->yOffset();
+			currItem->moveBy(-masterPage->xOffset() + page->xOffset(), -masterPage->yOffset() + page->yOffset(), true);
+			currItem->BoundingX = OldBX - masterPage->xOffset() + page->xOffset();
+			currItem->BoundingY = OldBY - masterPage->yOffset() + page->yOffset();
 		}
 		QRectF oldR(currItem->getBoundingRect().adjusted(0.0, 0.0, 1.0, 1.0));
 		if (clip.intersects(oldR.toRect()))
@@ -136,17 +144,17 @@ void ScPageOutput::drawMasterItems(ScPainterExBase *painter, ScPage *page, ScLay
 	}
 }
 
-void ScPageOutput::drawPageItems(ScPainterExBase *painter, ScPage *page, ScLayer& layer, QRect clip)
+void ScPageOutput::drawPageItems(ScPainterExBase *painter, ScPage *page, const ScLayer& layer, const QRect& clip)
 {
-	PageItem *currItem;
 	if (m_doc->Items->count() <= 0)
 		return;
 	if (!layer.isViewable || !layer.isPrintable)
 		return;
+
 	int currentPageNr = page->pageNr();
 	for (int it = 0; it < m_doc->Items->count(); ++it)
 	{
-		currItem = m_doc->Items->at(it);
+		PageItem* currItem = m_doc->Items->at(it);
 		if (currItem->m_layerID != layer.ID)
 			continue;
 		if (!currItem->printEnabled())
@@ -209,7 +217,19 @@ void ScPageOutput::drawItem_Pre(PageItem* item, ScPainterExBase* painter)
 	painter->setLineWidth(item->lineWidth());
 	if (item->isGroup())
 		return;
-	if (item->GrType == Gradient_Pattern)
+
+	if (item->GrType == Gradient_None)
+	{
+		painter->m_fillGradient = VGradientEx(VGradientEx::linear);
+		if (item->fillColor() != CommonStrings::None)
+		{
+			painter->setBrush(ScColorShade(m_doc->PageColors[item->fillColor()], (int) item->fillShade()));
+			painter->setFillMode(ScPainterExBase::Solid);
+		}
+		else
+			painter->setFillMode(ScPainterExBase::None);
+	}
+	else if (item->GrType == Gradient_Pattern)
 	{
 		QString pat = item->pattern();
 		ScPattern *pattern = m_doc->checkedPattern(pat);
@@ -227,11 +247,10 @@ void ScPageOutput::drawItem_Pre(PageItem* item, ScPainterExBase* painter)
 		else
 		{
 			QTransform patternTransform;
-			double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY;
 			bool   patternMirrorX, patternMirrorY;
-			item->patternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY);
+			const ScPatternTransform& patternTrans = item->patternTransform();
 			item->patternFlip(patternMirrorX, patternMirrorY);
-			painter->setPattern(pattern, patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY, patternMirrorX, patternMirrorY);
+			painter->setPattern(pattern, patternTrans, patternMirrorX, patternMirrorY);
 			painter->setFillMode(ScPainterExBase::Pattern);
 		}
 	}
@@ -249,11 +268,25 @@ void ScPageOutput::drawItem_Pre(PageItem* item, ScPainterExBase* painter)
 		painter->set4ColorGeometry(pG1, pG2, pG3, pG4, item->GrControl1, item->GrControl2, item->GrControl3, item->GrControl4);
 		painter->set4ColorColors(col1, col2, col3, col4);
 	}
-	else if (item->GrType != 0)
+	else if (item->GrType == Gradient_Hatch)
+	{
+		if (item->fillColor() != CommonStrings::None)
+			painter->setBrush(ScColorShade(m_doc->PageColors[item->fillColor()], (int) item->fillShade()));
+		painter->setFillMode(ScPainterExBase::Hatch);
+		bool hatchUseBackground = item->hatchUseBackground;
+		if ((item->hatchBackground == CommonStrings::None) || !m_doc->PageColors.contains(item->hatchBackground))
+			hatchUseBackground = false;
+		ScColorShade hatchBackgroundSh;
+		ScColorShade hatchForegroundSh(m_doc->PageColors[item->hatchForeground], 100.0);
+		if (hatchUseBackground)
+			hatchBackgroundSh = ScColorShade(m_doc->PageColors[item->hatchBackground], 100.0);
+		painter->setHatchParameters(item->hatchType, item->hatchDistance, item->hatchAngle, hatchUseBackground, hatchBackgroundSh, hatchForegroundSh, item->width(), item->height());
+	}
+	else
 	{
 		QString gradientVal = item->gradient();
 		if ((!gradientVal.isEmpty()) && (!m_doc->docGradients.contains(gradientVal)))
-			gradientVal = "";
+			gradientVal.clear();
 		if (!(gradientVal.isEmpty()) && (m_doc->docGradients.contains(gradientVal)))
 			painter->m_fillGradient = VGradientEx(m_doc->docGradients[gradientVal], *m_doc);
 		if ((painter->m_fillGradient.stops() < 2) && (item->GrType < Gradient_4Colors)) // fall back to solid filling if there are not enough colorstops in the gradient.
@@ -268,7 +301,8 @@ void ScPageOutput::drawItem_Pre(PageItem* item, ScPainterExBase* painter)
 		}
 		else
 		{
-			FPoint fpStart(item->GrStartX, item->GrStartY), fpEnd(item->GrEndX, item->GrEndY);
+			FPoint fpStart(item->GrStartX, item->GrStartY);
+			FPoint fpEnd(item->GrEndX, item->GrEndY);
 			FPoint fpFocal(item->GrFocalX, item->GrFocalY);
 			painter->setFillMode(ScPainterExBase::Gradient);
 			painter->m_fillGradient = VGradientEx(item->fill_gradient, *m_doc);
@@ -302,17 +336,7 @@ void ScPageOutput::drawItem_Pre(PageItem* item, ScPainterExBase* painter)
 			}
 		}
 	}
-	else
-	{
-		painter->m_fillGradient = VGradientEx(VGradientEx::linear);
-		if (item->fillColor() != CommonStrings::None)
-		{
-			painter->setBrush(ScColorShade(m_doc->PageColors[item->fillColor()], (int) item->fillShade()));
-			painter->setFillMode(ScPainterExBase::Solid);
-		}
-		else
-			painter->setFillMode(ScPainterExBase::None);
-	}
+
 	if (item->lineColor() != CommonStrings::None)
 	{
 		if ((item->lineWidth() == 0) && !item->asLine())
@@ -321,12 +345,13 @@ void ScPageOutput::drawItem_Pre(PageItem* item, ScPainterExBase* painter)
 		{
 			ScColorShade tmp(m_doc->PageColors[item->lineColor()], (int) item->lineShade());
 			painter->setPen(tmp , item->lineWidth(), item->PLineArt, item->PLineEnd, item->PLineJoin);
-			if (item->DashValues.count() != 0)
+			if (!item->DashValues.isEmpty())
 				painter->setDash(item->DashValues, item->DashOffset);
 		}
 	}
 	else
 		painter->setLineWidth(0);
+
 	painter->setBrushOpacity(1.0 - item->fillTransparency());
 	painter->setPenOpacity(1.0 - item->lineTransparency());
 	painter->setFillRule(item->fillRule);
@@ -342,9 +367,11 @@ void ScPageOutput::drawItem_Pre(PageItem* item, ScPainterExBase* painter)
 		else
 			painter->setMaskMode(3);
 		if ((!gradientMaskVal.isEmpty()) && (!m_doc->docGradients.contains(gradientMaskVal)))
-			gradientMaskVal = "";
+			gradientMaskVal.clear();
 		if (!(gradientMaskVal.isEmpty()) && (m_doc->docGradients.contains(gradientMaskVal)))
 			painter->m_maskGradient = VGradientEx(m_doc->docGradients[gradientMaskVal], *m_doc);
+		else
+			painter->m_maskGradient = VGradientEx(item->mask_gradient, *m_doc);
 		if ((item->GrMask == GradMask_Linear) || (item->GrMask == GradMask_LinearLumAlpha))
 			painter->setGradientMask(VGradientEx::linear, fpMaskStart, fpMaskEnd, fpMaskStart, item->GrMaskScale, item->GrMaskSkew);
 		else
@@ -356,8 +383,7 @@ void ScPageOutput::drawItem_Pre(PageItem* item, ScPainterExBase* painter)
 		ScPattern *patternMask = m_doc->checkedPattern(patternMaskVal);
 		if (patternMask)
 		{
-			painter->setPatternMask(patternMask, item->patternMaskScaleX, item->patternMaskScaleY, item->patternMaskOffsetX, item->patternMaskOffsetY,
-				                    item->patternMaskRotation, item->patternMaskSkewX, item->patternMaskSkewY, item->patternMaskMirrorX, item->patternMaskMirrorY);
+			painter->setPatternMask(patternMask, item->patternMaskTransfrm, item->patternMaskMirrorX, item->patternMaskMirrorY);
 			if (item->GrMask == GradMask_Pattern)
 				painter->setMaskMode(2);
 			else if (item->GrMask == GradMask_PatternLumAlpha)
@@ -412,7 +438,7 @@ void ScPageOutput::drawItem_Post(PageItem* item, ScPainterExBase* painter)
 					}
 					else
 					{
-						painter->setPattern(strokePattern, item->patternStrokeScaleX, item->patternStrokeScaleY, item->patternStrokeOffsetX, item->patternStrokeOffsetY, item->patternStrokeRotation, item->patternStrokeSkewX, item->patternStrokeSkewY, item->patternStrokeMirrorX, item->patternStrokeMirrorY);
+						painter->setPattern(strokePattern, item->patternStrokeTransfrm, item->patternStrokeMirrorX, item->patternStrokeMirrorY);
 						painter->setStrokeMode(ScPainterExBase::Pattern);
 						painter->strokePath();
 					}
@@ -485,83 +511,31 @@ void ScPageOutput::drawItem_Post(PageItem* item, ScPainterExBase* painter)
 	painter->restore();
 }
 
-void ScPageOutput::drawItem_Embedded(PageItem* item, ScPainterExBase *p, QRect clip, const CharStyle& style, PageItem* cembedded)
+void ScPageOutput::drawPattern(PageItem* item, ScPainterExBase* painter, const QRect& clip)
 {
-	if (!cembedded)
-		return;
-	QList<PageItem*> emG;
-	emG.append(cembedded);
-	for (int em = 0; em < emG.count(); ++em)
-	{
-		PageItem* embedded = emG.at(em);
-		p->save();
-		double x = embedded->xPos();
-		double y = embedded->yPos();
-		embedded->setXPos(embedded->gXpos, true);
-		embedded->setYPos((embedded->gHeight * (style.scaleV() / 1000.0)) + embedded->gYpos, true);
-		p->translate((embedded->gXpos * (style.scaleH() / 1000.0)), ( - (embedded->gHeight * (style.scaleV() / 1000.0)) + embedded->gYpos * (style.scaleV() / 1000.0)));
-		if (style.baselineOffset() != 0)
-		{
-			p->translate(0, -embedded->gHeight * (style.baselineOffset() / 1000.0));
-			embedded->setYPos(embedded->yPos() - embedded->gHeight * (style.baselineOffset() / 1000.0));
-		}
-		p->scale(style.scaleH() / 1000.0, style.scaleV() / 1000.0);
-		double pws = embedded->m_lineWidth;
-		drawItem_Pre(embedded, p);
-		switch (embedded->itemType())
-		{
-			case PageItem::ImageFrame:
-			case PageItem::LatexFrame:
-			case PageItem::TextFrame:
-			case PageItem::Polygon:
-			case PageItem::PathText:
-			case PageItem::Symbol:
-			case PageItem::Group:
-			case PageItem::RegularPolygon:
-			case PageItem::Arc:
-				drawItem(embedded, p, clip);
-				break;
-			case PageItem::Line:
-			case PageItem::PolyLine:
-				embedded->m_lineWidth = pws * qMin(style.scaleH() / 1000.0, style.scaleV() / 1000.0);
-				drawItem(embedded, p, clip);
-				break;
-			default:
-				break;
-		}
-		embedded->m_lineWidth = pws * qMin(style.scaleH() / 1000.0, style.scaleV() / 1000.0);
-		drawItem_Post(embedded, p);
-		embedded->setXPos(x, true);
-		embedded->setYPos(y, true);
-		p->restore();
-		embedded->m_lineWidth = pws;
-	}
-}
-
-void ScPageOutput::drawPattern(PageItem* item, ScPainterExBase* painter, QRect clip)
-{
-	double x1, x2, y1, y2;
-	ScPattern& pattern = m_doc->docPatterns[item->pattern()];
-	double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY;
-	item->patternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY);
+	const ScPattern& pattern = m_doc->docPatterns[item->pattern()];
+	const ScPatternTransform& patternTrans = item->patternTransform();
 
 	// Compute pattern tansformation matrix and its inverse for converting pattern coordinates
 	// to pageitem coordinates 
-	QTransform matrix, invMat;
-	matrix.translate(patternOffsetX, patternOffsetY);
-	matrix.rotate(patternRotation);
-	matrix.shear(patternSkewX, patternSkewY);
+	QTransform matrix;
+	matrix.translate(patternTrans.offsetX, patternTrans.offsetY);
+	matrix.rotate(patternTrans.rotation);
+	matrix.shear(-patternTrans.skewX, patternTrans.skewY);
 	matrix.scale(pattern.scaleX, pattern.scaleY);
-	matrix.scale(patternScaleX / 100.0 , patternScaleY / 100.0);
-	invMat.scale((patternScaleX != 0) ? (100 /patternScaleX) : 1.0, (patternScaleY != 0) ? (100 /patternScaleY) : 1.0);
-	invMat.scale((pattern.scaleX != 0) ? (1 /pattern.scaleX) : 1.0, (pattern.scaleY != 0) ? (1 /pattern.scaleY) : 1.0);
-	invMat.rotate(-patternRotation);
-	invMat.translate(-patternOffsetX, -patternOffsetY);
+	matrix.scale(patternTrans.scaleX, patternTrans.scaleY);
+
+	QTransform invMat;
+	invMat.scale((patternTrans.scaleX != 0) ? (1.0 / patternTrans.scaleX) : 1.0, (patternTrans.scaleY != 0) ? (1.0 / patternTrans.scaleY) : 1.0);
+	invMat.scale((pattern.scaleX != 0) ? (1.0 / pattern.scaleX) : 1.0, (pattern.scaleY != 0) ? (1.0 / pattern.scaleY) : 1.0);
+	invMat.shear(patternTrans.skewX, -patternTrans.skewY);
+	invMat.rotate(-patternTrans.rotation);
+	invMat.translate(-patternTrans.offsetX, -patternTrans.offsetY);
 
 	// Compute bounding box in which pattern item will be drawn
 	double width  = item->width();
 	double height = item->height();
-	double rot    = patternRotation - floor(patternRotation / 90) * 90;
+	double rot    = patternTrans.rotation - floor(patternTrans.rotation / 90) * 90;
 	double ctheta = cos(rot * M_PI / 180);
 	double stheta = sin(rot * M_PI / 180);
 	QRectF  itemRect(0.0, 0.0, item->width(), item->height());
@@ -569,8 +543,10 @@ void ScPageOutput::drawPattern(PageItem* item, ScPainterExBase* painter, QRect c
 	QPointF pb(width + height * ctheta * stheta, height * stheta * stheta);
 	QPointF pc(-height * ctheta * stheta, height * ctheta * ctheta);
 	QPointF pd(width * ctheta * ctheta, height + width * ctheta * stheta);
-	QPointF ipa = invMat.map(pa), ipb = invMat.map(pb);
-	QPointF ipc = invMat.map(pc), ipd = invMat.map(pd);
+	QPointF ipa = invMat.map(pa);
+	QPointF ipb = invMat.map(pb);
+	QPointF ipc = invMat.map(pc);
+	QPointF ipd = invMat.map(pd);
 
 	painter->save();
 	if (!item->imageClip.empty())
@@ -580,16 +556,17 @@ void ScPageOutput::drawPattern(PageItem* item, ScPainterExBase* painter, QRect c
 	}
 	painter->setupPolygon(&item->PoLine);
 	painter->setClipPath();
+
 	for (int index = 0; index < pattern.items.count(); index++)
 	{
-		QRectF itRect;
 		PageItem* it = pattern.items.at(index);
 
 		painter->save();
-		painter->translate(patternOffsetX, patternOffsetY);
-		painter->rotate(patternRotation);
+		painter->translate(patternTrans.offsetX, patternTrans.offsetY);
+		painter->rotate(patternTrans.rotation);
+		painter->shear(-patternTrans.skewX, patternTrans.skewY);
 		painter->scale(pattern.scaleX, pattern.scaleY);
-		painter->scale(patternScaleX / 100.0, patternScaleY / 100.0);
+		painter->scale(patternTrans.scaleX, patternTrans.scaleY);
 
 		double patWidth  = (pattern.width != 0.0) ? pattern.width : 1.0;
 		double patHeight = (pattern.height != 0.0) ? pattern.height : 1.0;
@@ -608,22 +585,21 @@ void ScPageOutput::drawPattern(PageItem* item, ScPainterExBase* painter, QRect c
 
 		double itx = it->xPos();
 		double ity = it->yPos();
-		double itPosX = it->gXpos, itPosY = it->gYpos;
+		double itPosX = it->gXpos;
+		double itPosY = it->gYpos;
 		for (int kx = kxMin; kx <= kxMax; kx++)
 		{
 			for (int ky = kyMin; ky <= kyMax; ky++)
 			{
+				painter->save();
 				itPosX = it->gXpos + kx * pattern.width;
 				itPosY = it->gYpos + ky * pattern.height;
-				it->setXYPos(itPosX, itPosY);
-				it->getBoundingRect(&x1, &y1, &x2, &y2);
-				itRect.setCoords(x1, y1, x2, y2);
-				itRect = matrix.mapRect(itRect);
-				if (itRect.intersects(itemRect))
-					drawItem(it, painter, clip);
+				it->setXYPos(itPosX, itPosY, true);
+				drawItem(it, painter, QRect());
+				painter->restore();
 			}
 		}
-		it->setXYPos(itx, ity);
+		it->setXYPos(itx, ity, true);
 		painter->restore();
 	}
 	painter->restore();
@@ -634,18 +610,19 @@ void ScPageOutput::drawStrokePattern(PageItem* item, ScPainterExBase* painter, c
 
 }
 
-void ScPageOutput::drawItem_Arc(PageItem_Arc* item , ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_Arc(PageItem_Arc* item , ScPainterExBase* painter, const QRect& clip)
 {
 	painter->setupPolygon(&item->PoLine);
 	fillPath(item, painter, clip);
 }
 
-void ScPageOutput::drawItem_Group(PageItem_Group* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_Group(PageItem_Group* item, ScPainterExBase* painter, const QRect& clip)
 {
 	if (item->groupItemList.isEmpty())
 		return;
 
 	painter->save();
+
 	if (item->imageFlippedH())
 	{
 		painter->translate(item->width(), 0);
@@ -656,47 +633,69 @@ void ScPageOutput::drawItem_Group(PageItem_Group* item, ScPainterExBase* painter
 		painter->translate(0, item->height());
 		painter->scale(1, -1);
 	}
-	/*if ((maskType() == 1) || (maskType() == 2) || (maskType() == 4) || (maskType() == 5))
+
+	if ((item->maskType() == GradMask_Linear) || (item->maskType() == GradMask_Radial) || (item->maskType() == GradMask_LinearLumAlpha) || (item->maskType() == GradMask_RadialLumAlpha))
 	{
-		if ((maskType() == 1) || (maskType() == 2))
+		QString gradientMask = item->gradientMask();
+		FPoint fpMaskStart(item->GrMaskStartX, item->GrMaskStartY);
+		FPoint fpMaskEnd(item->GrMaskEndX, item->GrMaskEndY);
+		FPoint fpMaskFocal(item->GrMaskFocalX, item->GrMaskFocalY);
+		if ((item->GrMask == GradMask_Linear) || (item->GrMask == GradMask_Radial))
 			painter->setMaskMode(1);
 		else
 			painter->setMaskMode(3);
-		if ((!gradientMask().isEmpty()) && (!m_Doc->docGradients.contains(gradientMask())))
-			gradientMaskVal = "";
-		if (!(gradientMask().isEmpty()) && (m_Doc->docGradients.contains(gradientMask())))
-			mask_gradient = m_Doc->docGradients[gradientMask()];
-		painter->mask_gradient = mask_gradient;
-		if ((maskType() == 1) || (maskType() == 4))
-			painter->setGradientMask(VGradient::linear, FPoint(GrMaskStartX, GrMaskStartY), FPoint(GrMaskEndX, GrMaskEndY), FPoint(GrMaskStartX, GrMaskStartY), GrMaskScale, GrMaskSkew);
+		if ((!gradientMask.isEmpty()) && (!m_doc->docGradients.contains(gradientMask)))
+			gradientMask.clear();
+		if (!(gradientMask.isEmpty()) && (m_doc->docGradients.contains(gradientMask)))
+			painter->m_maskGradient = VGradientEx(m_doc->docGradients[gradientMask], *m_doc);
 		else
-			painter->setGradientMask(VGradient::radial, FPoint(GrMaskStartX, GrMaskStartY), FPoint(GrMaskEndX, GrMaskEndY), FPoint(GrMaskFocalX, GrMaskFocalY), GrMaskScale, GrMaskSkew);
+			painter->m_maskGradient = VGradientEx(item->mask_gradient, *m_doc);
+		if ((item->maskType() == GradMask_Linear) || (item->maskType() == GradMask_LinearLumAlpha))
+			painter->setGradientMask(VGradientEx::linear, fpMaskStart, fpMaskEnd, fpMaskStart, item->GrMaskScale, item->GrMaskSkew);
+		else
+			painter->setGradientMask(VGradientEx::radial, fpMaskStart, fpMaskEnd, fpMaskFocal, item->GrMaskScale, item->GrMaskSkew);
 	}
-	else if ((maskType() == 3) || (maskType() == 6) || (maskType() == 7) || (maskType() == 8))
+	else if ((item->maskType() == GradMask_Pattern) || (item->maskType() == GradMask_PatternLumAlpha) || (item->maskType() == GradMask_PatternLumAlphaInverted) || (item->maskType() == GradMask_PatternInverted))
 	{
-		if ((patternMask().isEmpty()) || (!m_Doc->docPatterns.contains(patternMask())))
-			painter->setMaskMode(0);
-		else
+		QString patternMaskVal = item->patternMask();
+		ScPattern* patternMask = m_doc->checkedPattern(patternMaskVal);
+		if (patternMask)
 		{
-			double scw = Width / groupWidth;
-			double sch = Height / groupHeight;
-			painter->setPatternMask(&m_Doc->docPatterns[patternMask()], patternMaskScaleX * scw, patternMaskScaleY * sch, patternMaskOffsetX, patternMaskOffsetY, patternMaskRotation, patternMaskSkewX, patternMaskSkewY, patternMaskMirrorX, patternMaskMirrorY);
-			if (maskType() == 3)
+			double scw = item->width() / item->groupWidth;
+			double sch = item->height() / item->groupHeight;
+			ScMaskTransform patternMaskTrans = item->patternMaskTransfrm;
+			patternMaskTrans.scaleX *= scw;
+			patternMaskTrans.scaleY *= sch;
+			painter->setPatternMask(patternMask, patternMaskTrans, item->patternMaskMirrorX, item->patternMaskMirrorY);
+			if (item->GrMask == GradMask_Pattern)
 				painter->setMaskMode(2);
-			else if (maskType() == 6)
+			else if (item->GrMask == GradMask_PatternLumAlpha)
 				painter->setMaskMode(4);
-			else if (maskType() == 7)
+			else if (item->GrMask == GradMask_PatternLumAlphaInverted)
 				painter->setMaskMode(5);
 			else
 				painter->setMaskMode(6);
 		}
+		else
+		{
+			painter->setMaskMode(0);
+		}
 	}
-	else*/
+	else
 		painter->setMaskMode(0);
+
 	painter->setFillRule(item->fillRule);
-	//painter->beginLayer(1.0 - fillTransparency(), fillBlendmode(), &PoLine);
+	if (item->fillTransparency() != 0.0 || item->fillBlendmode() != 0 || item->maskType() != GradMask_None)
+	{
+		// Disable this for now, this does not work properly with cairo win32 printing surface
+		/*if (item->groupClipping())
+			painter->beginLayer(1.0 - item->fillTransparency(), item->fillBlendmode(), &item->PoLine);
+		else*/
+			painter->beginLayer(1.0 - item->fillTransparency(), item->fillBlendmode());
+	}
 	painter->setMaskMode(0);
 	painter->scale(item->width() / item->groupWidth, item->height() / item->groupHeight);
+
 	for (int em = 0; em < item->groupItemList.count(); ++em)
 	{
 		PageItem* embedded = item->groupItemList.at(em);
@@ -711,11 +710,13 @@ void ScPageOutput::drawItem_Group(PageItem_Group* item, ScPainterExBase* painter
 		embedded->OwnPage = embedded->savedOwnPage;
 		painter->restore();
 	}
-	//painter->endLayer();
+	
+	if (item->fillTransparency() != 0.0 || item->fillBlendmode() != 0 || item->maskType() != GradMask_None)
+		painter->endLayer();
 	painter->restore();
 }
 
-void ScPageOutput::drawItem_ImageFrame(PageItem_ImageFrame* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_ImageFrame(PageItem_ImageFrame* item, ScPainterExBase* painter, const QRect& clip)
 {
 	ScPainterExBase::ImageMode mode = ScPainterExBase::rgbImages;
 	if ((item->fillColor() != CommonStrings::None) || (item->GrType != 0))
@@ -800,11 +801,13 @@ void ScPageOutput::drawItem_ImageFrame(PageItem_ImageFrame* item, ScPainterExBas
 	}
 }
 
-void ScPageOutput::drawItem_Line(PageItem_Line* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_Line(PageItem_Line* item, ScPainterExBase* painter, const QRect& clip)
 {
 	int startArrowIndex = item->startArrowIndex();
 	int endArrowIndex = item->endArrowIndex();
 
+	painter->setBlendModeStroke(item->lineBlendmode());
+
 	if (item->NamedLStyle.isEmpty())
 	{
 		QString patternStrokeVal = item->strokePattern();
@@ -820,7 +823,7 @@ void ScPageOutput::drawItem_Line(PageItem_Line* item, ScPainterExBase* painter,
 			}
 			else
 			{
-				painter->setPattern(strokePattern, item->patternStrokeScaleX, item->patternStrokeScaleY, item->patternStrokeOffsetX, item->patternStrokeOffsetY, item->patternStrokeRotation, item->patternStrokeSkewX, item->patternStrokeSkewY, item->patternStrokeMirrorX, item->patternStrokeMirrorY);
+				painter->setPattern(strokePattern, item->patternStrokeTransfrm, item->patternStrokeMirrorX, item->patternStrokeMirrorY);
 				painter->setStrokeMode(ScPainterExBase::Pattern);
 				painter->strokePath();
 			}
@@ -884,6 +887,9 @@ void ScPageOutput::drawItem_Line(PageItem_Line* item, ScPainterExBase* painter,
 			}
 		}
 	}
+
+	painter->setBlendModeStroke(0);
+
 	if (startArrowIndex != 0)
 	{
 		QTransform arrowTrans;
@@ -1016,6 +1022,7 @@ public:
 			if (outline.size() > 3)
 			{
 				m_painter->setLineWidth(strokeWidth());
+				m_painter->setStrokeMode(ScPainterExBase::Solid);
 				m_painter->strokePath();
 			}
 			m_painter->restore();
@@ -1026,10 +1033,11 @@ public:
 		m_painter->restore();
 	}
 
-	void drawLine(QPointF start, QPointF end) override
+	void drawLine(const QPointF& start, const QPointF& end) override
 	{
 		m_painter->save();
 		setupState();
+		m_painter->setStrokeMode(ScPainterExBase::Solid);
 		m_painter->drawLine(start, end);
 		m_painter->restore();
 	}
@@ -1046,55 +1054,27 @@ public:
 
 	void drawObject(PageItem* embedded) override
 	{
-		QRect cullingArea;
 		if (!embedded)
 			return;
 
 		m_painter->save();
-		double pws = embedded->m_lineWidth;
 
 		embedded->invalid = true;
-		m_scpage->drawItem_Pre(embedded, m_painter);
+		m_scpage->drawItem(embedded, m_painter, QRect());
 
-		switch (embedded->itemType())
-		{
-		case PageItem::ImageFrame:
-		case PageItem::TextFrame:
-		case PageItem::LatexFrame:
-		case PageItem::OSGFrame:
-		case PageItem::Polygon:
-		case PageItem::PathText:
-		case PageItem::Symbol:
-		case PageItem::Group:
-		case PageItem::RegularPolygon:
-		case PageItem::Arc:
-		case PageItem::Table:
-			m_scpage->drawItem(embedded, m_painter, cullingArea);
-			break;
-		case PageItem::Line:
-		case PageItem::PolyLine:
-		case PageItem::Spiral:
-			embedded->m_lineWidth = pws * qMin(scaleH(), scaleV());
-			m_scpage->drawItem(embedded, m_painter, cullingArea);
-			break;
-		default:
-			break;
-		}
-
-		embedded->m_lineWidth = pws * qMin(scaleH(), scaleV());
-		m_scpage->drawItem_Post(embedded, m_painter);
-		embedded->m_lineWidth = pws;
 		m_painter->restore();
 	}
+
+	void drawObjectDecoration(PageItem* item) override {}
 };
 
-void ScPageOutput::drawItem_Polygon(PageItem_Polygon* item , ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_Polygon(PageItem_Polygon* item , ScPainterExBase* painter, const QRect& clip)
 {
 	painter->setupPolygon(&item->PoLine);
 	fillPath(item, painter, clip);
 }
 
-void ScPageOutput::drawItem_PolyLine(PageItem_PolyLine* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_PolyLine(PageItem_PolyLine* item, ScPainterExBase* painter, const QRect& clip)
 {
 	if (item->PoLine.size() < 4)
 		return;
@@ -1102,6 +1082,8 @@ void ScPageOutput::drawItem_PolyLine(PageItem_PolyLine* item, ScPainterExBase* p
 	int startArrowIndex = item->startArrowIndex();
 	int endArrowIndex = item->endArrowIndex();
 
+	painter->setBlendModeStroke(item->lineBlendmode());
+
 	if ((item->fillColor() != CommonStrings::None) || (item->GrType != 0))
 	{
 		FPointArray cli;
@@ -1159,7 +1141,7 @@ void ScPageOutput::drawItem_PolyLine(PageItem_PolyLine* item, ScPainterExBase* p
 			}
 			else
 			{
-				painter->setPattern(strokePattern, item->patternStrokeScaleX, item->patternStrokeScaleY, item->patternStrokeOffsetX, item->patternStrokeOffsetY, item->patternStrokeRotation, item->patternStrokeSkewX, item->patternStrokeSkewY, item->patternStrokeMirrorX, item->patternStrokeMirrorY);
+				painter->setPattern(strokePattern, item->patternStrokeTransfrm, item->patternStrokeMirrorX, item->patternStrokeMirrorY);
 				painter->setStrokeMode(ScPainterExBase::Pattern);
 				painter->strokePath();
 			}
@@ -1222,6 +1204,9 @@ void ScPageOutput::drawItem_PolyLine(PageItem_PolyLine* item, ScPainterExBase* p
 			}
 		}
 	}
+
+	painter->setBlendModeStroke(0);
+
 	if (startArrowIndex != 0)
 	{
 		FPoint Start = item->PoLine.point(0);
@@ -1258,13 +1243,13 @@ void ScPageOutput::drawItem_PolyLine(PageItem_PolyLine* item, ScPainterExBase* p
 	}
 }
 
-void ScPageOutput::drawItem_RegularPolygon(PageItem_RegularPolygon* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_RegularPolygon(PageItem_RegularPolygon* item, ScPainterExBase* painter, const QRect& clip)
 {
 	painter->setupPolygon(&item->PoLine);
 	painter->fillPath();
 }
 
-void ScPageOutput::drawItem_Spiral(PageItem_Spiral* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_Spiral(PageItem_Spiral* item, ScPainterExBase* painter, const QRect& clip)
 {
 	if (item->PoLine.size() < 4)
 		return;
@@ -1272,6 +1257,8 @@ void ScPageOutput::drawItem_Spiral(PageItem_Spiral* item, ScPainterExBase* paint
 	int startArrowIndex = item->startArrowIndex();
 	int endArrowIndex = item->endArrowIndex();
 
+	painter->setBlendModeStroke(item->lineBlendmode());
+
 	if ((item->fillColor() != CommonStrings::None) || (item->GrType != 0))
 	{
 		FPointArray cli;
@@ -1326,7 +1313,7 @@ void ScPageOutput::drawItem_Spiral(PageItem_Spiral* item, ScPainterExBase* paint
 			}
 			else
 			{
-				painter->setPattern(strokePattern, item->patternStrokeScaleX, item->patternStrokeScaleY, item->patternStrokeOffsetX, item->patternStrokeOffsetY, item->patternStrokeRotation, item->patternStrokeSkewX, item->patternStrokeSkewY, item->patternStrokeMirrorX, item->patternStrokeMirrorY);
+				painter->setPattern(strokePattern, item->patternStrokeTransfrm, item->patternStrokeMirrorX, item->patternStrokeMirrorY);
 				painter->setStrokeMode(ScPainterExBase::Pattern);
 				painter->strokePath();
 			}
@@ -1389,6 +1376,9 @@ void ScPageOutput::drawItem_Spiral(PageItem_Spiral* item, ScPainterExBase* paint
 			}
 		}
 	}
+
+	painter->setBlendModeStroke(0);
+
 	if (startArrowIndex != 0)
 	{
 		FPoint Start = item->PoLine.point(0);
@@ -1425,7 +1415,7 @@ void ScPageOutput::drawItem_Spiral(PageItem_Spiral* item, ScPainterExBase* paint
 	}
 }
 
-void ScPageOutput::drawItem_Table(PageItem_Table* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::drawItem_Table(PageItem_Table* item, ScPainterExBase* painter, const QRect& clip)
 {
 	painter->save();
 
@@ -1440,7 +1430,7 @@ void ScPageOutput::drawItem_Table(PageItem_Table* item, ScPainterExBase* painter
 	painter->restore();
 }
 
-void ScPageOutput::drawItem_Text(PageItem* item, ScPainterExBase* painter, QRect cullingArea)
+void ScPageOutput::drawItem_Text(PageItem* item, ScPainterExBase* painter, const QRect& clip)
 {
 	if (item->pathTextShowFrame())
 	{
@@ -1472,7 +1462,7 @@ void ScPageOutput::drawItem_Text(PageItem* item, ScPainterExBase* painter, QRect
 	if ((item->fillColor() != CommonStrings::None) || (item->GrType != 0))
 	{
 		painter->setupPolygon(&item->PoLine);
-		fillPath(item, painter, cullingArea);
+		fillPath(item, painter, clip);
 	}
 	if ((item->isAnnotation()) && (item->annotation().Type() == Annotation::Button) && (!item->Pfile.isEmpty()) && (item->imageIsAvailable) && (item->imageVisible()) && (item->annotation().UseIcons()))
 	{
@@ -1515,6 +1505,10 @@ void ScPageOutput::drawArrow(ScPainterExBase* painter, PageItem* item, QTransfor
 			arrowTrans.scale(ml[ml.size() - 1].Width, ml[ml.size() - 1].Width);
 	}
 	arrow.map(arrowTrans);
+
+	painter->setBlendModeStroke(item->lineBlendmode());
+	painter->setBlendModeFill(item->lineBlendmode()); // needed for fill in arrow shapes
+
 	painter->setupPolygon(&arrow);
 	if (item->NamedLStyle.isEmpty())
 	{
@@ -1549,6 +1543,9 @@ void ScPageOutput::drawArrow(ScPainterExBase* painter, PageItem* item, QTransfor
 			}
 		}
 	}
+
+	painter->setBlendModeStroke(0);
+	painter->setBlendModeFill(0);
 }
 
 void ScPageOutput::drawMarks(ScPage* page, ScPainterExBase* painter, const MarksOptions& options)
@@ -1587,14 +1584,12 @@ void ScPageOutput::drawMarks(ScPage* page, ScPainterExBase* painter, const Marks
 	painter->setPen(ScColorShade(Qt::black, 100), 0.5, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
 	if (options.cropMarks)
 	{
-		FPoint start, end;
 		double left = offsetX, right = offsetX + width;
 		double bottom = offsetY + height, top = offsetY;
 		drawBoxMarks(painter, QRectF(QPointF(left, top), QPointF(right, bottom)), bleedBox, markOffs, markLength);
 	}
 	if (options.bleedMarks)
 	{
-		FPoint start, end;
 		double left = offsetX - bleedLeft, right = offsetX + width + bleedRight;
 		double bottom = offsetY + height + bleedBottom, top = offsetY - bleedTop;
 		drawBoxMarks(painter, QRectF(QPointF(left, top), QPointF(right, bottom)), bleedBox, markOffs, markLength);
@@ -1753,7 +1748,7 @@ void ScPageOutput::drawRegistrationCross(ScPainterExBase* painter)
 	painter->restore();
 }
 
-void ScPageOutput::fillPath(PageItem* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::fillPath(PageItem* item, ScPainterExBase* painter, const QRect& clip)
 {
 	if (painter->fillMode() == ScPainterExBase::Pattern && !painter->hasCapability(ScPainterExBase::patterns))
 		drawPattern(item, painter, clip);
@@ -1761,7 +1756,7 @@ void ScPageOutput::fillPath(PageItem* item, ScPainterExBase* painter, QRect clip
 		painter->fillPath();
 }
 
-void ScPageOutput::strokePath(PageItem* item, ScPainterExBase* painter, QRect clip)
+void ScPageOutput::strokePath(PageItem* item, ScPainterExBase* painter, const QRect& clip)
 {
 	painter->strokePath();
 }
