@@ -25,9 +25,7 @@ for which a new license (GPL+exception) is in place.
 ScPainter::ScPainter(QImage *target, int w, int h, double transparency, int blendmode)
          : m_image(target),
 	       m_layerTransparency(transparency),
-	       m_blendMode(blendmode),
-	       m_width(w),
-	       m_height(h)
+	       m_blendMode(blendmode)
 {
 	Q_ASSERT(w >= 0);
 	Q_ASSERT(h >= 0);
@@ -55,85 +53,73 @@ void ScPainter::beginLayer(double transparency, int blendmode, FPointArray *clip
 {
 	layerProp la;
 	la.blendmode = m_blendMode;
-	la.tranparency = m_layerTransparency;
+	la.transparency = m_layerTransparency;
 	m_layerTransparency = transparency;
 	m_blendMode = blendmode;
-	la.pushed = false;
 	la.groupClip.resize(0);
+	if (clipArray != nullptr)
+		la.groupClip = *clipArray;
 	la.maskMode = m_maskMode;
-	la.mask_patternScaleX = m_mask_patternScaleX;
-	la.mask_patternScaleY = m_mask_patternScaleY;
-	la.mask_patternOffsetX = m_mask_patternOffsetX;
-	la.mask_patternOffsetY = m_mask_patternOffsetY;
-	la.mask_patternRotation = m_mask_patternRotation;
-	la.mask_patternSkewX = m_mask_patternSkewX;
-	la.mask_patternSkewY = m_mask_patternSkewY;
+	la.maskPattern = m_maskPattern;
+	la.maskPatternTrans = m_maskPatternTrans;
 	la.mask_patternMirrorX = m_mask_patternMirrorX;
 	la.mask_patternMirrorY = m_mask_patternMirrorY;
 	la.mask_gradientScale = m_mask_gradientScale;
 	la.mask_gradientSkew = m_mask_gradientSkew;
 	la.mask_gradient = mask_gradient;
-	la.maskPattern = m_maskPattern;
-	if (clipArray != nullptr)
-		la.groupClip = *clipArray;
 	la.data = cairo_get_group_target(m_cr);
 	la.fillRule = m_fillRule;
 	cairo_push_group(m_cr);
-	la.pushed = true;
 	m_Layers.push(la);
 }
 
 void ScPainter::endLayer()
 {
-	layerProp la;
-	if (m_Layers.count() == 0)
+	if (m_Layers.isEmpty())
 		return;
-	la = m_Layers.pop();
+
+	layerProp la = m_Layers.pop();
 	m_maskMode = la.maskMode;
-	m_mask_patternScaleX = la.mask_patternScaleX;
-	m_mask_patternScaleY = la.mask_patternScaleY;
-	m_mask_patternOffsetX = la.mask_patternOffsetX;
-	m_mask_patternOffsetY = la.mask_patternOffsetY;
-	m_mask_patternRotation = la.mask_patternRotation;
-	m_mask_patternSkewX = la.mask_patternSkewX;
-	m_mask_patternSkewY = la.mask_patternSkewY;
+	m_maskPattern = la.maskPattern;
+	m_maskPatternTrans = la.maskPatternTrans;
 	m_mask_patternMirrorX = la.mask_patternMirrorX;
 	m_mask_patternMirrorY = la.mask_patternMirrorY;
 	m_mask_gradientScale = la.mask_gradientScale;
 	m_mask_gradientSkew = la.mask_gradientSkew;
 	mask_gradient = la.mask_gradient;
-	m_maskPattern = la.maskPattern;
 	m_fillRule = la.fillRule;
-	if (la.pushed)
+
+	cairo_pop_group_to_source (m_cr);
+	if (!la.groupClip.empty())
 	{
-		cairo_pop_group_to_source (m_cr);
-		if (!la.groupClip.empty())
-		{
-			if (m_fillRule)
-				cairo_set_fill_rule (m_cr, CAIRO_FILL_RULE_EVEN_ODD);
-			else
-				cairo_set_fill_rule (m_cr, CAIRO_FILL_RULE_WINDING);
-			setupPolygon(&la.groupClip);
-			setClipPath();
-		}
-		cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
-		if (m_maskMode > 0)
-		{
-			cairo_pattern_t *patM = getMaskPattern();
-			setRasterOp(m_blendMode);
-			cairo_mask(m_cr, patM);
-			if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
-				cairo_surface_destroy(m_imageMask);
-			cairo_pattern_destroy(patM);
-		}
+		if (m_fillRule)
+			cairo_set_fill_rule (m_cr, CAIRO_FILL_RULE_EVEN_ODD);
 		else
-		{
-			setRasterOp(m_blendMode);
-			cairo_paint_with_alpha (m_cr, m_layerTransparency);
-		}
-		cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
+			cairo_set_fill_rule (m_cr, CAIRO_FILL_RULE_WINDING);
+		setupPolygon(&la.groupClip);
+		setClipPath();
 	}
-	m_layerTransparency = la.tranparency;
+	cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
+	if (m_maskMode > 0)
+	{
+		cairo_pattern_t *patM = getMaskPattern();
+		setRasterOp(m_blendMode);
+		cairo_mask(m_cr, patM);
+		if (m_imageMask)
+		{
+			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
+		cairo_pattern_destroy(patM);
+	}
+	else
+	{
+		setRasterOp(m_blendMode);
+		cairo_paint_with_alpha (m_cr, m_layerTransparency);
+	}
+	cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
+
+	m_layerTransparency = la.transparency;
 	m_blendMode = la.blendmode;
 	m_maskMode = 0;
 }
@@ -144,14 +130,8 @@ void ScPainter::begin()
 
 void ScPainter::end()
 {
-	if (m_svgMode)
-		cairo_show_page (m_cr);
-	if (m_layeredMode)
-	{
-		cairo_surface_flush(cairo_get_target(m_cr));
-		cairo_restore(m_cr);
-		return;
-	}
+	cairo_surface_flush(cairo_get_target(m_cr));
+	cairo_restore(m_cr);
 }
 
 void ScPainter::clear()
@@ -310,16 +290,10 @@ void ScPainter::setGradientMask(VGradient::VGradientType mode, const FPoint& ori
 		m_mask_gradientSkew = tan(M_PI / 180.0 * skew);
 }
 
-void ScPainter::setPatternMask(ScPattern *pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY)
+void ScPainter::setPatternMask(ScPattern *pattern, const ScMaskTransform& maskTrans, bool mirrorX, bool mirrorY)
 {
 	m_maskPattern = pattern;
-	m_mask_patternScaleX = scaleX / 100.0;
-	m_mask_patternScaleY = scaleY / 100.0;
-	m_mask_patternOffsetX = offsetX;
-	m_mask_patternOffsetY = offsetY;
-	m_mask_patternRotation = rotation;
-	m_mask_patternSkewX = skewX;
-	m_mask_patternSkewY = skewY;
+	m_maskPatternTrans = maskTrans;
 	m_mask_patternMirrorX = mirrorX;
 	m_mask_patternMirrorY = mirrorY;
 }
@@ -548,16 +522,10 @@ void ScPainter::setBlendModeStroke(int blendMode)
 	m_blendModeStroke = blendMode;
 }
 
-void ScPainter::setPattern(ScPattern *pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY)
+void ScPainter::setPattern(ScPattern *pattern, const ScPatternTransform& patternTrans, bool mirrorX, bool mirrorY)
 {
 	m_pattern = pattern;
-	m_patternScaleX = scaleX / 100.0;
-	m_patternScaleY = scaleY / 100.0;
-	m_patternOffsetX = offsetX;
-	m_patternOffsetY = offsetY;
-	m_patternRotation = rotation;
-	m_patternSkewX = skewX;
-	m_patternSkewY = skewY;
+	m_patternTrans = patternTrans;
 	m_patternMirrorX = mirrorX;
 	m_patternMirrorY = mirrorY;
 }
@@ -565,7 +533,7 @@ void ScPainter::setPattern(ScPattern *pattern, double scaleX, double scaleY, dou
 cairo_pattern_t * ScPainter::getMaskPattern()
 {
 	cairo_save(m_cr);
-	cairo_pattern_t *pat;
+	cairo_pattern_t *pat { nullptr };
 	if ((m_maskMode == 1) || (m_maskMode == 3))
 	{
 		double x1 = mask_gradient.origin().x();
@@ -631,31 +599,31 @@ cairo_pattern_t * ScPainter::getMaskPattern()
 				{
 					r = *s;
 					if (qAlpha(r) == 0)
-						k = 0; // 255;
+						k = 0;
 					else
 						k = qMin(qRound(0.3 * qRed(r) + 0.59 * qGreen(r) + 0.11 * qBlue(r)), 255);
-					*s = qRgba(qRed(r), qGreen(r), qBlue(r), /* 255 - */ k);
+					*s = qRgba(qRed(r), qGreen(r), qBlue(r), k);
 					s++;
 				}
 			}
-			m_imageMask = cairo_image_surface_create_for_data ((uchar*)m_imageQ.bits(), CAIRO_FORMAT_ARGB32, w, h, w * 4);
+			m_imageMask = cairo_image_surface_create_for_data (m_imageQ.bits(), CAIRO_FORMAT_ARGB32, w, h, w * 4);
 		}
 		else
 		{
 			m_imageQ = m_maskPattern->pattern.copy();
 			if (m_maskMode == 6)
 				m_imageQ.invertPixels(QImage::InvertRgba);
-			m_imageMask = cairo_image_surface_create_for_data ((uchar*)m_imageQ.bits(), CAIRO_FORMAT_ARGB32, m_maskPattern->getPattern()->width(), m_maskPattern->getPattern()->height(), m_maskPattern->getPattern()->width() * 4);
+			m_imageMask = cairo_image_surface_create_for_data (m_imageQ.bits(), CAIRO_FORMAT_ARGB32, m_maskPattern->getPattern()->width(), m_maskPattern->getPattern()->height(), m_maskPattern->getPattern()->width() * 4);
 		}
 		pat = cairo_pattern_create_for_surface(m_imageMask);
 		cairo_pattern_set_extend(pat, CAIRO_EXTEND_REPEAT);
 		cairo_pattern_set_filter(pat, CAIRO_FILTER_GOOD);
 		cairo_matrix_t matrix;
 		QTransform qmatrix;
-		qmatrix.translate(m_mask_patternOffsetX, m_mask_patternOffsetY);
-		qmatrix.rotate(m_mask_patternRotation);
-		qmatrix.shear(-m_mask_patternSkewX, m_mask_patternSkewY);
-		qmatrix.scale(m_mask_patternScaleX, m_mask_patternScaleY);
+		qmatrix.translate(m_maskPatternTrans.offsetX, m_maskPatternTrans.offsetY);
+		qmatrix.rotate(m_maskPatternTrans.rotation);
+		qmatrix.shear(-m_maskPatternTrans.skewX, m_maskPatternTrans.skewY);
+		qmatrix.scale(m_maskPatternTrans.scaleX, m_maskPatternTrans.scaleY);
 		qmatrix.scale(m_maskPattern->width / static_cast<double>(m_maskPattern->getPattern()->width()), m_maskPattern->height / static_cast<double>(m_maskPattern->getPattern()->height()));
 		if (m_mask_patternMirrorX)
 			qmatrix.scale(-1, 1);
@@ -688,8 +656,11 @@ void ScPainter::fillPathHelper()
 			setRasterOp(m_blendModeFill);
 			cairo_clip_preserve(m_cr);
 			cairo_mask(m_cr, pat);
-			if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
+			if (m_imageMask)
+			{
 				cairo_surface_destroy(m_imageMask);
+				m_imageMask = nullptr;
+			}
 			cairo_pattern_destroy(pat);
 		}
 		else
@@ -874,12 +845,12 @@ void ScPainter::fillPathHelper()
 					cairo_mesh_pattern_line_to(mpat, e1.x2(), e1.y2());
 					cairo_mesh_pattern_line_to(mpat, e2.x2(), e2.y2());
 					cairo_mesh_pattern_line_to(mpat, e2s.x2(), e2s.y2());
-					qStopColors[offset-1].getRgbF(&r, &g, &b, &a);
+					qStopColors[offset - 1].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 0, r, g, b, a);
 					qStopColors[offset].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 1, r, g, b, a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 2, r, g, b, a);
-					qStopColors[offset-1].getRgbF(&r, &g, &b, &a);
+					qStopColors[offset - 1].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 3, r, g, b, a);
 					cairo_mesh_pattern_end_patch(mpat);
 					cairo_mesh_pattern_begin_patch(mpat);
@@ -887,12 +858,12 @@ void ScPainter::fillPathHelper()
 					cairo_mesh_pattern_line_to(mpat, e2.x2(), e2.y2());
 					cairo_mesh_pattern_line_to(mpat, e3.x2(), e3.y2());
 					cairo_mesh_pattern_line_to(mpat, e3s.x2(), e3s.y2());
-					qStopColors[offset-1].getRgbF(&r, &g, &b, &a);
+					qStopColors[offset - 1].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 0, r, g, b, a);
 					qStopColors[offset].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 1, r, g, b, a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 2, r, g, b, a);
-					qStopColors[offset-1].getRgbF(&r, &g, &b, &a);
+					qStopColors[offset - 1].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 3, r, g, b, a);
 					cairo_mesh_pattern_end_patch(mpat);
 					cairo_mesh_pattern_begin_patch(mpat);
@@ -900,12 +871,12 @@ void ScPainter::fillPathHelper()
 					cairo_mesh_pattern_line_to(mpat, e3.x2(), e3.y2());
 					cairo_mesh_pattern_line_to(mpat, e4.x2(), e4.y2());
 					cairo_mesh_pattern_line_to(mpat, e4s.x2(), e4s.y2());
-					qStopColors[offset-1].getRgbF(&r, &g, &b, &a);
+					qStopColors[offset - 1].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 0, r, g, b, a);
 					qStopColors[offset].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 1, r, g, b, a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 2, r, g, b, a);
-					qStopColors[offset-1].getRgbF(&r, &g, &b, &a);
+					qStopColors[offset - 1].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 3, r, g, b, a);
 					cairo_mesh_pattern_end_patch(mpat);
 					cairo_mesh_pattern_begin_patch(mpat);
@@ -913,12 +884,12 @@ void ScPainter::fillPathHelper()
 					cairo_mesh_pattern_line_to(mpat, e4.x2(), e4.y2());
 					cairo_mesh_pattern_line_to(mpat, e1.x2(), e1.y2());
 					cairo_mesh_pattern_line_to(mpat, e1s.x2(), e1s.y2());
-					qStopColors[offset-1].getRgbF(&r, &g, &b, &a);
+					qStopColors[offset - 1].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 0, r, g, b, a);
 					qStopColors[offset].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 1, r, g, b, a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 2, r, g, b, a);
-					qStopColors[offset-1].getRgbF(&r, &g, &b, &a);
+					qStopColors[offset - 1].getRgbF(&r, &g, &b, &a);
 					cairo_mesh_pattern_set_corner_color_rgba(mpat, 3, r, g, b, a);
 					cairo_mesh_pattern_end_patch(mpat);
 				}
@@ -941,14 +912,14 @@ void ScPainter::fillPathHelper()
 			cairo_set_tolerance(cr, 0.5);
 			double r, g, b, a;
 			mpat = cairo_pattern_create_mesh();
-			for (int grow = 0; grow < meshGradientArray.count()-1; grow++)
+			for (int grow = 0; grow < meshGradientArray.count() - 1; ++grow)
 			{
-				for (int gcol = 0; gcol < meshGradientArray[grow].count()-1; gcol++)
+				for (int gcol = 0; gcol < meshGradientArray[grow].count() - 1; ++gcol)
 				{
 					MeshPoint mp1 = meshGradientArray[grow][gcol];
-					MeshPoint mp2 = meshGradientArray[grow][gcol+1];
-					MeshPoint mp3 = meshGradientArray[grow+1][gcol+1];
-					MeshPoint mp4 = meshGradientArray[grow+1][gcol];
+					MeshPoint mp2 = meshGradientArray[grow][gcol + 1];
+					MeshPoint mp3 = meshGradientArray[grow + 1][gcol + 1];
+					MeshPoint mp4 = meshGradientArray[grow + 1][gcol];
 					cairo_mesh_pattern_begin_patch(mpat);
 					cairo_mesh_pattern_move_to(mpat, mp1.gridPoint.x(), mp1.gridPoint.y());
 					cairo_mesh_pattern_curve_to(mpat, mp1.controlRight.x(), mp1.controlRight.y(), mp2.controlLeft.x(), mp2.controlLeft.y(), mp2.gridPoint.x(), mp2.gridPoint.y());
@@ -1083,8 +1054,11 @@ void ScPainter::fillPathHelper()
 			cairo_pattern_t *patM = getMaskPattern();
 			setRasterOp(m_blendModeFill);
 			cairo_mask(m_cr, patM);
-			if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
+			if (m_imageMask)
+			{
 				cairo_surface_destroy(m_imageMask);
+				m_imageMask = nullptr;
+			}
 			cairo_pattern_destroy (patM);
 		}
 		else
@@ -1109,10 +1083,10 @@ void ScPainter::fillPathHelper()
 		cairo_pattern_set_filter(m_pat, CAIRO_FILTER_GOOD);
 		cairo_matrix_t matrix;
 		QTransform qmatrix;
-		qmatrix.translate(m_patternOffsetX, m_patternOffsetY);
-		qmatrix.rotate(m_patternRotation);
-		qmatrix.shear(-m_patternSkewX, m_patternSkewY);
-		qmatrix.scale(m_patternScaleX, m_patternScaleY);
+		qmatrix.translate(m_patternTrans.offsetX, m_patternTrans.offsetY);
+		qmatrix.rotate(m_patternTrans.rotation);
+		qmatrix.shear(-m_patternTrans.skewX, m_patternTrans.skewY);
+		qmatrix.scale(m_patternTrans.scaleX, m_patternTrans.scaleY);
 		qmatrix.scale(m_pattern->width / static_cast<double>(m_pattern->getPattern()->width()), m_pattern->height / static_cast<double>(m_pattern->getPattern()->height()));
 		if (m_patternMirrorX)
 			qmatrix.scale(-1, 1);
@@ -1128,8 +1102,11 @@ void ScPainter::fillPathHelper()
 			cairo_pattern_t *patM = getMaskPattern();
 			setRasterOp(m_blendModeFill);
 			cairo_mask(m_cr, patM);
-			if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
+			if (m_imageMask)
+			{
 				cairo_surface_destroy(m_imageMask);
+				m_imageMask = nullptr;
+			}
 			cairo_pattern_destroy (patM);
 		}
 		else
@@ -1143,8 +1120,7 @@ void ScPainter::fillPathHelper()
 	}
 	else if (m_fillMode == 4)
 	{
-		cairo_path_t *path;
-		path = cairo_copy_path(m_cr);
+		cairo_path_t *path = cairo_copy_path(m_cr);
 		cairo_push_group(m_cr);
 		if (m_hatchUseBackground && m_hatchBackground.isValid())
 		{
@@ -1221,8 +1197,11 @@ void ScPainter::fillPathHelper()
 			cairo_pattern_t *patM = getMaskPattern();
 			cairo_pattern_set_filter(patM, CAIRO_FILTER_FAST);
 			cairo_mask(m_cr, patM);
-			if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
+			if (m_imageMask)
+			{
 				cairo_surface_destroy(m_imageMask);
+				m_imageMask = nullptr;
+			}
 			cairo_pattern_destroy(patM);
 		}
 		else
@@ -1271,10 +1250,10 @@ void ScPainter::strokePathHelper()
 		cairo_matrix_t matrix;
 		QTransform qmatrix;
 		qmatrix.translate(-m_LineWidth / 2.0, -m_LineWidth / 2.0);
-		qmatrix.translate(m_patternOffsetX, m_patternOffsetY);
-		qmatrix.rotate(m_patternRotation);
-		qmatrix.shear(-m_patternSkewX, m_patternSkewY);
-		qmatrix.scale(m_patternScaleX, m_patternScaleY);
+		qmatrix.translate(m_patternTrans.offsetX, m_patternTrans.offsetY);
+		qmatrix.rotate(m_patternTrans.rotation);
+		qmatrix.shear(-m_patternTrans.skewX, m_patternTrans.skewY);
+		qmatrix.scale(m_patternTrans.scaleX, m_patternTrans.scaleY);
 		qmatrix.scale(m_pattern->width / static_cast<double>(m_pattern->getPattern()->width()), m_pattern->height / static_cast<double>(m_pattern->getPattern()->height()));
 		if (m_patternMirrorX)
 			qmatrix.scale(-1, 1);
@@ -1400,8 +1379,11 @@ void ScPainter::drawImage(QImage *image)
 		cairo_pattern_t *patM = getMaskPattern();
 		cairo_pattern_set_filter(patM, CAIRO_FILTER_GOOD);
 		cairo_mask(m_cr, patM);
-		if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
+		if (m_imageMask)
+		{
 			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
 		cairo_pattern_destroy(patM);
 	}
 	else
@@ -1890,15 +1872,15 @@ void ScPainter::blurAlpha(int radius)
 	QRgb *pix = (QRgb*)cairo_image_surface_get_data(data);
 	int w   = cairo_image_surface_get_width(data);
 	int h   = cairo_image_surface_get_height(data);
-	int wm  = w-1;
-	int hm  = h-1;
-	int wh  = w*h;
+	int wm  = w - 1;
+	int hm  = h - 1;
+	int wh  = w * h;
 	int div = radius+radius+1;
 	int *a = new int[wh];
 	int asum, x, y, i, yp, yi, yw;
 	QRgb p;
-	int *vmin = new int[qMax(w,h)];
-	int divsum = (div+1)>>1;
+	int *vmin = new int[qMax(w, h)];
+	int divsum = (div + 1)>>1;
 	divsum *= divsum;
 	int *dv = new int[256 * (size_t) divsum];
 	for (i = 0; i < 256 * divsum; ++i)
@@ -1923,11 +1905,11 @@ void ScPainter::blurAlpha(int radius)
 		ainsum = aoutsum = asum = 0;
 		for (i = -radius; i <= radius; ++i)
 		{
-			p = pix[yi+qMin(wm,qMax(i,0))];
-			sir = stack[i+radius];
+			p = pix[yi + qMin(wm, qMax(i, 0))];
+			sir = stack[i + radius];
 			sir[0] = qAlpha(p);
-			rbs = r1-abs(i);
-			asum += sir[0]*rbs;
+			rbs = r1 - abs(i);
+			asum += sir[0] * rbs;
 			if (i > 0)
 				ainsum += sir[0];
 			else
@@ -1938,7 +1920,7 @@ void ScPainter::blurAlpha(int radius)
 		{
 			a[yi] = dv[asum];
 			asum -= aoutsum;
-			stackstart = stackpointer-radius+div;
+			stackstart = stackpointer - radius + div;
 			sir = stack[stackstart % div];
 			aoutsum -= sir[0];
 			if (y == 0)
