@@ -8,10 +8,11 @@ for which a new license (GPL+exception) is in place.
 #include "scpainterex_cairo.h"
 #include "sccolorengine.h"
 #include "scimage.h"
+#include "scpattern.h"
 #include "util.h"
 #include "util_math.h"
 
-ScPainterEx_Cairo::ScPainterEx_Cairo(cairo_t* context, const QRect& rect,  ScribusDoc* doc, bool gray) : ScPainterExBase()
+ScPainterEx_Cairo::ScPainterEx_Cairo(cairo_t* context, const QRect& rect, ScribusDoc* doc, bool gray) : ScPainterExBase()
 {
 	m_doc    = doc;
 	m_width  = rect.width();
@@ -28,7 +29,11 @@ ScPainterEx_Cairo::ScPainterEx_Cairo(cairo_t* context, const QRect& rect,  Scrib
 
 ScPainterEx_Cairo::~ScPainterEx_Cairo()
 {
-
+	if (m_imageMask)
+	{
+		cairo_surface_destroy(m_imageMask);
+		m_imageMask = nullptr;
+	}
 }
 
 QColor ScPainterEx_Cairo::transformColor(const ScColorShade& colorShade, double trans) const
@@ -65,12 +70,79 @@ void ScPainterEx_Cairo::transformImage(QImage& image) const
 	}
 }
 
-void ScPainterEx_Cairo::begin()
+void ScPainterEx_Cairo::beginLayer(double transparency, int blendMode, FPointArray* clipArray)
 {
+	LayerProp la;
+	la.blendMode = m_blendModeLayer;
+	la.transparency = m_layerTransparency;
+	m_layerTransparency = transparency;
+	m_blendModeLayer = blendMode;
+	la.groupClip.resize(0);
+	if (clipArray != nullptr)
+		la.groupClip = *clipArray;
+	la.maskMode = m_maskMode;
+	la.maskPattern = m_maskPattern;
+	la.maskPatternTrans = m_maskPatternTrans;
+	la.maskPatternMirrorX = m_maskPatternMirrorX;
+	la.maskPatternMirrorY = m_maskPatternMirrorY;
+	la.maskGradientScale = m_maskGradientScale;
+	la.maskGradientSkew = m_maskGradientSkew;
+	la.maskGradient = m_maskGradient;
+	la.data = cairo_get_group_target(m_cr);
+	la.fillRule = m_fillRule;
+	cairo_push_group(m_cr);
+	m_layers.push(la);
 }
 
-void ScPainterEx_Cairo::end()
+void ScPainterEx_Cairo::endLayer()
 {
+	if (m_layers.isEmpty())
+		return;
+
+	LayerProp la = m_layers.pop();
+	m_maskMode = la.maskMode;
+	m_maskPattern = la.maskPattern;
+	m_maskPatternTrans = la.maskPatternTrans;
+	m_maskPatternMirrorX = la.maskPatternMirrorX;
+	m_maskPatternMirrorY = la.maskPatternMirrorY;
+	m_maskGradientScale = la.maskGradientScale;
+	m_maskGradientSkew = la.maskGradientSkew;
+	m_maskGradient = la.maskGradient;
+	m_fillRule = la.fillRule;
+
+	cairo_pop_group_to_source(m_cr);
+	if (!la.groupClip.empty())
+	{
+		if (m_fillRule)
+			cairo_set_fill_rule(m_cr, CAIRO_FILL_RULE_EVEN_ODD);
+		else
+			cairo_set_fill_rule(m_cr, CAIRO_FILL_RULE_WINDING);
+		setupPolygon(&la.groupClip);
+		setClipPath();
+	}
+	cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
+	if (m_maskMode > 0)
+	{
+		cairo_pattern_t* patM = getMaskPattern();
+		setRasterOp(m_blendModeLayer);
+		cairo_mask(m_cr, patM);
+		if (m_imageMask)
+		{
+			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
+		cairo_pattern_destroy(patM);
+	}
+	else
+	{
+		setRasterOp(m_blendModeLayer);
+		cairo_paint_with_alpha(m_cr, m_layerTransparency);
+	}
+	cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
+
+	m_layerTransparency = la.transparency;
+	m_blendModeLayer = la.blendMode;
+	m_maskMode = 0;
 }
 
 void ScPainterEx_Cairo::clear()
@@ -122,6 +194,16 @@ void ScPainterEx_Cairo::scale(double x, double y)
 	cairo_scale(m_cr, x, y);
 }
 
+void ScPainterEx_Cairo::shear(double x, double y)
+{
+	QTransform trans;
+	trans.shear(x, y);
+
+	cairo_matrix_t matrix;
+	cairo_matrix_init(&matrix, trans.m11(), trans.m12(), trans.m21(), trans.m22(), trans.dx(), trans.dy());
+	cairo_transform(m_cr, &matrix);
+}
+
 void ScPainterEx_Cairo::moveTo(const double &x, const double &y)
 {
 	cairo_move_to(m_cr, x, y);
@@ -132,7 +214,7 @@ void ScPainterEx_Cairo::lineTo(const double &x, const double &y)
 	cairo_line_to(m_cr, x, y);
 }
 
-void ScPainterEx_Cairo::curveTo(FPoint p1, FPoint p2, FPoint p3)
+void ScPainterEx_Cairo::curveTo(const FPoint& p1, const FPoint& p2, const FPoint& p3)
 {
 	cairo_curve_to(m_cr, p1.x(), p1.y(), p2.x(), p2.y(), p3.x(), p3.y());
 }
@@ -162,7 +244,7 @@ void ScPainterEx_Cairo::setStrokeMode(int stroke)
 	m_strokeMode = stroke;
 }
 
-void ScPainterEx_Cairo::setGradient(VGradientEx::Type mode, FPoint orig, FPoint vec, FPoint foc, double scale, double skew)
+void ScPainterEx_Cairo::setGradient(VGradientEx::Type mode, const FPoint& orig, const FPoint& vec, const FPoint& foc, double scale, double skew)
 {
 	m_fillGradient.setType(mode);
 	m_fillGradient.setOrigin(orig);
@@ -192,7 +274,7 @@ void ScPainterEx_Cairo::setMaskMode(int mask)
 	m_maskMode = mask;
 }
 
-void ScPainterEx_Cairo::setGradientMask(VGradientEx::Type mode, FPoint orig, FPoint vec, FPoint foc, double scale, double skew)
+void ScPainterEx_Cairo::setGradientMask(VGradientEx::Type mode, const FPoint& orig, const FPoint& vec, const FPoint& foc, double scale, double skew)
 {
 	m_maskGradient.setType(mode);
 	m_maskGradient.setOrigin(orig);
@@ -211,35 +293,23 @@ void ScPainterEx_Cairo::setGradientMask(VGradientEx::Type mode, FPoint orig, FPo
 		m_maskGradientSkew = tan(M_PI / 180.0 * skew);
 }
 
-void ScPainterEx_Cairo::setPatternMask(ScPattern *pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY)
+void ScPainterEx_Cairo::setPatternMask(ScPattern *pattern, const ScMaskTransform& maskTrans, bool mirrorX, bool mirrorY)
 {
 	m_maskPattern = pattern;
-	m_maskPatternScaleX = scaleX / 100.0;
-	m_maskPatternScaleY = scaleY / 100.0;
-	m_maskPatternOffsetX = offsetX;
-	m_maskPatternOffsetY = offsetY;
-	m_maskPatternRotation = rotation;
-	m_maskPatternSkewX = skewX;
-	m_maskPatternSkewY = skewY;
+	m_maskPatternTrans = maskTrans;
 	m_maskPatternMirrorX = mirrorX;
 	m_maskPatternMirrorY = mirrorY;
 }
 
-void ScPainterEx_Cairo::setPattern(ScPattern *pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY)
+void ScPainterEx_Cairo::setPattern(ScPattern *pattern, const ScPatternTransform& patternTrans, bool mirrorX, bool mirrorY)
 {
 	m_pattern = pattern;
-	m_patternScaleX = scaleX / 100.0;
-	m_patternScaleY = scaleY / 100.0;
-	m_patternOffsetX = offsetX;
-	m_patternOffsetY = offsetY;
-	m_patternRotation = rotation;
-	m_patternSkewX   = skewX;
-	m_patternSkewY   = skewY;
+	m_patternTrans = patternTrans;
 	m_patternMirrorX = mirrorX;
 	m_patternMirrorY = mirrorY;
 }
 
-void ScPainterEx_Cairo::set4ColorGeometry(FPoint p1, FPoint p2, FPoint p3, FPoint p4, FPoint c1, FPoint c2, FPoint c3, FPoint c4)
+void ScPainterEx_Cairo::set4ColorGeometry(const FPoint& p1, const FPoint& p2, const FPoint& p3, const FPoint& p4, const FPoint& c1, const FPoint& c2, const FPoint& c3, const FPoint& c4)
 {
 	m_fillGradient.setType(VGradientEx::fourcolor);
 	m_gradPatchP1 = p1;
@@ -260,7 +330,7 @@ void ScPainterEx_Cairo::set4ColorColors(const ScColorShade&  col1, const ScColor
 	m_gradPatchColor4 = col4;
 }
 
-void ScPainterEx_Cairo::setDiamondGeometry(FPoint p1, FPoint p2, FPoint p3, FPoint p4, FPoint c1, FPoint c2, FPoint c3, FPoint c4, FPoint c5)
+void ScPainterEx_Cairo::setDiamondGeometry(const FPoint& p1, const FPoint& p2, const FPoint& p3, const FPoint& p4, const FPoint& c1, const FPoint& c2, const FPoint& c3, const FPoint& c4, const FPoint& c5)
 {
 	m_fillGradient.setType(VGradientEx::diamond);
 	m_gradPatchP1 = p1;
@@ -274,7 +344,7 @@ void ScPainterEx_Cairo::setDiamondGeometry(FPoint p1, FPoint p2, FPoint p3, FPoi
 	m_gradControlP5 = c5;
 }
 
-void ScPainterEx_Cairo::setMeshGradient(FPoint p1, FPoint p2, FPoint p3, FPoint p4, QList<QList<MeshPoint> > meshArray)
+void ScPainterEx_Cairo::setMeshGradient(const FPoint& p1, const FPoint& p2, const FPoint& p3, const FPoint& p4, QList<QList<MeshPoint> > meshArray)
 {
 	m_fillGradient.setType(VGradientEx::mesh);
 	m_meshGradientArray = meshArray;
@@ -284,7 +354,7 @@ void ScPainterEx_Cairo::setMeshGradient(FPoint p1, FPoint p2, FPoint p3, FPoint
 	m_gradPatchP4 = p4;
 }
 
-void ScPainterEx_Cairo::setMeshGradient(FPoint p1, FPoint p2, FPoint p3, FPoint p4, QList<meshGradientPatch> meshPatches)
+void ScPainterEx_Cairo::setMeshGradient(const FPoint& p1, const FPoint& p2, const FPoint& p3, const FPoint& p4, QList<meshGradientPatch> meshPatches)
 {
 	m_fillGradient.setType(VGradientEx::freemesh);
 	m_meshGradientPatches = meshPatches;
@@ -294,6 +364,18 @@ void ScPainterEx_Cairo::setMeshGradient(FPoint p1, FPoint p2, FPoint p3, FPoint
 	m_gradPatchP4 = p4;
 }
 
+void ScPainterEx_Cairo::setHatchParameters(int mode, double distance, double angle, bool useBackground, const ScColorShade& background, const ScColorShade& foreground, double width, double height)
+{
+	m_hatchType = mode;
+	m_hatchDistance = distance;
+	m_hatchAngle = angle;
+	m_hatchUseBackground = useBackground;
+	m_hatchBackground = background;
+	m_hatchForeground = foreground;
+	m_hatchWidth = width;
+	m_hatchHeight = height;
+}
+
 void ScPainterEx_Cairo::fillPath()
 {
 	if (m_fillMode != 0)
@@ -442,6 +524,114 @@ void ScPainterEx_Cairo::setBlendModeStroke(int blendMode)
 	m_blendModeStroke = blendMode;
 }
 
+cairo_pattern_t* ScPainterEx_Cairo::getMaskPattern()
+{
+	cairo_save(m_cr);
+	cairo_pattern_t* pat { nullptr };
+	if ((m_maskMode == 1) || (m_maskMode == 3))
+	{
+		double x1 = m_maskGradient.origin().x();
+		double y1 = m_maskGradient.origin().y();
+		double x2 = m_maskGradient.vector().x();
+		double y2 = m_maskGradient.vector().y();
+		double fx = m_maskGradient.focalPoint().x();
+		double fy = m_maskGradient.focalPoint().y();
+		if (m_maskGradient.type() == VGradientEx::linear)
+			pat = cairo_pattern_create_linear(x1, y1, x2, y2);
+		else
+			pat = cairo_pattern_create_radial(fx, fy, 0, x1, y1, sqrt(pow(x2 - x1, 2) + pow(y2 - y1, 2)));
+		QList<VColorStopEx*> colorStops = m_maskGradient.colorStops();
+		QColor qStopColor;
+		for (int offset = 0; offset < colorStops.count(); offset++)
+		{
+			const auto* stop = colorStops[offset];
+			qStopColor = transformColor(ScColorShade(stop->color, stop->shade), 1.0);
+			double a = colorStops[offset]->opacity;
+			double r, g, b;
+			qStopColor.getRgbF(&r, &g, &b);
+			if (m_maskMode == 3)
+				a = 0.3 * r + 0.59 * g + 0.11 * b;
+			cairo_pattern_add_color_stop_rgba(pat, colorStops[offset]->rampPoint, r, g, b, a);
+		}
+		cairo_matrix_t matrix;
+		QTransform qmatrix;
+		if (m_maskGradient.type() == VGradientEx::radial)
+		{
+			double rotEnd = xy2Deg(x2 - x1, y2 - y1);
+			qmatrix.translate(x1, y1);
+			qmatrix.rotate(rotEnd);
+			qmatrix.shear(m_maskGradientSkew, 0);
+			qmatrix.translate(0, y1 * (1.0 - m_maskGradientScale));
+			qmatrix.translate(-x1, -y1);
+			qmatrix.scale(1, m_maskGradientScale);
+		}
+		else
+		{
+			qmatrix.translate(x1, y1);
+			qmatrix.shear(-m_maskGradientSkew, 0);
+			qmatrix.translate(-x1, -y1);
+		}
+		cairo_matrix_init(&matrix, qmatrix.m11(), qmatrix.m12(), qmatrix.m21(), qmatrix.m22(), qmatrix.dx(), qmatrix.dy());
+		cairo_matrix_invert(&matrix);
+		cairo_pattern_set_matrix(pat, &matrix);
+	}
+	else
+	{
+		if ((m_maskMode == 4) || (m_maskMode == 5))
+		{
+			m_imageQ = m_maskPattern->pattern.copy();
+			if (m_maskMode == 5)
+				m_imageQ.invertPixels();
+			int h = m_imageQ.height();
+			int w = m_imageQ.width();
+			int k;
+			QRgb* s;
+			QRgb r;
+			for (int yi = 0; yi < h; ++yi)
+			{
+				s = (QRgb*) (m_imageQ.scanLine(yi));
+				for (int xi = 0; xi < w; ++xi)
+				{
+					r = *s;
+					if (qAlpha(r) == 0)
+						k = 0;
+					else
+						k = qMin(qRound(0.3 * qRed(r) + 0.59 * qGreen(r) + 0.11 * qBlue(r)), 255);
+					*s = qRgba(qRed(r), qGreen(r), qBlue(r), k);
+					s++;
+				}
+			}
+			m_imageMask = cairo_image_surface_create_for_data(m_imageQ.bits(), CAIRO_FORMAT_ARGB32, w, h, w * 4);
+		}
+		else
+		{
+			m_imageQ = m_maskPattern->pattern.copy();
+			if (m_maskMode == 6)
+				m_imageQ.invertPixels(QImage::InvertRgba);
+			m_imageMask = cairo_image_surface_create_for_data(m_imageQ.bits(), CAIRO_FORMAT_ARGB32, m_maskPattern->getPattern()->width(), m_maskPattern->getPattern()->height(), m_maskPattern->getPattern()->width() * 4);
+		}
+		pat = cairo_pattern_create_for_surface(m_imageMask);
+		cairo_pattern_set_extend(pat, CAIRO_EXTEND_REPEAT);
+		cairo_pattern_set_filter(pat, CAIRO_FILTER_GOOD);
+		cairo_matrix_t matrix;
+		QTransform qmatrix;
+		qmatrix.translate(m_maskPatternTrans.offsetX, m_maskPatternTrans.offsetY);
+		qmatrix.rotate(m_maskPatternTrans.rotation);
+		qmatrix.shear(-m_maskPatternTrans.skewX, m_maskPatternTrans.skewY);
+		qmatrix.scale(m_maskPatternTrans.scaleX, m_maskPatternTrans.scaleY);
+		qmatrix.scale(m_maskPattern->width / static_cast<double>(m_maskPattern->getPattern()->width()), m_maskPattern->height / static_cast<double>(m_maskPattern->getPattern()->height()));
+		if (m_maskPatternMirrorX)
+			qmatrix.scale(-1, 1);
+		if (m_maskPatternMirrorY)
+			qmatrix.scale(1, -1);
+		cairo_matrix_init(&matrix, qmatrix.m11(), qmatrix.m12(), qmatrix.m21(), qmatrix.m22(), qmatrix.dx(), qmatrix.dy());
+		cairo_matrix_invert(&matrix);
+		cairo_pattern_set_matrix(pat, &matrix);
+	}
+	cairo_restore(m_cr);
+	return pat;
+}
+
 void ScPainterEx_Cairo::fillPathHelper()
 {
 	cairo_save(m_cr);
@@ -457,14 +647,18 @@ void ScPainterEx_Cairo::fillPathHelper()
 		fillColor.getRgbF(&r, &g, &b);
 		if (m_maskMode > 0)
 		{
-			/*cairo_pattern_t *pat = getMaskPattern();
+			cairo_pattern_t *pat = getMaskPattern();
 			cairo_set_source_rgb(m_cr, r, g, b);
 			setRasterOp(m_blendModeFill);
 			cairo_clip_preserve(m_cr);
-			cairo_mask(m_cr, pat);
-			if ((maskMode == 2) || (maskMode == 4) || (maskMode == 5) || (maskMode == 6))
-				cairo_surface_destroy(imageMask);
-			cairo_pattern_destroy(pat);*/
+			if (pat)
+				cairo_mask(m_cr, pat);
+			if (m_imageMask)
+			{
+				cairo_surface_destroy(m_imageMask);
+				m_imageMask = nullptr;
+			}
+			cairo_pattern_destroy(pat);
 		}
 		else
 		{
@@ -479,7 +673,12 @@ void ScPainterEx_Cairo::fillPathHelper()
 	}
 	else if (m_fillMode == ScPainterExBase::Pattern)
 	{
-
+		// Pattern painting is emulated in ScPageOutput::drawPattern(),
+		// So we have nothing to do here
+	}
+	else if (m_fillMode == ScPainterExBase::Hatch)
+	{
+		drawHatch();
 	}
 	cairo_restore(m_cr);
 	cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
@@ -538,13 +737,36 @@ void ScPainterEx_Cairo::drawImage(ScImage *image, ScPainterExBase::ImageMode mod
 	QImage qImage(image->qImage());
 	if (m_convertToGray)
 		transformImage(qImage);
-	cairo_save(m_cr);
+
+	cairo_push_group(m_cr);
+	cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
 	cairo_set_fill_rule(m_cr, cairo_get_fill_rule(m_cr));
-	cairo_surface_t *image2 = cairo_image_surface_create_for_data ((uchar*)qImage.bits(), CAIRO_FORMAT_ARGB32, qImage.width(), qImage.height(), qImage.width()*4);
-	cairo_set_source_surface (m_cr, image2, 0, 0);
-	cairo_paint_with_alpha (m_cr, m_fillTrans);
-	cairo_surface_destroy (image2);
-	cairo_restore(m_cr);
+	cairo_surface_t* image2 = cairo_image_surface_create_for_data(qImage.bits(), CAIRO_FORMAT_RGB24, qImage.width(), qImage.height(), qImage.width() * 4);
+	cairo_surface_t* image3 = cairo_image_surface_create_for_data(qImage.bits(), CAIRO_FORMAT_ARGB32, qImage.width(), qImage.height(), qImage.width() * 4);
+	cairo_set_source_surface(m_cr, image2, 0, 0);
+	cairo_pattern_set_filter(cairo_get_source(m_cr), CAIRO_FILTER_GOOD);
+	cairo_mask_surface(m_cr, image3, 0, 0);
+	cairo_surface_destroy(image2);
+	cairo_surface_destroy(image3);
+	cairo_pop_group_to_source(m_cr);
+	cairo_pattern_set_filter(cairo_get_source(m_cr), CAIRO_FILTER_GOOD);
+	setRasterOp(m_blendModeFill);
+	if (m_maskMode > 0)
+	{
+		cairo_pattern_t* patM = getMaskPattern();
+		cairo_pattern_set_filter(patM, CAIRO_FILTER_GOOD);
+		if (patM)
+			cairo_mask(m_cr, patM);
+		if (m_imageMask)
+		{
+			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
+		cairo_pattern_destroy(patM);
+	}
+	else
+		cairo_paint_with_alpha(m_cr, m_fillTrans);
+	cairo_set_operator(m_cr, CAIRO_OPERATOR_OVER);
 }
 
 void ScPainterEx_Cairo::setupPolygon(const FPointArray *points, bool closed)
@@ -566,7 +788,7 @@ void ScPainterEx_Cairo::setupPolygon(const FPointArray *points, bool closed)
 		if (nPath)
 		{
 			np = points->point(poi);
-			if ((!first) && (closed) && (np4 == firstP))
+			if (!first && closed && (np4 == firstP))
 				cairo_close_path(m_cr);
 			moveTo(np.x(), np.y());
 			first = nPath = false;
@@ -598,7 +820,7 @@ void ScPainterEx_Cairo::drawPolyLine()
 	strokePath();
 }
 
-void ScPainterEx_Cairo::drawLine(FPoint start, FPoint end)
+void ScPainterEx_Cairo::drawLine(const FPoint& start, const FPoint& end)
 {
 	newPath();
 	moveTo(start.x(), start.y());
@@ -627,33 +849,30 @@ void ScPainterEx_Cairo::drawRect(double x, double y, double w, double h)
 	strokePath();
 }
 
-void ScPainterEx_Cairo::drawGradient(VGradientEx& gradient)
+void ScPainterEx_Cairo::drawGradient(const VGradientEx& gradient)
 {
-	QRect clipPathRect;
 	save();
 	setClipPath();
-	getClipPathDimensions(clipPathRect);
 	if (gradient.type() == VGradientEx::linear)
-		drawLinearGradient(gradient, clipPathRect);
+		drawLinearGradient(gradient);
 	else if (gradient.type() == VGradientEx::radial)
-		drawCircularGradient(gradient, clipPathRect);
+		drawCircularGradient(gradient);
 	else if (gradient.type() == VGradientEx::fourcolor)
-		drawFourColorGradient(clipPathRect);
+		drawFourColorGradient();
 	else if (gradient.type() == VGradientEx::diamond)
-		drawDiamondGradient(gradient, clipPathRect);
+		drawDiamondGradient(gradient);
 	else if (gradient.type() == VGradientEx::mesh)
-		drawMeshGradient(clipPathRect);
+		drawMeshGradient();
 	else if (gradient.type() == VGradientEx::freemesh)
-		drawFreeMeshGradient(clipPathRect);
+		drawFreeMeshGradient();
 	restore();
 }
 
-void ScPainterEx_Cairo::drawLinearGradient(VGradientEx& gradient, const QRect& rect)
+void ScPainterEx_Cairo::drawLinearGradient(const VGradientEx& gradient)
 {
-	int index = 0;
 	double r, g, b;
 	QList<VColorStopEx*> colorStops = gradient.colorStops();
-	VColorStopEx* stop = nullptr;
+	const VColorStopEx* stop = nullptr;
 	QColor color;
 
 	if (gradient.stops() < 2)
@@ -669,7 +888,7 @@ void ScPainterEx_Cairo::drawLinearGradient(VGradientEx& gradient, const QRect& r
 
 	bool   isFirst  = true;
 	double lastStop = 0.0;
-	for (int index = 0 ; index < gradient.stops(); index++)
+	for (int index = 0 ; index < gradient.stops(); ++index)
 	{
 		stop  = colorStops.at(index);
 		if ((lastStop == stop->rampPoint) && (!isFirst))
@@ -698,12 +917,11 @@ void ScPainterEx_Cairo::drawLinearGradient(VGradientEx& gradient, const QRect& r
 	cairo_pattern_destroy (pat);
 }
 
-void ScPainterEx_Cairo::drawCircularGradient(VGradientEx& gradient, const QRect& rect)
+void ScPainterEx_Cairo::drawCircularGradient(const VGradientEx& gradient)
 {
-	int offset = 0;
 	double r, g, b;
 	QList<VColorStopEx*> colorStops = gradient.colorStops();
-	VColorStopEx* stop = nullptr;
+	const VColorStopEx* stop = nullptr;
 	QColor color;
 
 	double x1  = gradient.origin().x();
@@ -749,12 +967,8 @@ void ScPainterEx_Cairo::drawCircularGradient(VGradientEx& gradient, const QRect&
 	cairo_pattern_destroy (pat);
 }
 
-void ScPainterEx_Cairo::drawFourColorGradient(const QRect& rect)
+void ScPainterEx_Cairo::drawFourColorGradient()
 {
-	cairo_pattern_t *pat = nullptr;
-	cairo_surface_t *img = nullptr;
-	cairo_t *cr = nullptr;
-	cairo_pattern_t *mpat = nullptr;
 	QColor color;
 
 	double p1x = m_gradPatchP1.x();
@@ -765,13 +979,15 @@ void ScPainterEx_Cairo::drawFourColorGradient(const QRect& rect)
 	double p3y = m_gradPatchP3.y();
 	double p4x = m_gradPatchP4.x();
 	double p4y = m_gradPatchP4.y();
-	img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, p3x, p3y);
-	cr = cairo_create(img);
+
+	cairo_surface_t* img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, p3x, p3y);
+	cairo_t* cr = cairo_create(img);
 	cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_set_tolerance(cr, 0.5);
+
 	double r, g, b, a;
-	mpat = cairo_pattern_create_mesh();
+	cairo_pattern_t* mpat = cairo_pattern_create_mesh();
 	cairo_mesh_pattern_begin_patch(mpat);
 	cairo_mesh_pattern_move_to(mpat, p1x, p1y);
 	cairo_mesh_pattern_line_to(mpat, p2x, p2y);
@@ -798,7 +1014,8 @@ void ScPainterEx_Cairo::drawFourColorGradient(const QRect& rect)
 	cairo_pattern_set_filter(mpat, CAIRO_FILTER_GOOD);
 	cairo_set_source(cr, mpat);
 	cairo_paint_with_alpha(cr, 1.0);
-	pat = cairo_pattern_create_for_surface(img);
+
+	cairo_pattern_t* pat = cairo_pattern_create_for_surface(img);
 	cairo_pattern_set_extend(pat, CAIRO_EXTEND_NONE);
 	cairo_pattern_set_filter(pat, CAIRO_FILTER_GOOD);
 
@@ -807,12 +1024,16 @@ void ScPainterEx_Cairo::drawFourColorGradient(const QRect& rect)
 
 	if (m_maskMode > 0)
 	{
-		/*cairo_pattern_t *patM = getMaskPattern();
+		cairo_pattern_t *patM = getMaskPattern();
 		setRasterOp(m_blendModeFill);
-		cairo_mask(m_cr, patM);
-		if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
-			cairo_surface_destroy(imageMask);
-		cairo_pattern_destroy (patM);*/
+		if (patM)
+			cairo_mask(m_cr, patM);
+		if (m_imageMask)
+		{
+			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
+		cairo_pattern_destroy (patM);
 	}
 	else
 	{
@@ -826,15 +1047,8 @@ void ScPainterEx_Cairo::drawFourColorGradient(const QRect& rect)
 	if (cr) cairo_destroy(cr);
 }
 
-void ScPainterEx_Cairo::drawDiamondGradient(VGradientEx& gradient, const QRect& rect)
+void ScPainterEx_Cairo::drawDiamondGradient(const VGradientEx& gradient)
 {
-	cairo_pattern_t *pat = nullptr;
-	cairo_surface_t *img = nullptr;
-	cairo_t *cr = nullptr;
-	cairo_pattern_t *mpat = nullptr;
-	VColorStopEx* stop = nullptr;
-	QColor color;
-
 	double p1x = m_gradControlP1.x();
 	double p1y = m_gradControlP1.y();
 	double p2x = m_gradControlP2.x();
@@ -843,12 +1057,15 @@ void ScPainterEx_Cairo::drawDiamondGradient(VGradientEx& gradient, const QRect&
 	double p3y = m_gradControlP3.y();
 	double p4x = m_gradControlP4.x();
 	double p4y = m_gradControlP4.y();
-	img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, m_gradPatchP3.x(), m_gradPatchP3.y());
-	cr = cairo_create(img);
+
+	cairo_surface_t *img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, m_gradPatchP3.x(), m_gradPatchP3.y());
+	cairo_t *cr = cairo_create(img);
 	cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_set_tolerance(cr, 0.5);
+
 	double r, g, b, a;
+	const VColorStopEx* stop = nullptr;
 	QList<VColorStopEx*> colorStops = gradient.colorStops();
 	QList<QColor> qStopColors;
 	QList<double> qStopRampPoints;
@@ -863,7 +1080,7 @@ void ScPainterEx_Cairo::drawDiamondGradient(VGradientEx& gradient, const QRect&
 		sneu = s * shad / 100;
 		vneu = 255 - ((255 - v) * shad / 100);
 		qStopColor.setHsv(h, sneu, vneu);
-		qStopColor.setAlphaF(colorStops[offset]->opacity);
+		qStopColor.setAlphaF(stop->opacity);
 		if (offset == 0)
 		{
 			if (colorStops[offset]->rampPoint > 0)
@@ -876,11 +1093,11 @@ void ScPainterEx_Cairo::drawDiamondGradient(VGradientEx& gradient, const QRect&
 		qStopRampPoints.append(colorStops[offset]->rampPoint);
 	}
 	qStopColors.last().getRgbF(&r, &g, &b, &a);
-	QPointF centerP = QPointF(m_gradControlP5.x(), m_gradControlP5.y());
-	QLineF edge1 = QLineF(centerP, QPointF(p1x, p1y));
-	QLineF edge2 = QLineF(centerP, QPointF(p2x, p2y));
-	QLineF edge3 = QLineF(centerP, QPointF(p3x, p3y));
-	QLineF edge4 = QLineF(centerP, QPointF(p4x, p4y));
+	QPointF centerP(m_gradControlP5.x(), m_gradControlP5.y());
+	QLineF edge1(centerP, QPointF(p1x, p1y));
+	QLineF edge2(centerP, QPointF(p2x, p2y));
+	QLineF edge3(centerP, QPointF(p3x, p3y));
+	QLineF edge4(centerP, QPointF(p4x, p4y));
 	QPointF p1 = edge1.pointAt(colorStops.last()->rampPoint);
 	QPointF p2 = edge2.pointAt(colorStops.last()->rampPoint);
 	QPointF p3 = edge3.pointAt(colorStops.last()->rampPoint);
@@ -897,7 +1114,8 @@ void ScPainterEx_Cairo::drawDiamondGradient(VGradientEx& gradient, const QRect&
 	cairo_set_source_rgba(cr, 0, 0, 0, 1);
 	cairo_fill(cr);
 	cairo_set_operator(cr, CAIRO_OPERATOR_ADD);
-	mpat = cairo_pattern_create_mesh();
+
+	cairo_pattern_t *mpat = cairo_pattern_create_mesh();
 	for (int offset = 1 ; offset <  qStopRampPoints.count() ; offset++)
 	{
 		QLineF e1 = edge1;
@@ -1022,7 +1240,8 @@ void ScPainterEx_Cairo::drawDiamondGradient(VGradientEx& gradient, const QRect&
 	cairo_pattern_set_filter(mpat, CAIRO_FILTER_GOOD);
 	cairo_set_source(cr, mpat);
 	cairo_paint_with_alpha(cr, 1.0);
-	pat = cairo_pattern_create_for_surface(img);
+
+	cairo_pattern_t *pat = cairo_pattern_create_for_surface(img);
 	cairo_pattern_set_extend(pat, CAIRO_EXTEND_PAD);
 	cairo_pattern_set_filter(pat, CAIRO_FILTER_GOOD);
 
@@ -1031,12 +1250,16 @@ void ScPainterEx_Cairo::drawDiamondGradient(VGradientEx& gradient, const QRect&
 
 	if (m_maskMode > 0)
 	{
-		/*cairo_pattern_t *patM = getMaskPattern();
+		cairo_pattern_t *patM = getMaskPattern();
 		setRasterOp(m_blendModeFill);
-		cairo_mask(m_cr, patM);
-		if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
-			cairo_surface_destroy(imageMask);
-		cairo_pattern_destroy (patM);*/
+		if (patM)
+			cairo_mask(m_cr, patM);
+		if (m_imageMask)
+		{
+			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
+		cairo_pattern_destroy (patM);
 	}
 	else
 	{
@@ -1050,32 +1273,27 @@ void ScPainterEx_Cairo::drawDiamondGradient(VGradientEx& gradient, const QRect&
 	if (cr) cairo_destroy(cr);
 }
 
-void ScPainterEx_Cairo::drawMeshGradient(const QRect& rect)
+void ScPainterEx_Cairo::drawMeshGradient()
 {
-	cairo_pattern_t *pat = nullptr;
-	cairo_surface_t *img = nullptr;
-	cairo_t *cr = nullptr;
-	cairo_pattern_t *mpat = nullptr;
-	VColorStopEx* stop = nullptr;
-	QColor color;
-
 	double p3x = m_gradPatchP3.x();
 	double p3y = m_gradPatchP3.y();
-	img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, p3x, p3y);
-	cr  = cairo_create(img);
+
+	cairo_surface_t* img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, p3x, p3y);
+	cairo_t* cr = cairo_create(img);
 	cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_set_tolerance(cr, 0.5);
+
 	double r, g, b, a;
-	mpat = cairo_pattern_create_mesh();
-	for (int grow = 0; grow < m_meshGradientArray.count()-1; grow++)
+	cairo_pattern_t* mpat = cairo_pattern_create_mesh();
+	for (int grow = 0; grow < m_meshGradientArray.count() - 1; ++grow)
 	{
-		for (int gcol = 0; gcol < m_meshGradientArray[grow].count()-1; gcol++)
+		for (int gcol = 0; gcol < m_meshGradientArray[grow].count() - 1; ++gcol)
 		{
 			MeshPoint mp1 = m_meshGradientArray[grow][gcol];
-			MeshPoint mp2 = m_meshGradientArray[grow][gcol+1];
-			MeshPoint mp3 = m_meshGradientArray[grow+1][gcol+1];
-			MeshPoint mp4 = m_meshGradientArray[grow+1][gcol];
+			MeshPoint mp2 = m_meshGradientArray[grow][gcol + 1];
+			MeshPoint mp3 = m_meshGradientArray[grow + 1][gcol + 1];
+			MeshPoint mp4 = m_meshGradientArray[grow + 1][gcol];
 			cairo_mesh_pattern_begin_patch(mpat);
 			cairo_mesh_pattern_move_to(mpat, mp1.gridPoint.x(), mp1.gridPoint.y());
 			cairo_mesh_pattern_curve_to(mpat, mp1.controlRight.x(), mp1.controlRight.y(), mp2.controlLeft.x(), mp2.controlLeft.y(), mp2.gridPoint.x(), mp2.gridPoint.y());
@@ -1100,7 +1318,8 @@ void ScPainterEx_Cairo::drawMeshGradient(const QRect& rect)
 	cairo_pattern_set_filter(mpat, CAIRO_FILTER_BEST);
 	cairo_set_source(cr, mpat);
 	cairo_paint_with_alpha(cr, 1.0);
-	pat = cairo_pattern_create_for_surface(img);
+
+	cairo_pattern_t* pat = cairo_pattern_create_for_surface(img);
 	cairo_pattern_set_extend(pat, CAIRO_EXTEND_NONE);
 	cairo_pattern_set_filter(pat, CAIRO_FILTER_BEST);
 
@@ -1109,12 +1328,16 @@ void ScPainterEx_Cairo::drawMeshGradient(const QRect& rect)
 
 	if (m_maskMode > 0)
 	{
-		/*cairo_pattern_t *patM = getMaskPattern();
+		cairo_pattern_t *patM = getMaskPattern();
 		setRasterOp(m_blendModeFill);
-		cairo_mask(m_cr, patM);
-		if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
-			cairo_surface_destroy(imageMask);
-		cairo_pattern_destroy (patM);*/
+		if (patM)
+			cairo_mask(m_cr, patM);
+		if (m_imageMask)
+		{
+			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
+		cairo_pattern_destroy (patM);
 	}
 	else
 	{
@@ -1128,24 +1351,19 @@ void ScPainterEx_Cairo::drawMeshGradient(const QRect& rect)
 	if (cr) cairo_destroy(cr);
 }
 
-void ScPainterEx_Cairo::drawFreeMeshGradient(const QRect& rect)
+void ScPainterEx_Cairo::drawFreeMeshGradient()
 {
-	cairo_pattern_t *pat = nullptr;
-	cairo_surface_t *img = nullptr;
-	cairo_t *cr = nullptr;
-	cairo_pattern_t *mpat = nullptr;
-	VColorStopEx* stop = nullptr;
-	QColor color;
-
 	double p3x = m_gradPatchP3.x();
 	double p3y = m_gradPatchP3.y();
-	img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, p3x, p3y);
-	cr = cairo_create(img);
+
+	cairo_surface_t* img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, p3x, p3y);
+	cairo_t* cr = cairo_create(img);
 	cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
 	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 	cairo_set_tolerance(cr, 0.5);
+
 	double r, g, b, a;
-	mpat = cairo_pattern_create_mesh();
+	cairo_pattern_t* mpat = cairo_pattern_create_mesh();
 	for (int col = 0; col < m_meshGradientPatches.count(); col++)
 	{
 		meshGradientPatch patch = m_meshGradientPatches[col];
@@ -1176,7 +1394,8 @@ void ScPainterEx_Cairo::drawFreeMeshGradient(const QRect& rect)
 	cairo_pattern_set_filter(mpat, CAIRO_FILTER_BEST);
 	cairo_set_source(cr, mpat);
 	cairo_paint_with_alpha(cr, 1.0);
-	pat = cairo_pattern_create_for_surface(img);
+
+	cairo_pattern_t* pat = cairo_pattern_create_for_surface(img);
 	cairo_pattern_set_extend(pat, CAIRO_EXTEND_NONE);
 	cairo_pattern_set_filter(pat, CAIRO_FILTER_BEST);
 	
@@ -1185,12 +1404,16 @@ void ScPainterEx_Cairo::drawFreeMeshGradient(const QRect& rect)
 
 	if (m_maskMode > 0)
 	{
-		/*cairo_pattern_t *patM = getMaskPattern();
+		cairo_pattern_t *patM = getMaskPattern();
 		setRasterOp(m_blendModeFill);
-		cairo_mask(m_cr, patM);
-		if ((m_maskMode == 2) || (m_maskMode == 4) || (m_maskMode == 5) || (m_maskMode == 6))
-			cairo_surface_destroy(imageMask);
-		cairo_pattern_destroy (patM);*/
+		if (patM)
+			cairo_mask(m_cr, patM);
+		if (m_imageMask)
+		{
+			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
+		cairo_pattern_destroy (patM);
 	}
 	else
 	{
@@ -1204,7 +1427,127 @@ void ScPainterEx_Cairo::drawFreeMeshGradient(const QRect& rect)
 	if (cr) cairo_destroy(cr);
 }
 
-void ScPainterEx_Cairo::strokeGradient(VGradientEx& gradient)
+void ScPainterEx_Cairo::drawHatch()
+{
+	cairo_path_t* path = cairo_copy_path(m_cr);
+
+	cairo_surface_t *img = cairo_surface_create_similar(cairo_get_target(m_cr), CAIRO_CONTENT_COLOR_ALPHA, m_hatchWidth, m_hatchHeight);
+	cairo_t* cr = cairo_create(img);
+
+	cairo_new_path(cr);
+	cairo_append_path(cr, path);
+	cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
+	cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
+
+	if (m_hatchUseBackground)
+	{
+		double r2, g2, b2;
+		QColor hatchBackground = transformColor(m_hatchBackground, 1.0);
+		hatchBackground.getRgbF(&r2, &g2, &b2);
+		cairo_set_source_rgb(cr, r2, g2, b2);
+		cairo_fill_preserve(cr);
+	}
+
+	double r, g, b;
+	QColor hatchForeground = transformColor(m_hatchForeground, 1.0);
+	hatchForeground.getRgbF(&r, &g, &b);
+	cairo_set_line_width(cr, 1);
+	cairo_set_source_rgb(cr, r, g, b);
+	cairo_translate(cr, m_hatchWidth / 2.0, m_hatchHeight / 2.0);
+
+	double lineLen = sqrt((m_hatchWidth / 2.0) * (m_hatchWidth / 2.0) + (m_hatchHeight / 2.0) * (m_hatchHeight / 2.0));
+	double dist = 0.0;
+	while (dist < lineLen)
+	{
+		cairo_save(cr);
+		cairo_rotate(cr, -m_hatchAngle * 3.1415927 / 180.0);
+		cairo_new_path(cr);
+		cairo_move_to(cr, -lineLen, dist);
+		cairo_line_to(cr, lineLen, dist);
+		cairo_stroke(cr);
+		if (dist > 0)
+		{
+			cairo_new_path(cr);
+			cairo_move_to(cr, -lineLen, -dist);
+			cairo_line_to(cr, lineLen, -dist);
+			cairo_stroke(cr);
+		}
+		cairo_restore(cr);
+		if ((m_hatchType == 1) || (m_hatchType == 2))
+		{
+			cairo_save(cr);
+			cairo_rotate(cr, (-m_hatchAngle + 90) * 3.1415927 / 180.0);
+			cairo_new_path(cr);
+			cairo_move_to(cr, -lineLen, dist);
+			cairo_line_to(cr, lineLen, dist);
+			cairo_stroke(cr);
+			if (dist > 0)
+			{
+				cairo_new_path(cr);
+				cairo_move_to(cr, -lineLen, -dist);
+				cairo_line_to(cr, lineLen, -dist);
+				cairo_stroke(cr);
+			}
+			cairo_restore(cr);
+		}
+		if (m_hatchType == 2)
+		{
+			cairo_save(cr);
+			cairo_rotate(cr, (-m_hatchAngle + 45) * 3.1415927 / 180.0);
+			double dDist = dist * sqrt(2.0);
+			cairo_new_path(cr);
+			cairo_move_to(cr, -lineLen, dDist);
+			cairo_line_to(cr, lineLen, dDist);
+			cairo_stroke(cr);
+			if (dist > 0)
+			{
+				cairo_new_path(cr);
+				cairo_move_to(cr, -lineLen, -dDist);
+				cairo_line_to(cr, lineLen, -dDist);
+				cairo_stroke(cr);
+			}
+			cairo_restore(cr);
+		}
+		dist += m_hatchDistance;
+	}
+
+	cairo_pattern_t* pat = cairo_pattern_create_for_surface(img);
+	cairo_pattern_set_extend(pat, CAIRO_EXTEND_NONE);
+	cairo_pattern_set_filter(pat, CAIRO_FILTER_BEST);
+
+	cairo_set_source(m_cr, pat);
+	cairo_clip_preserve(m_cr);
+
+	setRasterOp(m_blendModeFill);
+	if (m_maskMode > 0)
+	{
+		cairo_pattern_t* patM = getMaskPattern();
+		cairo_pattern_set_filter(patM, CAIRO_FILTER_FAST);
+		if (patM)
+			cairo_mask(m_cr, patM);
+		if (m_imageMask)
+		{
+			cairo_surface_destroy(m_imageMask);
+			m_imageMask = nullptr;
+		}
+		cairo_pattern_destroy(patM);
+	}
+	else
+		cairo_paint_with_alpha(m_cr, m_fillTrans);
+
+	if (pat)
+		cairo_pattern_destroy(pat);
+	if (cr)
+		cairo_destroy(cr);
+	if (img)
+		cairo_surface_destroy(img);
+
+	newPath();
+	cairo_append_path(m_cr, path);
+	cairo_path_destroy(path);
+}
+
+void ScPainterEx_Cairo::strokeGradient(const VGradientEx& gradient)
 {
 	save();
 	if (gradient.type() == VGradientEx::linear)
@@ -1214,23 +1557,20 @@ void ScPainterEx_Cairo::strokeGradient(VGradientEx& gradient)
 	restore();
 }
 
-void ScPainterEx_Cairo::strokeLinearGradient(VGradientEx& gradient)
+void ScPainterEx_Cairo::strokeLinearGradient(const VGradientEx& gradient)
 {
-	cairo_pattern_t *pat = nullptr;
-	double r, g, b, lastPoint = 0.0;
+	double r, g, b;
 	double x1 = gradient.origin().x();
 	double y1 = gradient.origin().y();
 	double x2 = gradient.vector().x();
 	double y2 = gradient.vector().y();
-	double fx = gradient.focalPoint().x();
-	double fy = gradient.focalPoint().y();
 	QList<VColorStopEx*> colorStops = gradient.colorStops();
-	VColorStopEx* stop = nullptr;
+	const VColorStopEx* stop = nullptr;
 	QColor color;
 
 	cairo_push_group(m_cr);
 
-	pat = cairo_pattern_create_linear (x1, y1,  x2, y2);
+	cairo_pattern_t* pat = cairo_pattern_create_linear (x1, y1,  x2, y2);
 	cairo_pattern_set_extend(pat, CAIRO_EXTEND_PAD);
 	cairo_pattern_set_filter(pat, CAIRO_FILTER_GOOD);
 
@@ -1266,10 +1606,9 @@ void ScPainterEx_Cairo::strokeLinearGradient(VGradientEx& gradient)
 	cairo_paint_with_alpha (m_cr, m_strokeTrans);
 }
 
-void ScPainterEx_Cairo::strokeCircularGradient(VGradientEx& gradient)
+void ScPainterEx_Cairo::strokeCircularGradient(const VGradientEx& gradient)
 {
-	cairo_pattern_t *pat = nullptr;
-	double r, g, b, lastPoint = 0.0;
+	double r, g, b;
 	double x1 = gradient.origin().x();
 	double y1 = gradient.origin().y();
 	double x2 = gradient.vector().x();
@@ -1277,12 +1616,12 @@ void ScPainterEx_Cairo::strokeCircularGradient(VGradientEx& gradient)
 	double fx = gradient.focalPoint().x();
 	double fy = gradient.focalPoint().y();
 	QList<VColorStopEx*> colorStops = gradient.colorStops();
-	VColorStopEx* stop = nullptr;
+	const VColorStopEx* stop = nullptr;
 	QColor color;
 
 	cairo_push_group(m_cr);
 
-	pat = cairo_pattern_create_radial (fx, fy, 0, x1, y1, sqrt(pow(x2 - x1, 2) + pow(y2 - y1,2)));
+	cairo_pattern_t* pat = cairo_pattern_create_radial (fx, fy, 0, x1, y1, sqrt(pow(x2 - x1, 2) + pow(y2 - y1,2)));
 	cairo_pattern_set_extend(pat, CAIRO_EXTEND_PAD);
 	cairo_pattern_set_filter(pat, CAIRO_FILTER_GOOD);
 
