@@ -142,30 +142,30 @@ public:
 	void setMargins(MarginStruct& newMargins) { m_docPrefsData.docSetupPrefs.margins = newMargins; }
 	double pageGapHorizontal() const { return m_docPrefsData.displayPrefs.pageGapHorizontal; }
 	double pageGapVertical() const { return m_docPrefsData.displayPrefs.pageGapVertical; }
-	void setPageGapHorizontal(double h) { m_docPrefsData.displayPrefs.pageGapHorizontal=h; }
-	void setPageGapVertical(double v) { m_docPrefsData.displayPrefs.pageGapVertical=v; }
+	void setPageGapHorizontal(double h) { m_docPrefsData.displayPrefs.pageGapHorizontal = h; }
+	void setPageGapVertical(double v) { m_docPrefsData.displayPrefs.pageGapVertical = v; }
 	const QList<PageSet>& pageSets() const { return m_docPrefsData.pageSets; }
 	void setPageSetFirstPage(int layout, int fp);
 	void clearPageSets() { m_docPrefsData.pageSets.clear(); }
 	void appendToPageSets(const PageSet& ps) { m_docPrefsData.pageSets.append(ps); }
-	void setPaperColor(const QColor &c) { m_docPrefsData.displayPrefs.paperColor=c; }
+	void setPaperColor(const QColor &c) { m_docPrefsData.displayPrefs.paperColor = c; }
 	const QColor& paperColor() const { return m_docPrefsData.displayPrefs.paperColor; }
 	bool hyphAutomatic() const { return m_docPrefsData.hyphPrefs.Automatic; }
 	bool hyphAutoCheck() const { return m_docPrefsData.hyphPrefs.AutoCheck; }
-	void setHyphAutomatic(bool b) { m_docPrefsData.hyphPrefs.Automatic=b; }
-	void setHyphAutoCheck(bool b) { m_docPrefsData.hyphPrefs.AutoCheck=b; }
+	void setHyphAutomatic(bool b) { m_docPrefsData.hyphPrefs.Automatic = b; }
+	void setHyphAutoCheck(bool b) { m_docPrefsData.hyphPrefs.AutoCheck = b; }
 	bool autoSave() const { return m_docPrefsData.docSetupPrefs.AutoSave; }
-	int autoSaveTime() const  { return m_docPrefsData.docSetupPrefs.AutoSaveTime; }
-	int autoSaveCount() const  { return m_docPrefsData.docSetupPrefs.AutoSaveCount; }
-	bool autoSaveKeep() const  { return m_docPrefsData.docSetupPrefs.AutoSaveKeep; }
-	bool autoSaveInDocDir() const  { return m_docPrefsData.docSetupPrefs.AutoSaveLocation; }
+	int autoSaveTime() const { return m_docPrefsData.docSetupPrefs.AutoSaveTime; }
+	int autoSaveCount() const { return m_docPrefsData.docSetupPrefs.AutoSaveCount; }
+	bool autoSaveKeep() const { return m_docPrefsData.docSetupPrefs.AutoSaveKeep; }
+	bool autoSaveInDocDir() const { return m_docPrefsData.docSetupPrefs.AutoSaveLocation; }
 	QString autoSaveDir() const { return m_docPrefsData.docSetupPrefs.AutoSaveDir; }
-	bool autoSaveClockDisplay() const  { return m_docPrefsData.displayPrefs.showAutosaveClockOnCanvas; }
-	void setAutoSave(bool b) { m_docPrefsData.docSetupPrefs.AutoSave=b; }
-	void setAutoSaveTime(int i) { m_docPrefsData.docSetupPrefs.AutoSaveTime=i; }
-	void setAutoSaveCount(int i) { m_docPrefsData.docSetupPrefs.AutoSaveCount=i; }
-	void setAutoSaveKeep(bool i) { m_docPrefsData.docSetupPrefs.AutoSaveKeep=i; }
-	void setAutoSaveInDocDir(bool i) { m_docPrefsData.docSetupPrefs.AutoSaveLocation=i; }
+	bool autoSaveClockDisplay() const { return m_docPrefsData.displayPrefs.showAutosaveClockOnCanvas; }
+	void setAutoSave(bool b) { m_docPrefsData.docSetupPrefs.AutoSave = b; }
+	void setAutoSaveTime(int i) { m_docPrefsData.docSetupPrefs.AutoSaveTime = i; }
+	void setAutoSaveCount(int i) { m_docPrefsData.docSetupPrefs.AutoSaveCount = i; }
+	void setAutoSaveKeep(bool i) { m_docPrefsData.docSetupPrefs.AutoSaveKeep = i; }
+	void setAutoSaveInDocDir(bool i) { m_docPrefsData.docSetupPrefs.AutoSaveLocation = i; }
 	void setAutoSaveDir(const QString& autoDaveDir) { m_docPrefsData.docSetupPrefs.AutoSaveDir = autoDaveDir; }
 	//FIXME (maybe) :non const, the loaders make a mess here
 	PDFOptions& pdfOptions() { return m_docPrefsData.pdfPrefs; }
@@ -173,12 +173,12 @@ public:
 	ObjAttrVector& itemAttributes() { return m_docPrefsData.itemAttrPrefs.defaultItemAttributes; }
 	const ObjAttrVector& itemAttributes() const { return m_docPrefsData.itemAttrPrefs.defaultItemAttributes; }
 
-	void setItemAttributes(ObjAttrVector& oav) { m_docPrefsData.itemAttrPrefs.defaultItemAttributes=oav;}
+	void setItemAttributes(ObjAttrVector& oav) { m_docPrefsData.itemAttrPrefs.defaultItemAttributes = oav; }
 	void clearItemAttributes() { m_docPrefsData.itemAttrPrefs.defaultItemAttributes.clear(); }
 	void appendToItemAttributes(const ObjectAttribute& oa) { m_docPrefsData.itemAttrPrefs.defaultItemAttributes.append(oa); }
 
 	ToCSetupVector& tocSetups() { return m_docPrefsData.tocPrefs.defaultToCSetups; }
-	void setTocSetups(ToCSetupVector& tsv) { m_docPrefsData.tocPrefs.defaultToCSetups=tsv; }
+	void setTocSetups(ToCSetupVector& tsv) { m_docPrefsData.tocPrefs.defaultToCSetups = tsv; }
 	void clearTocSetups() { m_docPrefsData.tocPrefs.defaultToCSetups.clear(); }
 	void appendToTocSetups(const ToCSetup& ts) { m_docPrefsData.tocPrefs.defaultToCSetups.append(ts); }
 
@@ -223,6 +223,7 @@ public:
 	ColorPrefs& colorPrefs() { return m_docPrefsData.colorPrefs; }
 	CMSData& cmsSettings() { return m_docPrefsData.colorPrefs.DCMSset; }
 	DocumentInformation& documentInfo() { return m_docPrefsData.docInfo; }
+	HyphenatorPrefs& hyphenatorPrefs() { return m_docPrefsData.hyphPrefs; }
 	void setDocumentInfo(DocumentInformation di) { m_docPrefsData.docInfo = di; }
 	DocumentSectionMap& sections() { return m_docPrefsData.docSectionMap; }
 	void setSections(DocumentSectionMap dsm) { m_docPrefsData.docSectionMap = std::move(dsm); }
@@ -233,7 +234,7 @@ public:
 
 	// Add, delete and move pages
 	
-	ScPage* addPage(int pageNumber, const QString& masterPageName=QString(), bool addAutoFrame=false);
+	ScPage* addPage(int pageNumber, const QString& masterPageName = QString(), bool addAutoFrame = false);
 	void deletePage(int);
 	//! @brief Add a master page with this function, do not use addPage
 	ScPage* addMasterPage(int, const QString&);
@@ -290,7 +291,7 @@ public:
 	 * @param activate the layer active
 	 * @return Number of the layer created
 	 */
-	int addLayer(const QString& layerName, bool activate=false);
+	int addLayer(const QString& layerName, bool activate = false);
 	/**
 	 * @brief Copies a layer from the current document
 	 * @param layerIDToCopy source layer
@@ -309,13 +310,13 @@ public:
 	 * @brief Return the number of the current layer
 	 * @return Active layer number
 	 */
-	int activeLayer();
+	int activeLayer() const;
 
 	/**
 	 * @brief Return the name of the current layer
 	 * @return Name of the layer
 	 */
-	const QString& activeLayerName();
+	const QString& activeLayerName() const;
 	/**
 	 * @brief Set the active layer via the layer number
 	 * @param layerToActivate Number of the layer
@@ -624,7 +625,7 @@ public:
 	QList<int> getSortedTableStyleList() const;
 	QList<int> getSortedCellStyleList() const;
 	
-	void redefineStyles(const StyleSet<ParagraphStyle>& newStyles, bool removeUnused=false);
+	void redefineStyles(const StyleSet<ParagraphStyle>& newStyles, bool removeUnused = false);
 	/**
 	 * @brief Remove any reference to old styles and replace with new name. This needs to be
 	 *        called when a style was removed. New name may be "".
@@ -651,7 +652,7 @@ public:
 
 	const CharStyle& charStyle(const QString& name) const { return m_docCharStyles.get(name); }
 	const StyleSet<CharStyle>& charStyles() const { return m_docCharStyles; }
-	void redefineCharStyles(const StyleSet<CharStyle>& newStyles, bool removeUnused=false);
+	void redefineCharStyles(const StyleSet<CharStyle>& newStyles, bool removeUnused = false);
 	/**
 	 * @brief Remove any reference to old styles and replace with new name. This needs to be
 	 *        called when a style was removed. New name may be "".
@@ -953,7 +954,7 @@ public:
 	/**
 	 * @brief Item type conversion functions
 	 */
-	PageItem* convertItemTo(PageItem *currItem, PageItem::ItemType newType, PageItem* secondaryItem=nullptr);
+	PageItem* convertItemTo(PageItem* currItem, PageItem::ItemType newType, PageItem* secondaryItem = nullptr);
 	
 	/**
 	 * @brief The page number of the current page
@@ -999,7 +1000,7 @@ public:
 	 * @brief Add a section to the document sections list
 	 * Set number to -1 to add in the default section if the map is empty
 	 */
-	void addSection(int number=0, const QString& name=QString(), const uint fromindex=0, const uint toindex=0, const  NumFormat type=Type_1_2_3, const uint sectionstartindex=0, bool reversed=false, bool active=true, const QChar fillChar=QChar(), int fieldWidth=0);
+	void addSection(int number = 0, const QString& name = QString(), const uint fromindex = 0, const uint toindex = 0, const  NumFormat type = Type_1_2_3, const uint sectionstartindex = 0, bool reversed = false, bool active = true, const QChar fillChar = QChar(), int fieldWidth = 0);
 	/**
 	 * @brief Delete a section from the document sections list
 	 */
@@ -1034,7 +1035,7 @@ public:
 	 * @param location 
 	 * @param count 
 	 */
-	void addPageToSection(uint otherPageIndex, uint location, uint count=1);
+	void addPageToSection(uint otherPageIndex, uint location, uint count = 1);
 	/**
 	 * 
 	 * @param pageIndex 
@@ -1053,7 +1054,7 @@ public:
 	/**
 	 * Update annotation links when a page is added
 	 */
-	void addPageToAnnotLinks(int otherPageIndex, int location, int count=1);
+	void addPageToAnnotLinks(int otherPageIndex, int location, int count = 1);
 
 	/**
 	 * Update annotation links when a page is removed
@@ -1256,7 +1257,7 @@ public:
 	void moveGroup(double x, double y, Selection* customSelection = nullptr);
 	void rotateGroup(double angle, Selection* customSelection = nullptr);
 	void rotateGroup(double angle, const FPoint& RCenter, Selection* customSelection = nullptr);
-	void scaleGroup(double scx, double scy, bool scaleText=true, Selection* customSelection = nullptr, bool scaleLine = false);
+	void scaleGroup(double scx, double scy, bool scaleText = true, Selection* customSelection = nullptr, bool scaleLine = false);
 	//! \brief Get a list of frames of certain type
 	QHash<PageItem*, QString> getDocItemNames(PageItem::ItemType itemType);
 	//! \brief Returns a serializer for this document
@@ -1282,7 +1283,7 @@ public:
 	void checkItemForFrames(PageItem *it, int fIndex);
 	bool hasPreflightErrors();
 	QFileDevice::Permissions filePermissions() { return m_docFilePermissions; }
-	void saveFilePermissions(QFileDevice::Permissions p) { m_docFilePermissions=p; }
+	void saveFilePermissions(QFileDevice::Permissions p) { m_docFilePermissions = p; }
 
 protected:
 	void addSymbols();
@@ -1521,10 +1522,10 @@ public slots:
 	//FIXME : change to process a selection
 	void item_setFrameShape(PageItem* item, int frameType, int count, double* points); 
 
-	void itemSelection_ClearItem(Selection* customSelection = nullptr, bool useWarning=false);
+	void itemSelection_ClearItem(Selection* customSelection = nullptr, bool useWarning = false);
 	void itemSelection_TruncateItem(Selection* customSelection = nullptr);
 	//! Delete the items in the current selection. When force is true, we do not warn the user and make SE happy too. Force is used from @sa Page::restorePageItemCreation
-	void itemSelection_DeleteItem(Selection* customSelection = nullptr, bool forceDeletion=false);
+	void itemSelection_DeleteItem(Selection* customSelection = nullptr, bool forceDeletion = false);
 	void itemSelection_SetItemFillTransparency(double t, Selection* customSelection = nullptr);
 	void itemSelection_SetHyphenWordMin(int wordMin, Selection* customSelection = nullptr);
 	void itemSelection_SetHyphenConsecutiveLines(int consecutiveLines, Selection* customSelection = nullptr);
@@ -1532,9 +1533,9 @@ public slots:
 	void itemSelection_SetItemLineTransparency(double t, Selection* customSelection = nullptr);
 	void itemSelection_SetItemFillBlend(int t);
 	void itemSelection_SetItemLineBlend(int t);
-	void itemSelection_SetLineGradient(VGradient& newGradient, Selection* customSelection = nullptr);
-	void itemSelection_SetFillGradient(VGradient& newGradient, Selection* customSelection = nullptr);
-	void itemSelection_SetMaskGradient(VGradient& newGradient, Selection* customSelection = nullptr);
+	void itemSelection_SetLineGradient(const VGradient& newGradient, Selection* customSelection = nullptr);
+	void itemSelection_SetFillGradient(const VGradient& newGradient, Selection* customSelection = nullptr);
+	void itemSelection_SetMaskGradient(const VGradient& newGradient, Selection* customSelection = nullptr);
 	void itemSelection_SetOverprint(bool overprint, Selection* customSelection = nullptr);
 	void itemSelection_ApplyImageEffects(ScImageEffectList& newEffectList, Selection* customSelection = nullptr);
 	void itemSelection_FlipH(Selection* customSelection = nullptr);
@@ -1567,13 +1568,13 @@ public slots:
 	void bringItemSelectionToFront();
 	void itemSelection_LowerItem();
 	void itemSelection_RaiseItem();
-	void itemSelection_DistributeDistH(bool usingDistance=false, double distance=0.0, bool reverseDistribute=false);
-	void itemSelection_DistributeAcrossPage(bool useMargins=false);
+	void itemSelection_DistributeDistH(bool usingDistance = false, double distance = 0.0, bool reverseDistribute = false);
+	void itemSelection_DistributeAcrossPage(bool useMargins = false);
 	void itemSelection_DistributeRight();
 	void itemSelection_DistributeBottom();
 	void itemSelection_DistributeCenterH();
-	void itemSelection_DistributeDistV(bool usingDistance=false, double distance=0.0, bool reverseDistribute=false);
-	void itemSelection_DistributeDownPage(bool useMargins=false);
+	void itemSelection_DistributeDistV(bool usingDistance = false, double distance = 0.0, bool reverseDistribute = false);
+	void itemSelection_DistributeDownPage(bool useMargins = false);
 	void itemSelection_DistributeLeft();
 	void itemSelection_DistributeCenterV();
 	void itemSelection_DistributeTop();
@@ -1743,19 +1744,15 @@ public slots:
 	void removePict(const QString& name);
 
 // Marks and notes
-public:
 	/**
 	 * Explanation
 	 * master frame - text frame with marks for notes
 	 * notesframe - frame with notes
 	 * master & note mark - master is mark in "master" text, note mark is at beginning of note in noteframe
 	 */
-	
-	//return page where endnotesframe should be located depending of notes style range and location of master mark
-	const ScPage* page4EndNotes(NotesStyle* NS, PageItem* item);
-
 	//data handling structures
 private:
+	bool m_docUsesMarksAndNotes {false};
 	QList<Mark*> m_docMarksList;
 	QList<TextNote*> m_docNotesList;
 	//flags used for indicating needs of updates
@@ -1764,6 +1761,10 @@ private:
 	void multipleDuplicateByPage(const ItemMultipleDuplicateData& mdData, Selection& selection, QString& tooltip);
 
 public:
+	bool usesMarksAndNotes() const { return m_docUsesMarksAndNotes; }
+	void setUsesMarksAndNotes(bool b) { m_docUsesMarksAndNotes = b; }
+	//return page where endnotesframe should be located depending of notes style range and location of master mark
+	const ScPage* page4EndNotes(NotesStyle* NS, PageItem* item);
 	const QList<Mark*>& marksList() { return m_docMarksList; }
 	const QList<TextNote*>& notesList() { return m_docNotesList; }
 	QList<NotesStyle*> m_docNotesStylesList;
@@ -1793,7 +1794,7 @@ public:
 	//set cursor in text where given mark will be found
 	void setCursor2MarkPos(const Mark* mark);
 	//return false if mark was not found
-	bool eraseMark(Mark* mrk, bool fromText=false, PageItem* item = nullptr, bool force = false); //force is used only for deleting non-unique marks by MarksManager
+	bool eraseMark(Mark* mrk, bool fromText = false, PageItem* item = nullptr, bool force = false); //force is used only for deleting non-unique marks by MarksManager
 	void setUndoDelMark(Mark* mrk);
 	//invalidate all text frames where given mark will found
 	//useful spacially for variable text marks after changing its text definition
@@ -1813,7 +1814,7 @@ public:
 	PageItem_NoteFrame* createNoteFrame(PageItem_TextFrame* inFrame, NotesStyle *nStyle, int index = -1);
 	PageItem_NoteFrame* createNoteFrame(NotesStyle *nStyle, double x, double y, double w, double h, double w2, const QString& fill, const QString& outline);
 	//delete noteframe
-	void delNoteFrame(PageItem_NoteFrame *noteFrame, bool removeMarks=true, bool forceDeletion = true);
+	void delNoteFrame(PageItem_NoteFrame *noteFrame, bool removeMarks = true, bool forceDeletion = true);
 	//renumber notes for given notes style
 	//return true if doc needs update after changing numbers of notes
 	bool updateNotesNums(NotesStyle* nStyle);
@@ -1842,7 +1843,7 @@ public:
 
 	//finds mark position in text
 	//return true if mark was found, CPos is set for mark`s position
-	//if item==nullptr then search in all items and if mark is found than item is set
+	//if item == nullptr then search in all items and if mark is found than item is set
 	int findMarkCPos(const Mark* mrk, PageItem* &item, int start = 0) const;
 	QList<PageItem_NoteFrame*> m_docEndNotesFramesChanged;
 
