@@ -24,7 +24,7 @@
 
 using namespace icu;
 
-int GroupBox::pointToPosition(QPointF coord, const StoryText &story) const
+int GroupBox::pointToPosition(const QPointF& coord, const StoryText &story) const
 {
 	QPointF rel = coord - QPointF(m_x, m_y);
 	for (const Box *box : boxes())
@@ -39,11 +39,11 @@ int GroupBox::pointToPosition(QPointF coord, const StoryText &story) const
 
 	if (containsPoint(coord) && (m_boxes.count() > 0))
 	{
-		LineBox* firstLine = dynamic_cast<LineBox*>(m_boxes.first());
+		const LineBox* firstLine = dynamic_cast<LineBox*>(m_boxes.first());
 		if (firstLine && (coord.y() < firstLine->y()))
 			return firstLine->firstChar();
 
-		LineBox* lastLine = dynamic_cast<LineBox*>(m_boxes.last());
+		const LineBox* lastLine = dynamic_cast<LineBox*>(m_boxes.last());
 		if (lastLine && (coord.y() > lastLine->y() + lastLine->naturalHeight()))
 			return lastLine->lastChar() + 1;
 	}
@@ -102,7 +102,8 @@ void GroupBox::drawSelection(ScreenPainter *p, ITextContext *ctx) const
 double GroupBox::naturalHeight() const
 {
 	double nH = 0;
-	for (const Box* box : boxes()) {
+	for (const Box* box : boxes())
+	{
 		if (m_direction == D_Horizontal)
 			nH = qMax(m_naturalHeight, box->naturalHeight());
 		else
@@ -158,7 +159,7 @@ void GroupBox::justify(const ParagraphStyle& style)
 }
 #endif
 
-int LineBox::pointToPosition(QPointF coord, const StoryText &story) const
+int LineBox::pointToPosition(const QPointF& coord, const StoryText &story) const
 {
 	int position = GroupBox::pointToPosition(coord, story);
 	if (position < 0 && containsPoint(coord))
@@ -205,7 +206,7 @@ QLineF LineBox::positionToPoint(int pos, const StoryText& story) const
 	return result;
 }
 
-bool LineBox::containsPoint(QPointF coord) const
+bool LineBox::containsPoint(const QPointF& coord) const
 {
 	return QRectF(0, m_y, m_width, height()).contains(coord);
 }
@@ -463,7 +464,7 @@ void LineBox::justify(const ParagraphStyle& style)
 
 void PathLineBox::update()
 {
-	for (Box* box : boxes())
+	for (const Box* box : boxes())
 	{
 		m_firstChar = qMin(m_firstChar, box->firstChar());
 		m_lastChar = qMax(m_lastChar, box->lastChar());
@@ -692,7 +693,7 @@ void GlyphBox::render(TextLayoutPainter *p) const
 
 		if ((charStyle.effects() & ScStyle_Outline) && hasStrokeColor && ((charStyle.fontSize() * m_glyphRun.scaleV() * charStyle.outlineWidth() / 10000.0) != 0))
 		{
-			p->setStrokeWidth((charStyle.fontSize() * m_glyphRun.scaleV() * charStyle.outlineWidth() / 10000.0));
+			p->setStrokeWidth(charStyle.fontSize() * m_glyphRun.scaleV() * charStyle.outlineWidth() / 10000.0);
 			p->drawGlyphOutline(m_glyphRun, hasFillColor);
 		}
 		else if (hasFillColor)
@@ -748,18 +749,23 @@ void GlyphBox::render(TextLayoutPainter *p) const
 	p->restore();
 }
 
-int GlyphBox::pointToPosition(QPointF coord, const StoryText& story) const
+int GlyphBox::pointToPosition(const QPointF& coord, const StoryText& story) const
 {
 	if (firstChar() != lastChar())
 	{
 		BreakIterator *it = StoryText::getGraphemeIterator();
 		QString text(story.text(firstChar(), lastChar() - firstChar() + 1));
-		it->setText((const UChar*) text.utf16());
+		icu::UnicodeString unicodeStr((const UChar*) text.utf16());
+		it->setText(unicodeStr);
+
 		int count = 0;
 		while (it->next() != BreakIterator::DONE)
 			count++;
 		if (count == 0)
+		{
 			qFatal("GlyphBox::pointToPosition: divide by zero error");
+			return -1;
+		}
 
 		bool rtlLayout = m_glyphRun.hasFlag(ScLayout_RightToLeft);
 		double componentWidth = width() / count;
@@ -798,10 +804,12 @@ QLineF GlyphBox::positionToPoint(int pos, const StoryText& story) const
 	double xPos = 0.0;
 	if (firstChar() != lastChar())
 	{
-		int index = 0;
 		BreakIterator *it = StoryText::getGraphemeIterator();
 		QString text(story.text(firstChar(), lastChar() - firstChar() + 1));
-		it->setText((const UChar*) text.utf16());
+		icu::UnicodeString unicodeStr((const UChar*) text.utf16());
+		it->setText(unicodeStr);
+
+		int index = 0;
 		int count = 0;
 		while (it->next() != BreakIterator::DONE)
 		{
@@ -810,7 +818,10 @@ QLineF GlyphBox::positionToPoint(int pos, const StoryText& story) const
 				index = count;
 		}
 		if (count == 0)
+		{
 			qFatal("GlyphBox::positionToPoint: divide by zero error");
+			QLineF(x(), y(), x(), y() + height());
+		}
 
 		double componentWidth = width() / count;
 		if (m_glyphRun.hasFlag(ScLayout_RightToLeft))
@@ -831,22 +842,42 @@ QLineF GlyphBox::positionToPoint(int pos, const StoryText& story) const
 
 void ObjectBox::render(TextLayoutPainter *p) const
 {
-	p->save();
 	double oldX = m_object->xPos();
 	double oldY = m_object->yPos();
 	bool oldEM = m_object->isEmbedded;
-	//m_item->isEmbedded = false; // #14311: fix discrepancy of display between 1.5.1 and 1.5.2+
 	const CharStyle& charStyle = style();
-	p->translate(x(), y() - ascent());
+
+	double scaleH;
+	double scaleV;
 	if (m_glyphRun.hasFlag(ScLayout_DropCap))
-		p->setScale(m_glyphRun.scaleH(), m_glyphRun.scaleV());
+	{
+		scaleH = m_glyphRun.scaleH();
+		scaleV = m_glyphRun.scaleV();
+	}
 	else
-		p->setScale(charStyle.scaleH() / 1000.0, charStyle.scaleV() / 1000.0);
+	{
+		scaleH = charStyle.scaleH() / 1000.0;
+		scaleV = charStyle.scaleV() / 1000.0;
+	}
+
+	double lineWidth = m_object->visualLineWidth();
+	QTransform trans;
+	trans.translate(lineWidth / 2.0, lineWidth / 2.0);
+	trans.scale(scaleH, scaleV);
+	trans.rotate(m_object->rotation());
+	QSizeF objectSize = m_object->visualSize();
+	QRectF mappedRect = trans.mapRect(QRectF(-lineWidth / 2.0, -lineWidth / 2.0, objectSize.width(), objectSize.height()));
+	double dx = (mappedRect.left() < lineWidth / 2.0) ? -mappedRect.left() + lineWidth / 2.0 : 0.0;
+	double dy = (mappedRect.top() < lineWidth / 2.0) ? -mappedRect.top() + lineWidth / 2.0 : 0.0;
+
+	p->save();
+	p->translate(x(), y() - ascent());
+	p->translate(dx, dy);
+	p->setScale(scaleH, scaleV);
 	p->setMatrix(m_matrix);
 
 	m_object->setXPos(m_object->gXpos, true);
 	m_object->setYPos(m_object->gYpos, true);
-	//	m_item->setYPos((m_object->gHeight * (charStyle.scaleV() / 1000.0)) + m_object->gYpos, true);
 
 	if (charStyle.baselineOffset() != 0)
 	{
@@ -856,6 +887,9 @@ void ObjectBox::render(TextLayoutPainter *p) const
 
 	p->drawObject(m_object);
 
+	p->translate(-dx, -dy);
+	p->drawObjectDecoration(m_object);
+
 	m_object->setXPos(oldX, true);
 	m_object->setYPos(oldY, true);
 	m_object->isEmbedded = oldEM;
@@ -866,3 +900,17 @@ void ObjectBox::render(ScreenPainter *p, ITextContext *ctx) const
 {
 	render(p);
 }
+
+void ObjectBox::update()
+{
+	if (m_object)
+	{
+		m_naturalAscent = m_ascent;
+		m_naturalDescent = m_descent;
+	}
+	else
+	{
+		m_naturalAscent = m_glyphRun.ascent();
+		m_naturalDescent = m_glyphRun.descent();
+	}
+}
