@@ -245,7 +245,10 @@ void StoryText::moveCursorForward()
 	if (!it)
 		return;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	int pos = it->following(cursorPosition());
 	if (pos != BreakIterator::DONE)
 		setCursorPosition(pos);
@@ -257,7 +260,10 @@ void StoryText::moveCursorBackward()
 	if (!it)
 		return;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	int pos = it->preceding(cursorPosition());
 	if (pos != BreakIterator::DONE)
 		setCursorPosition(pos);
@@ -284,7 +290,11 @@ void StoryText::moveCursorWordLeft()
 	BreakIterator* it = getWordIterator();
 	if (!it)
 		return;
-	it->setText((const UChar*) plainText().utf16());
+
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	int pos = cursorPosition();
 	if (paragraphStyle().direction() == ParagraphStyle::RTL)
 	{
@@ -313,7 +323,10 @@ void StoryText::moveCursorWordRight()
 	if (!it)
 		return;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	int pos = cursorPosition();
 	if (paragraphStyle().direction() == ParagraphStyle::RTL)
 	{
@@ -389,7 +402,8 @@ int StoryText::indexOf(const QString &str, int from, Qt::CaseSensitivity cs, int
 	}
 	else
 	{
-		bool qCharIsDiacritic, curCharIsDiacritic;
+		bool qCharIsDiacritic;
+		bool curCharIsDiacritic;
 		int i = indexOf(ch, from, cs);
 		while (i >= 0 && i < (int) d->len)
 		{
@@ -399,8 +413,8 @@ int StoryText::indexOf(const QString &str, int from, Qt::CaseSensitivity cs, int
 			{
 				const QChar &qChar = qStr.at(index);
 				const QChar &curChar = d->at(index + diacriticsCounter + i)->ch;
-				qCharIsDiacritic   = SpecialChars::isArabicModifierLetter(qChar.unicode()) | (qChar.category() == QChar::Mark_NonSpacing);
-				curCharIsDiacritic = SpecialChars::isArabicModifierLetter(curChar.unicode()) | (curChar.category() == QChar::Mark_NonSpacing);
+				qCharIsDiacritic   = SpecialChars::isArabicModifierLetter(qChar.unicode()) || (qChar.category() == QChar::Mark_NonSpacing);
+				curCharIsDiacritic = SpecialChars::isArabicModifierLetter(curChar.unicode()) || (curChar.category() == QChar::Mark_NonSpacing);
 				if (qCharIsDiacritic || curCharIsDiacritic)
 				{
 					if (qCharIsDiacritic)
@@ -656,10 +670,10 @@ void StoryText::trim()
 	if (length() < 2)
 		return;
 	int posCount = 0;
-	int pos = static_cast<int>(length()) - 1;
-	for ( int i = static_cast<int>(length()) - 1; i >= 0; --i )
+	int pos = length() - 1;
+	for (int i = length() - 1; i >= 0; --i)
 	{
-		ScText *it = d->at(i);
+		const ScText *it = d->at(i);
 		if ((it->ch == SpecialChars::PARSEP) || (it->ch.isSpace()))
 		{
 			pos--;
@@ -672,7 +686,7 @@ void StoryText::trim()
 	{
 		ParagraphStyle pst = paragraphStyle(pos);
 		if (posCount > 1)
-			removeChars(pos+1, posCount-1);
+			removeChars(pos + 1, posCount - 1);
 		applyStyle(pos, pst);
 	}
 }
@@ -878,7 +892,7 @@ void StoryText::hyphenateWord(int pos, uint len, const char* hyphens)
 	assert(pos + signed(len) <= length());
 	
 //	QString dump("");
-	for (int i=pos; i < pos+signed(len); ++i)
+	for (int i = pos; i < pos + signed(len); ++i)
 	{
 //		dump += d->at(i)->ch;
 		if (hyphens && hyphens[i-pos] & 1)
@@ -905,7 +919,7 @@ void StoryText::insertObject(int pos, int ob)
 		pos += length()+1;
 
 	insertChars(pos, SpecialChars::OBJECT);
-	const_cast<StoryText *>(this)->d->at(pos)->embedded = ob;
+	this->d->at(pos)->embedded = ob;
 	m_doc->FrameItems[ob]->isEmbedded = true;   // this might not be enough...
 	m_doc->FrameItems[ob]->OwnPage = -1; // #10379: OwnPage is not meaningful for inline object
 }
@@ -932,7 +946,7 @@ void StoryText::replaceObject(int pos, int ob)
 		pos += length()+1;
 
 	replaceChar(pos, SpecialChars::OBJECT);
-	const_cast<StoryText *>(this)->d->at(pos)->embedded = ob;
+	this->d->at(pos)->embedded = ob;
 	m_doc->FrameItems[ob]->isEmbedded = true;   // this might not be enough...
 	m_doc->FrameItems[ob]->OwnPage = -1; // #10379: OwnPage is not meaningful for inline object
 }
@@ -954,9 +968,9 @@ QString StoryText::plainText() const
 	int len = length();
 	result.reserve(len);
 
-	StoryText* that(const_cast<StoryText*>(this));
-	for (int i = 0; i < len; ++i) {
-		ch = that->d->at(i)->ch;
+	for (int i = 0; i < len; ++i)
+	{
+		ch = d->at(i)->ch;
 		if (ch == SpecialChars::PARSEP)
 			ch = QLatin1Char('\n');
 		result += ch;
@@ -979,7 +993,7 @@ QChar StoryText::text(int pos) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	return const_cast<StoryText *>(this)->d->at(pos)->ch;
+	return d->at(pos)->ch;
 }
 
 QString StoryText::text(int pos, uint len) const
@@ -991,9 +1005,8 @@ QString StoryText::text(int pos, uint len) const
 	assert(pos + signed(len) <= length());
 
 	QString result;
-	StoryText* that(const_cast<StoryText*>(this));
-	for (int i = pos; i < pos+signed(len); ++i)
-		result += that->d->at(i)->ch;
+	for (int i = pos; i < pos + signed(len); ++i)
+		result += d->at(i)->ch;
 
 	return result;
 }
@@ -1027,8 +1040,7 @@ InlineFrame StoryText::object(int pos) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	StoryText* that = const_cast<StoryText *>(this);
-	return InlineFrame(that->d->at(pos)->embedded);
+	return InlineFrame(d->at(pos)->embedded);
 }
 
 
@@ -1063,7 +1075,9 @@ QString StoryText::word(int pos)
 	BreakIterator* it = getWordIterator();
 	if (it)
 	{
-		it->setText((const UChar*) plainText().utf16());
+		QString fullText = plainText();
+		icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+		it->setText(unicodeStr);
 		int end = it->following(pos);
 		return text(pos, end - pos);
 	}
@@ -1110,9 +1124,8 @@ bool StoryText::hasObject(int pos) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	StoryText* that = const_cast<StoryText *>(this);
-	if (that->d->at(pos)->ch == SpecialChars::OBJECT)
-		return that->d->at(pos)->hasObject(m_doc);
+	if (d->at(pos)->ch == SpecialChars::OBJECT)
+		return d->at(pos)->hasObject(m_doc);
 	return false;
 }
 
@@ -1125,8 +1138,7 @@ PageItem* StoryText::getItem(int pos) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	StoryText* that = const_cast<StoryText *>(this);
-	return that->d->at(pos)->getItem(m_doc);
+	return d->at(pos)->getItem(m_doc);
 }
 
 int StoryText::findMark(const Mark* mrk, int startPos) const
@@ -1278,8 +1290,7 @@ LayoutFlags StoryText::flags(int pos) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	StoryText* that = const_cast<StoryText *>(this);
-	return  static_cast<LayoutFlags>((*that->d->at(pos)).effects().value & ScStyle_NonUserStyles);
+	return static_cast<LayoutFlags>(d->at(pos)->effects().value & ScStyle_NonUserStyles);
 }
 
 bool StoryText::hasFlag(int pos, LayoutFlags flags) const
@@ -1391,7 +1402,8 @@ const ParagraphStyle & StoryText::paragraphStyle(int pos) const
 //		current->parstyle->charStyle().setName( "cpara(paragraphStyle)" ); // DON'T TRANSLATE
 //		current->parstyle->charStyle().setContext( d->defaultStyle.charStyleContext());
 	}
-	else {
+	else
+	{
 //		qDebug() << QString("using parstyle at %1").arg(pos);
 	}
 	assert (that->d->at(pos)->parstyle);
@@ -1439,7 +1451,7 @@ void StoryText::applyCharStyle(int pos, uint len, const CharStyle& style )
 
 //	int lastParStart = pos == 0? 0 : -1;
 	ScText* itText;
-	for (uint i=pos; i < pos+len; ++i)
+	for (uint i = pos; i < pos + len; ++i)
 	{
 		itText = d->at(i);
 		// #6165 : applying style on last character applies style on whole text on next open 
@@ -1480,7 +1492,8 @@ void StoryText::eraseCharStyle(int pos, uint len, const CharStyle& style )
 		return;
 	
 	ScText* itText;
-	for (uint i=pos; i < pos+len; ++i) {
+	for (uint i = pos; i < pos + len; ++i)
+	{
 		itText = d->at(i);
 		// FIXME?? see #6165 : should we really erase charstyle of paragraph style??
 		if (itText->ch == SpecialChars::PARSEP && itText->parstyle != nullptr)
@@ -1510,7 +1523,8 @@ void StoryText::applyStyle(int pos, const ParagraphStyle& style, bool rmDirectFo
 
 	if (i < length())
 	{
-		if (!d->at(i)->parstyle) {
+		if (!d->at(i)->parstyle)
+		{
 			qDebug("PARSEP without style at pos %i", i);
 			d->at(i)->parstyle = new ParagraphStyle();
 			d->at(i)->parstyle->setContext( & d->pstyleContext);
@@ -1521,7 +1535,8 @@ void StoryText::applyStyle(int pos, const ParagraphStyle& style, bool rmDirectFo
 //		qDebug() << QString("applying parstyle %2 at %1 for %3").arg(i).arg(paragraphStyle(pos).name()).arg(pos);
 		d->at(i)->parstyle->applyStyle(style);
 	}
-	else {
+	else
+	{
 		// not happy about this but inserting a new PARSEP makes more trouble
 //		qDebug() << QString("applying parstyle %1 as defaultstyle for %2").arg(paragraphStyle(pos).name()).arg(pos);
 		d->trailingStyle.applyStyle(style);
@@ -1552,7 +1567,8 @@ void StoryText::eraseStyle(int pos, const ParagraphStyle& style)
 
 	if (i < length())
 	{
-		if (!d->at(i)->parstyle) {
+		if (!d->at(i)->parstyle)
+		{
 			qDebug("PARSEP without style at pos %i", i);
 			d->at(i)->parstyle = new ParagraphStyle();
 			d->at(i)->parstyle->setContext( & d->pstyleContext);
@@ -1590,7 +1606,7 @@ void StoryText::setCharStyle(int pos, uint len, const CharStyle& style)
 		return;
 	
 	ScText* itText;
-	for (uint i=pos; i < pos+len; ++i)
+	for (uint i = pos; i < pos + len; ++i)
 	{
 		itText = d->at(i);
 		// #6165 : applying style on last character applies style on whole text on next open 
@@ -1607,7 +1623,7 @@ void StoryText::getNamedResources(ResourceCollection& lists) const
 	d->defaultStyle.getNamedResources(lists);
 	d->trailingStyle.getNamedResources(lists);
 
-	for (int i=0; i < length(); ++i)
+	for (int i = 0; i < length(); ++i)
 	{
 		if (text(i) == SpecialChars::PARSEP)
 			paragraphStyle(i).getNamedResources(lists);
@@ -1636,7 +1652,7 @@ void StoryText::replaceNamedResources(ResourceCollection& newNames)
 		return;
 	
 	ScText* itText;
-	for (int i=0; i < len; ++i)
+	for (int i = 0; i < len; ++i)
 	{
 		itText = d->at(i);
 		if (itText->parstyle)
@@ -1707,12 +1723,11 @@ uint StoryText::nrOfParagraph() const
 uint StoryText::nrOfParagraph(int pos) const
 {
 	uint result = 0;
-	StoryText* that = const_cast<StoryText *>(this);
 	bool lastWasPARSEP = true;
-	pos = qMin(pos, that->length());
-	for (int i=0; i < pos; ++i)
+	pos = qMin(pos, length());
+	for (int i = 0; i < pos; ++i)
 	{
-		lastWasPARSEP = that->d->at(i)->ch == SpecialChars::PARSEP;
+		lastWasPARSEP = d->at(i)->ch == SpecialChars::PARSEP;
 		if (lastWasPARSEP)
 			++result;
 	}
@@ -1722,11 +1737,10 @@ uint StoryText::nrOfParagraph(int pos) const
 uint StoryText::nrOfParagraphs() const
 {
 	uint result = 0;
-	StoryText* that = const_cast<StoryText *>(this);
 	bool lastWasPARSEP = true;
-	for (int i=0; i < length(); ++i)
+	for (int i = 0; i < length(); ++i)
 	{
-		lastWasPARSEP = that->d->at(i)->ch == SpecialChars::PARSEP;
+		lastWasPARSEP = d->at(i)->ch == SpecialChars::PARSEP;
 		if (lastWasPARSEP)
 			++result;
 	}
@@ -1743,10 +1757,9 @@ int StoryText::startOfParagraph(uint index) const
 	if (index == 0)
 		return 0;
 
-	StoryText* that = const_cast<StoryText *>(this);
-	for (int i=0; i < length(); ++i)
+	for (int i = 0; i < length(); ++i)
 	{
-		if (that->d->at(i)->ch == SpecialChars::PARSEP && ! --index)
+		if (d->at(i)->ch == SpecialChars::PARSEP && ! --index)
 			return i + 1;
 	}
 	return length();
@@ -1760,10 +1773,9 @@ int StoryText::endOfParagraph() const
 int StoryText::endOfParagraph(uint index) const
 {
 	++index;
-	StoryText* that = const_cast<StoryText *>(this);
-	for (int i=0; i < length(); ++i)
+	for (int i = 0; i < length(); ++i)
 	{
-		if (that->d->at(i)->ch == SpecialChars::PARSEP && ! --index)
+		if (d->at(i)->ch == SpecialChars::PARSEP && ! --index)
 			return i;
 	}
 	return length();
@@ -1820,7 +1832,10 @@ int StoryText::nextWord(int pos)
 	if (!it)
 		return pos;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	pos = it->following(pos);
 	
 	int len = length();
@@ -1835,7 +1850,10 @@ int StoryText::prevWord(int pos)
 	if (!it)
 		return pos;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	pos = it->preceding(pos);
 	return pos;
 }
@@ -1846,7 +1864,10 @@ int StoryText::endOfWord(int pos) const
 	if (!it)
 		return pos;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	pos = it->following(pos);
 	return pos;
 }
@@ -1857,7 +1878,10 @@ int StoryText::endOfSentence(int pos) const
 	if (!it)
 		return pos;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	int end = it->following(pos);
 	return end;
 }
@@ -1868,7 +1892,10 @@ int StoryText::nextSentence(int pos)
 	if (!it)
 		return pos;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	pos = it->following(pos);
 	pos = it->next();
 	return pos;
@@ -1883,10 +1910,14 @@ int StoryText::prevSentence(int pos)
 	if (!it)
 		return pos;
 
-	it->setText((const UChar*) plainText().utf16());
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	pos = it->preceding(pos);
 	return pos;
 }
+
 int StoryText::nextParagraph(int pos)
 {
 	int len = length();
@@ -1895,6 +1926,7 @@ int StoryText::nextParagraph(int pos)
 		++pos;
 	return pos;
 }
+
 int StoryText::prevParagraph(int pos)
 {
 	pos = qMax(0, pos - 1);
@@ -1952,7 +1984,11 @@ int StoryText::selectWord(int pos)
 	BreakIterator* it = getWordIterator();
 	if (!it)
 		return pos;
-	it->setText((const UChar*) plainText().utf16());
+
+	QString fullText = plainText();
+	icu::UnicodeString unicodeStr(true, (const UChar*) fullText.utf16(), fullText.length());
+	it->setText(unicodeStr);
+
 	int start = it->preceding(pos + 1);
 	int end = it->next();
 	int wordLength = end - start;
@@ -1983,21 +2019,24 @@ void StoryText::select(int pos, int len, bool on)
 //	qDebug("old selection: %d - %d", d->selFirst, d->selLast);
 
 //	StoryText* that = const_cast<StoryText *>(this);
-//	for (int i=pos; i < pos+signed(len); ++i)
+//	for (int i = pos; i < pos + signed(len); ++i)
 //		that->at(i)->cselect = on;
 
-	if (on) {
+	if (on)
+	{
 		// extend if possible
 		if (selected(pos - 1))
 			d->selLast = qMax(d->selLast, pos + len - 1);
 		else if (selected(pos + len))
 			d->selFirst = qMin(d->selFirst, pos);
-		else {
+		else
+		{
 			d->selFirst = pos;
 			d->selLast = pos + len - 1;
 		}
 	}
-	else {
+	else
+	{
 		if (pos <= d->selFirst && d->selLast < pos + signed(len))
 			deselectAll();
 		// shrink
@@ -2125,26 +2164,12 @@ BreakIterator* StoryText::getLineIterator()
 
 void StoryText::selectAll()
 {
-/*	StoryText* that = const_cast<StoryText *>(this);
-	that->at(0);
-	for (int i=0; i < length(); ++i) {
-		that->current()->cselect = true;
-		that->next();
-	}
-*/
 	d->selFirst = 0;
 	d->selLast = length() - 1;
 }
 
 void StoryText::deselectAll()
 {
-/*	StoryText* that = const_cast<StoryText *>(this);
-	that->at(0);
-	for (int i=0; i < length(); ++i) {
-		that->current()->cselect = false;
-		that->next();
-	}
-*/	
 	d->selFirst = 0;
 	d->selLast = -1;
 }
@@ -2207,13 +2232,13 @@ void StoryText::validate()
 ScText* StoryText::item(int index)
 {
 	assert( index < length() );
-	return const_cast<StoryText *>(this)->d->at(index);
+	return this->d->at(index);
 }
 
 const ScText* StoryText::item(int index) const
 {
 	assert( index < length() );
-	return const_cast<StoryText *>(this)->d->at(index);
+	return d->at(index);
 }
 
 
@@ -2391,7 +2416,7 @@ void StoryText::saxx(SaxHandler& handler, const Xml_string& elemtag) const
 class AppendText_body : public Action_body
 {
 public:	
-	void chars(const Xml_string& txt)
+	void chars(const Xml_string& txt) override
 	{
 		QChar chr;
 		int   lastPos = 0, len;
@@ -2434,9 +2459,9 @@ struct  AppendText : public MakeAction<AppendText_body>
 class AppendSpecial_body : public Action_body
 {
 public:
-	AppendSpecial_body(QChar sp) : chr(sp) {}
+	explicit AppendSpecial_body(QChar sp) : chr(sp) {}
 	
-	void begin(const Xml_string& tag, Xml_attr attr)
+	void begin(const Xml_string& tag, Xml_attr attr) override
 	{
 		StoryText* obj = this->dig->top<StoryText>();
 		Xml_attr::iterator code = attr.find("code");
@@ -2459,15 +2484,15 @@ private:
 
 struct AppendSpecial : public MakeAction<AppendSpecial_body, QChar>
 {
-	AppendSpecial(QChar sp) : MakeAction<AppendSpecial_body, QChar>(sp) {}
 	AppendSpecial() : MakeAction<AppendSpecial_body, QChar>(SpecialChars::BLANK) {}
+	explicit AppendSpecial(QChar sp) : MakeAction<AppendSpecial_body, QChar>(sp) {}
 };
 
 
 class AppendInlineFrame_body : public Action_body
 {
 public:
-	void end(const Xml_string& tag) // this could be a setter if we had StoryText::appendObject() ...
+	void end(const Xml_string& tag) override // this could be a setter if we had StoryText::appendObject() ...
 	{
 		StoryText* story = this->dig->top<StoryText>(1);
 		PageItem* obj = this->dig->top<PageItem>(0);
@@ -2493,10 +2518,10 @@ struct AppendInlineFrame : public MakeAction<AppendInlineFrame_body>
 class AppendMark_body : public Action_body
 {
 public:
-	void begin(const Xml_string& tag, Xml_attr attr)
+	void begin(const Xml_string& tag, Xml_attr attr) override
 	{
 		StoryText* story = this->dig->top<StoryText>();
-		QString l = "";
+		QString l;
 		MarkType t = MARKNoType;
 		
 		Mark* mrk = nullptr;
@@ -2709,20 +2734,20 @@ struct ApplyCharStyle : public MakeAction<ApplyCharStyle_body, const Xml_string&
 class Paragraph_body : public Action_body
 {
 public:
-	Paragraph_body() : lastPos(0), numPara(0), lastStyle(nullptr)
+	Paragraph_body()
 	{}
 	
-	~Paragraph_body() 
+	~Paragraph_body() override
 	{
 		delete lastStyle;
 	}
 
-	virtual void reset()
+	void reset() override
 	{
 		numPara = 0;
 	}
 	
-	void begin(const Xml_string& tag, Xml_attr attr)
+	void begin(const Xml_string& tag, Xml_attr attr) override
 	{
 		if (tag == "text-content")
 		{
@@ -2742,7 +2767,7 @@ public:
 		}
 	}
 	
-	void end(const Xml_string& tag) 
+	void end(const Xml_string& tag) override
 	{
 		if (tag == ParagraphStyle::saxxDefaultElem)
 		{
@@ -2763,9 +2788,9 @@ public:
 		}
 	}
 private:
-	int lastPos;
-	int numPara;
-	ParagraphStyle* lastStyle;
+	int lastPos { 0 };
+	int numPara { 0 };
+	ParagraphStyle* lastStyle { nullptr };
 };
 
 struct Paragraph : public MakeAction<Paragraph_body>
@@ -2777,15 +2802,15 @@ struct Paragraph : public MakeAction<Paragraph_body>
 class SpanAction_body : public Action_body
 {
 public:
-	SpanAction_body() : lastPos(0), lastStyle(nullptr)
+	SpanAction_body()
 	{}
 	
-	~SpanAction_body() 
+	~SpanAction_body() override
 	{
 		delete lastStyle;
 	}
 	
-	void begin(const Xml_string& tag, Xml_attr attr)
+	void begin(const Xml_string& tag, Xml_attr attr) override
 	{
 //		qDebug() << QString("spanaction: begin %1").arg(tag);
 		if (tag == "span")
@@ -2797,7 +2822,7 @@ public:
 		}
 	}
 	
-	void end(const Xml_string& tag) 
+	void end(const Xml_string& tag) override
 	{
 		if (tag == CharStyle::saxxDefaultElem)
 //			qDebug() << QString("spanaction: end %1").arg(tag);
@@ -2816,8 +2841,8 @@ public:
 		}
 	}
 private:
-	int lastPos;
-	CharStyle* lastStyle;
+	int lastPos { 0 };
+	CharStyle* lastStyle { nullptr };
 };
 
 struct SpanAction : public MakeAction<SpanAction_body>
