@@ -19,9 +19,9 @@ for which a new license (GPL+exception) is in place.
 class ColorCombo;
 class Navigator;
 class PageItem;
+class PrefsContext;
 class ScribusDoc;
 class ScribusView;
-class PrefsContext;
 
 class SCRIBUS_API ScAnnot : public QDialog, Ui::ScAnnot
 {
@@ -29,7 +29,7 @@ class SCRIBUS_API ScAnnot : public QDialog, Ui::ScAnnot
 
 public:
 	ScAnnot(QWidget* parent, PageItem *it, ScribusDoc* doc, ScribusView* view);
-	~ScAnnot();
+	~ScAnnot() = default;
 
 	void DecodeNum();
 	void DecodeVali();
