@@ -40,13 +40,8 @@ for which a new license (GPL+exception) is in place.
 
 
 GuideManager::GuideManager(QWidget* parent) :
-		ScrPaletteBase(parent, "GuideManager"),
-		m_Doc(nullptr),
-		currentPage(nullptr),
-		m_drawGuides(true)
+		ScrPaletteBase(parent, "GuideManager")
 {
-	docUnitIndex = 0;
-
 	setupUi(this);
 	tabWidget->setEnabled(false);
 	horizontalAutoGapSpin->setMinimum(0.0);
@@ -148,7 +143,7 @@ void GuideManager::setupPage(bool storeValues)
 		return;
 	m_drawGuides = false;
 	setEnabled(true);
-	// store old values for current page (=page to leave)
+	// store old values for current page (= page to leave)
 	if (currentPage && storeValues)
 		storePageValues(currentPage);
 
@@ -213,21 +208,21 @@ void GuideManager::setupGui()
 // 	drawGuides(); let Canvas::DrawPageMarks take care of it and avoid a costly ScribusView::DrawNew()
 }
 
-void GuideManager::storePageValues(ScPage *page)
+void GuideManager::storePageValues(ScPage *page) const
 {
 	if (!page || !m_Doc)
 		return;
 
 	// Handle case where page to store values from does not belong
 	// to current doc, eg. when switching between documents
-	ScribusDoc* doc = page->doc();
+	const ScribusDoc* doc = page->doc();
 	int unitIndex   = doc->unitIndex();
 
 	double gapValue = 0.0;
 	if (horizontalAutoGapCheck->isChecked())
 		gapValue = value2pts(horizontalAutoGapSpin->value(), unitIndex);
 	page->guides.setHorizontalAutoGap(gapValue);
-	page->guides.setHorizontalAutoCount(horizontalAutoCountSpin->value());
+	page->guides.setHorizontalAutoCount(static_cast<int>(horizontalAutoCountSpin->value()));
 	page->guides.setHorizontalAutoRefer(horizontalRefer());
 	page->guides.addHorizontals(getAutoHorizontals(page), GuideManagerCore::Auto);
 
@@ -235,7 +230,7 @@ void GuideManager::storePageValues(ScPage *page)
 	if (verticalAutoGapCheck->isChecked())
 		gapValue = value2pts(verticalAutoGapSpin->value(), unitIndex);
 	page->guides.setVerticalAutoGap(gapValue);
-	page->guides.setVerticalAutoCount(verticalAutoCountSpin->value());
+	page->guides.setVerticalAutoCount(static_cast<int>(verticalAutoCountSpin->value()));
 	page->guides.setVerticalAutoRefer(verticalRefer());
 	page->guides.addVerticals(getAutoVerticals(page), GuideManagerCore::Auto);
 }
@@ -342,7 +337,7 @@ void GuideManager::copyGuidesToAllPages(GuideManagerCore::GuideType t)
 	ScPage *tmpPage;
 	while (it.hasNext())
 	{
-		tmpPage=it.next();
+		tmpPage = it.next();
 		if (tmpPage->pageNr() == currentPage->pageNr())
 			continue;
 		tmpPage->guides.clearHorizontals(t);
@@ -379,7 +374,7 @@ void GuideManager::horizontalAutoCountSpin_valueChanged(double val)
 		horizontalAutoGapSpin->setEnabled(true);
 	else
 		horizontalAutoGapSpin->setEnabled(false);
-	currentPage->guides.setHorizontalAutoCount(val);
+	currentPage->guides.setHorizontalAutoCount(static_cast<int>(val));
 	drawGuides();
 	m_Doc->changed();
 }
@@ -410,7 +405,7 @@ void GuideManager::verticalAutoCountSpin_valueChanged(double val)
 		verticalAutoGapSpin->setEnabled(true);
 	else
 		verticalAutoGapSpin->setEnabled(false);
-	currentPage->guides.setVerticalAutoCount(val);
+	currentPage->guides.setVerticalAutoCount(static_cast<int>(val));
 	drawGuides();
 	m_Doc->changed();
 }
@@ -469,7 +464,7 @@ Guides GuideManager::selectedVerticals() const
 
 void GuideManager::setGuideLock(bool guidesLocked)
 {
-	bool b=lockCheck->blockSignals(true);
+	bool b = lockCheck->blockSignals(true);
 	lockCheck->setChecked(guidesLocked);
 	lockCheck->blockSignals(b);
 }
@@ -551,83 +546,58 @@ void GuideManager::deleteAllGuides_clicked()
 	m_Doc->changed();
 }
 
-Guides GuideManager::getAutoVerticals(ScPage * page)
+Guides GuideManager::getAutoVerticals(const ScPage * page) const
 {
 	GuideManagerCore guides;
 
 	// Handle case where page to store values from does not belong
 	// to current doc, eg. when switching between documents
-	ScribusDoc* doc = page->doc();
+	const ScribusDoc* doc = page->doc();
 	int unitIndex = doc->unitIndex();
 
 	double gapValue = 0.0;
 	if (horizontalAutoGapCheck->isChecked())
 		gapValue = value2pts(horizontalAutoGapSpin->value(), unitIndex);
 	guides.setHorizontalAutoGap(gapValue);
-	guides.setHorizontalAutoCount(horizontalAutoCountSpin->value());
+	guides.setHorizontalAutoCount(static_cast<int>(horizontalAutoCountSpin->value()));
 	guides.setHorizontalAutoRefer(horizontalRefer());
 
 	gapValue = 0.0;
 	if (verticalAutoGapCheck->isChecked())
 		gapValue = value2pts(verticalAutoGapSpin->value(), unitIndex);
 	guides.setVerticalAutoGap(gapValue);
-	guides.setVerticalAutoCount(verticalAutoCountSpin->value());
+	guides.setVerticalAutoCount(static_cast<int>(verticalAutoCountSpin->value()));
 	guides.setVerticalAutoRefer(verticalRefer());
 
 	return guides.getAutoVerticals(page);
 }
 
-Guides GuideManager::getAutoHorizontals(ScPage * page)
+Guides GuideManager::getAutoHorizontals(const ScPage * page) const
 {
 	GuideManagerCore guides;
 
 	// Handle case where page to store values from does not belong
 	// to current doc, eg. when switching between documents
-	ScribusDoc* doc = page->doc();
+	const ScribusDoc* doc = page->doc();
 	int unitIndex = doc->unitIndex();
 
 	double gapValue = 0.0;
 	if (horizontalAutoGapCheck->isChecked())
 		gapValue = value2pts(horizontalAutoGapSpin->value(), unitIndex);
 	guides.setHorizontalAutoGap(gapValue);
-	guides.setHorizontalAutoCount(horizontalAutoCountSpin->value());
+	guides.setHorizontalAutoCount(static_cast<int>(horizontalAutoCountSpin->value()));
 	guides.setHorizontalAutoRefer(horizontalRefer());
 
 	gapValue = 0.0;
 	if (verticalAutoGapCheck->isChecked())
 		gapValue = value2pts(verticalAutoGapSpin->value(), unitIndex);
 	guides.setVerticalAutoGap(gapValue);
-	guides.setVerticalAutoCount(verticalAutoCountSpin->value());
+	guides.setVerticalAutoCount(static_cast<int>(verticalAutoCountSpin->value()));
 	guides.setVerticalAutoRefer(verticalRefer());
 
 	return guides.getAutoHorizontals(page);
 }
 
-void GuideManager::resetSelectionForPage()
-{
-	int docSelectionCount = currentPage->doc()->m_Selection->count();
-
-	currentPage->guides.gx = currentPage->guides.gy = currentPage->guides.gw = currentPage->guides.gh = 0.0;
-
-	// multiselection
-	if (docSelectionCount > 1)
-	{
-		double x, y;
-		m_Doc->m_Selection->getGroupRect(&x, &y, &currentPage->guides.gw, &currentPage->guides.gh);
-		currentPage->guides.gx = x - currentPage->xOffset();
-		currentPage->guides.gy = y - currentPage->yOffset();
-	}
-	// only one item selected
-	else if (docSelectionCount == 1)
-	{
-		PageItem *currItem = m_Doc->m_Selection->itemAt(0);
-		currentPage->guides.gx = currItem->xPos() - currentPage->xOffset();
-		currentPage->guides.gy = currItem->yPos() - currentPage->yOffset();
-		currentPage->guides.gw = currItem->width();
-		currentPage->guides.gh = currItem->height();
-	}
-}
-
 void GuideManager::verticalModel_valueChanged()
 {
 	currentPage->guides.clearVerticals(GuideManagerCore::Standard);
@@ -656,10 +626,12 @@ void GuideManager::setHorizontalRefer(int button)
 			break;
 		case 2 :
 			horizontalSelectionAutoButton->setChecked(true);
+		default:
+			break;
 	}
 }
 
-int GuideManager::horizontalRefer()
+int GuideManager::horizontalRefer() const
 {
 	if (horizontalPageAutoButton->isChecked())
 		return 0;
@@ -682,10 +654,12 @@ void GuideManager::setVerticalRefer(int button)
 			break;
 		case 2 :
 			verticalSelectionAutoButton->setChecked(true);
+		default:
+			break;
 	}
 }
 
-int GuideManager::verticalRefer()
+int GuideManager::verticalRefer() const
 {
 	if (verticalPageAutoButton->isChecked())
 		return 0;
@@ -718,7 +692,7 @@ void GuideManager::horizontalSelectionAutoButton_toggled(bool state)
 		return;
 	currentPage->guides.setHorizontalAutoRefer(2);
 	if (horizontalSelectionAutoButton->isEnabled())
-		resetSelectionForPage();
+		currentPage->guides.resetSelectionForPage(currentPage);
 	drawGuides();
 }
 
@@ -746,7 +720,7 @@ void GuideManager::verticalSelectionAutoButton_toggled(bool state)
 		return;
 	currentPage->guides.setVerticalAutoRefer(2);
 	if (verticalSelectionAutoButton->isEnabled())
-		resetSelectionForPage();
+		currentPage->guides.resetSelectionForPage(currentPage);
 	drawGuides();
 	m_Doc->changed();
 }
