@@ -164,7 +164,7 @@ HelpBrowser::HelpBrowser( QWidget* parent, const QString& /*caption*/, const QSt
 	firstRun = true;
 	setupUi(this);
 	helpNav = new HelpNavigation(this);
-#if defined(Q_OS_MAC) && defined(HELP_NAV_AS_DRAWER)
+#if defined(Q_OS_MACOS) && defined(HELP_NAV_AS_DRAWER)
 	// TODO
 #else
 	QDockWidget * dckw = new QDockWidget(tr("Navigation"),this);
@@ -467,7 +467,7 @@ void HelpBrowser::bookmarkButton_clicked()
 		return;
 	//TODO: start storing full paths
  	QString toFind(fname.remove(QDir::toNativeSeparators(m_finalBaseDir)));
-	toFind=toFind.mid(1, toFind.length()-1);
+	toFind = toFind.mid(1, toFind.length() - 1);
 	QMapIterator<QString, QString> i(m_quickHelpIndex);
 	while (i.hasNext())
 	{
@@ -762,8 +762,8 @@ QString HelpBrowser::historyFile()
 
 void HelpBrowser::displayNoHelp()
 {
-	QString noHelpMsg=tr("<h2><p>Sorry, no manual is installed!</p><p>Please see:</p><ul><li>http://docs.scribus.net for updated documentation</li><li>http://www.scribus.net for downloads</li></ul></h2>",
-						 "HTML message for no documentation available to show");
+	QString noHelpMsg = tr("<h2><p>Sorry, no manual is installed!</p><p>Please see:</p><ul><li>http://docs.scribus.net for updated documentation</li><li>http://www.scribus.net for downloads</li></ul></h2>",
+						   "HTML message for no documentation available to show");
 
 	textBrowser->setHtml(noHelpMsg);
 	
