@@ -9,6 +9,7 @@ for which a new license (GPL+exception) is in place.
 
 
 #include <QListWidgetItem>
+#include <QDialogButtonBox>
 #include <QMap>
 #include <QStackedWidget>
 
@@ -22,6 +23,7 @@ for which a new license (GPL+exception) is in place.
 #include "ui/prefs_documentitemattributes.h"
 #include "ui/prefs_documentsections.h"
 #include "ui/prefs_documentsetup.h"
+#include "ui/prefs_experimental.h"
 #include "ui/prefs_externaltools.h"
 #include "ui/prefs_fonts.h"
 #include "ui/prefs_guides.h"
@@ -55,8 +57,8 @@ class SCRIBUS_API PreferencesDialog : public QDialog, Ui::PreferencesDialog
 	Q_OBJECT
 
 	public:
-		PreferencesDialog(QWidget* parent, ApplicationPrefs& prefsData, ScribusDoc *doc=nullptr);
-		~PreferencesDialog();
+		PreferencesDialog(QWidget* parent, ApplicationPrefs& prefsData, ScribusDoc* doc = nullptr);
+		~PreferencesDialog() = default;
 
 		ApplicationPrefs prefs() const { return localPrefs; }
 		void getResizeDocumentPages(bool &resizePages, bool &resizeMasterPages, bool &resizePageMargins, bool &resizeMasterPageMargins);
@@ -74,7 +76,6 @@ class SCRIBUS_API PreferencesDialog : public QDialog, Ui::PreferencesDialog
 
 	protected slots:
 		virtual void languageChange();
-		void applyButtonClicked();
 
 	protected:
 		void addWidget(Prefs_Pane* tab);
@@ -93,6 +94,7 @@ class SCRIBUS_API PreferencesDialog : public QDialog, Ui::PreferencesDialog
 		Prefs_DocumentItemAttributes *prefs_DocumentItemAttributes {nullptr};
 		Prefs_DocumentSections *prefs_DocumentSections {nullptr};
 		Prefs_DocumentSetup *prefs_DocumentSetup {nullptr};
+		Prefs_Experimental *prefs_Experimental {nullptr};
 		Prefs_ExternalTools *prefs_ExternalTools {nullptr};
 		Prefs_Fonts *prefs_Fonts {nullptr};
 		Prefs_Guides *prefs_Guides;
