@@ -283,7 +283,7 @@ void BibView::checkAndChange(const QString& text, const QString& nam, const QStr
 						source = QDir::cleanPath(QDir::toNativeSeparators(Pfile));
 					else
 					{
-						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir+"/"+Pfile)));
+						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir + "/" + Pfile)));
 						source = pfi2.absoluteFilePath();
 					}
 					QString target = QDir::cleanPath(QDir::toNativeSeparators(dir + "/" + fid.baseName() + "/" + fi.fileName()));
@@ -298,7 +298,7 @@ void BibView::checkAndChange(const QString& text, const QString& nam, const QStr
 						source = QDir::cleanPath(QDir::toNativeSeparators(Pfile2));
 					else
 					{
-						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir+"/"+Pfile2)));
+						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir + "/" + Pfile2)));
 						source = pfi2.absoluteFilePath();
 					}
 					QString target = QDir::cleanPath(QDir::toNativeSeparators(dir + "/" + fid.baseName() + "/" + fi.fileName()));
@@ -313,7 +313,7 @@ void BibView::checkAndChange(const QString& text, const QString& nam, const QStr
 						source = QDir::cleanPath(QDir::toNativeSeparators(Pfile3));
 					else
 					{
-						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir+"/"+Pfile3)));
+						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir + "/" + Pfile3)));
 						source = pfi2.absoluteFilePath();
 					}
 					QString target = QDir::cleanPath(QDir::toNativeSeparators(dir + "/" + fid.baseName() + "/" + fi.fileName()));
@@ -332,7 +332,7 @@ void BibView::checkAndChange(const QString& text, const QString& nam, const QStr
 						source = QDir::cleanPath(QDir::toNativeSeparators(Pfile));
 					else
 					{
-						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir+"/"+Pfile)));
+						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir + "/" + Pfile)));
 						source = pfi2.absoluteFilePath();
 					}
 					QString target = QDir::cleanPath(QDir::toNativeSeparators(dir + "/" + fid.baseName() + "/" + fi.fileName()));
@@ -378,7 +378,7 @@ void BibView::checkAndChangeGroups(const QDomElement& elem, const QString& dir,
 						source = QDir::cleanPath(QDir::toNativeSeparators(Pfile));
 					else
 					{
-						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir+"/"+Pfile)));
+						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir + "/" + Pfile)));
 						source = pfi2.absoluteFilePath();
 					}
 					QString target = QDir::cleanPath(QDir::toNativeSeparators(dir + "/" + fid.baseName() + "/" + fi.fileName()));
@@ -393,7 +393,7 @@ void BibView::checkAndChangeGroups(const QDomElement& elem, const QString& dir,
 						source = QDir::cleanPath(QDir::toNativeSeparators(Pfile2));
 					else
 					{
-						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir+"/"+Pfile2)));
+						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir + "/" + Pfile2)));
 						source = pfi2.absoluteFilePath();
 					}
 					QString target = QDir::cleanPath(QDir::toNativeSeparators(dir + "/" + fid.baseName() + "/" + fi.fileName()));
@@ -408,7 +408,7 @@ void BibView::checkAndChangeGroups(const QDomElement& elem, const QString& dir,
 						source = QDir::cleanPath(QDir::toNativeSeparators(Pfile3));
 					else
 					{
-						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir+"/"+Pfile3)));
+						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir + "/" + Pfile3)));
 						source = pfi2.absoluteFilePath();
 					}
 					QString target = QDir::cleanPath(QDir::toNativeSeparators(dir + "/" + fid.baseName() + "/" + fi.fileName()));
@@ -427,7 +427,7 @@ void BibView::checkAndChangeGroups(const QDomElement& elem, const QString& dir,
 						source = QDir::cleanPath(QDir::toNativeSeparators(Pfile));
 					else
 					{
-						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir+"/"+Pfile)));
+						QFileInfo pfi2(QDir::cleanPath(QDir::toNativeSeparators(fileDir + "/" + Pfile)));
 						source = pfi2.absoluteFilePath();
 					}
 					QString target = QDir::cleanPath(QDir::toNativeSeparators(dir + "/" + fid.baseName() + "/" + fi.fileName()));
@@ -467,8 +467,8 @@ void BibView::readOldContents(const QString& name, const QString& newName)
 	QDomNode node = elem.firstChild();
 	while (!node.isNull())
 	{
-		QDomElement dc=node.toElement();
-		if (dc.tagName()=="OBJEKT")
+		QDomElement dc = node.toElement();
+		if (dc.tagName() == "OBJEKT")
 		{
 			QFile fi(QDir::cleanPath(QDir::toNativeSeparators(newName + "/" + dc.attribute("NAME", nullptr) + ".sce")));
 			if (!fi.open(QIODevice::WriteOnly))
@@ -508,6 +508,7 @@ void BibView::readContents(const QString& name)
 	fileCount += dd.count();
 	QDir d(dirPath, "*.sce", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
 	fileCount += d.count();
+
 	QStringList vectorFiles = LoadSavePlugin::getExtensionsForPreview(FORMATID_FIRSTUSER);
 	for (int v = 0; v < vectorFiles.count(); v++)
 	{
@@ -517,6 +518,7 @@ void BibView::readContents(const QString& name)
 		if (d4.count() > 0)
 			vectorFound.insert(vectorFiles[v]);
 	}
+
 	QString formatD(FormatsManager::instance()->extensionListForFormat(FormatsManager::RASTORIMAGES, 1));
 	QStringList rasterFiles = formatD.split("|");
 	for (int v = 0; v < rasterFiles.count(); v++)
@@ -527,14 +529,15 @@ void BibView::readContents(const QString& name)
 		if (d5.count() > 0)
 			rasterFound.insert(rasterFiles[v]);
 	}
+
 	QProgressDialog *pgDia = nullptr;
 	QStringList previewFiles;
-	previewFiles.clear();
 	if (ScCore->initialized())
 	{
 		pgDia = new QProgressDialog("Reading Files...", QString(), 0, fileCount, this);
 		pgDia->setWindowModality(Qt::WindowModal);
 	}
+
 	if ((dd.exists()) && (dd.count() != 0))
 	{
 		for (uint dc = 0; dc < dd.count(); ++dc)
@@ -550,6 +553,7 @@ void BibView::readContents(const QString& name)
 			addObject(dd[dc], "", pm, true);
 		}
 	}
+
 	if ((d.exists()) && (d.count() != 0))
 	{
 		for (uint dc = 0; dc < d.count(); ++dc)
@@ -580,17 +584,16 @@ void BibView::readContents(const QString& name)
 						f = QString::fromUtf8(cf.data());
 					else
 						f = cf.data();
-					ScPreview *pre = new ScPreview();
-					pm = QPixmap::fromImage(pre->createPreview(f));
+					pm = QPixmap::fromImage(ScPreview::create(f));
 					if (canWrite && PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews)
 						pm.save(filePath + "/.ScribusThumbs/" + fi.baseName() + ".png", "PNG");
-					delete pre;
 				}
 			}
 			previewFiles.append(fi.baseName() + ".png");
 			addObject(fi.baseName(), QDir::cleanPath(dirPath + "/" + d[dc]), pm);
 		}
 	}
+
 	for (int v = 0; v < vectorFiles.count(); v++)
 	{
 		if (!vectorFound.contains(vectorFiles[v]))
@@ -633,6 +636,7 @@ void BibView::readContents(const QString& name)
 			addObject(fi.fileName(), QDir::cleanPath(dirPath + "/" + d4[dc]), pm, false, false, true);
 		}
 	}
+
 	for (int v = 0; v < rasterFiles.count(); v++)
 	{
 		if (!rasterFound.contains(rasterFiles[v]))
@@ -678,38 +682,40 @@ void BibView::readContents(const QString& name)
 		pgDia->setValue(fileCount);
 		delete pgDia;
 	}
-	QMap<QString,Elem>::Iterator itf;
-	for (itf = objectMap.begin(); itf != objectMap.end(); ++itf)
-	{
-		if (itf.value().isDir)
-		{
-			QPixmap pm(60, 60);
-			pm.fill(palette().color(QPalette::Base));
-			QPainter p;
-			p.begin(&pm);
-			p.drawPixmap(30 - itf.value().Preview.width() / 2, 30 - itf.value().Preview.height() / 2, itf.value().Preview);
-			p.end();
-			QListWidgetItem *item = new QListWidgetItem(QIcon(pm), itf.key(), this);
-			item->setToolTip(itf.key());
-			item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-			itf.value().widgetItem = item;
-		}
-	}
-	for (itf = objectMap.begin(); itf != objectMap.end(); ++itf)
+
+	for (auto itf = objectMap.begin(); itf != objectMap.end(); ++itf)
 	{
 		if (!itf.value().isDir)
-		{
-			itf.value().Preview = itf.value().Preview.scaled(60, 60, Qt::KeepAspectRatio, Qt::SmoothTransformation);
-			QPixmap pm(60, 60);
-			pm.fill(palette().color(QPalette::Base));
-			QPainter p;
-			p.begin(&pm);
-			p.drawPixmap(30 - itf.value().Preview.width() / 2, 30 - itf.value().Preview.height() / 2, itf.value().Preview);
-			p.end();
-			QListWidgetItem *item = new QListWidgetItem(QIcon(pm), itf.key(), this);
-			item->setToolTip(itf.key());
-			itf.value().widgetItem = item;
-		}
+			continue;
+		QPixmap pm(60, 60);
+		pm.fill(palette().color(QPalette::Base));
+		QPainter p;
+		p.begin(&pm);
+		p.drawPixmap(30 - itf.value().Preview.width() / 2, 30 - itf.value().Preview.height() / 2, itf.value().Preview);
+		p.end();
+		auto *item = new QListWidgetItem(QIcon(pm), itf.key(), this);
+		item->setToolTip(itf.key());
+		item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
+		itf.value().widgetItem = item;
+	}
+
+	IconManager& iconManager = IconManager::instance();
+	for (auto itf = objectMap.begin(); itf != objectMap.end(); ++itf)
+	{
+		if (itf.value().isDir)
+			continue;
+		auto& preview = itf.value().Preview;
+		preview = preview.scaled(60, 60, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+		QPixmap pm(60, 60);
+		pm.fill(palette().color(QPalette::Base));
+		QPainter p;
+		p.begin(&pm);
+		p.fillRect(0, 0, 60, 60, QBrush(iconManager.loadPixmap("testfill.png")));
+		p.drawPixmap(30 - preview.width() / 2, 30 - preview.height() / 2, preview);
+		p.end();
+		auto *item = new QListWidgetItem(QIcon(pm), itf.key(), this);
+		item->setToolTip(itf.key());
+		itf.value().widgetItem = item;
 	}
 }
 
@@ -745,6 +751,8 @@ Biblio::Biblio(QWidget* parent) : ScDockPalette(parent, "Sclib", Qt::WindowFlags
 	closeButton->setIconSize(QSize(16, 16));
 	configButton = new QToolButton(this);
 	configButton->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
+	configButton->setIcon(IconManager::instance().loadPixmap("16/configure.png"));
+	configButton->setIconSize(QSize(16, 16));
 
 	configMenue = new QMenu();
 	conf_HideDirs = configMenue->addAction( tr("Hide Directories"));
@@ -842,9 +850,9 @@ QStringList Biblio::getOpenScrapbooks() const
 	QStringList ret;
 	if (Frame3->count() > 2) // omit the first 2 Tabs since they contain the main and temp scrapbook
 	{
-		for (int a = 2; a < Frame3->count(); a++)
+		for (int i = 2; i < Frame3->count(); i++)
 		{
-			auto bv = (BibView*) Frame3->widget(a);
+			auto bv = (BibView*) Frame3->widget(i);
 			ret.append(bv->ScFilename);
 		}
 	}
@@ -854,9 +862,9 @@ QStringList Biblio::getOpenScrapbooks() const
 QStringList Biblio::getOpenScrapbooksNames() const
 {
 	QStringList ret;
-	for (int a = 0; a < Frame3->count(); a++)
+	for (int i = 0; i < Frame3->count(); i++)
 	{
-		auto bv = (BibView*) Frame3->widget(a);
+		auto bv = (BibView*) Frame3->widget(i);
 		ret.append(bv->visibleName);
 	}
 	return ret;
@@ -864,20 +872,20 @@ QStringList Biblio::getOpenScrapbooksNames() const
 
 void Biblio::setScrapbookFileName(const QString& fileName)
 {
-	activeBView->ScFilename=fileName;
+	activeBView->ScFilename = fileName;
 }
 
-const QString& Biblio::getScrapbookFileName()
+const QString& Biblio::getScrapbookFileName() const
 {
 	return activeBView->ScFilename;
 }
 
-int Biblio::objectCount()
+int Biblio::objectCount() const
 {
 	return activeBView->objectMap.count();
 }
 
-bool Biblio::tempHasContents()
+bool Biblio::tempHasContents() const
 {
 	return (!tempBView->objectMap.isEmpty());
 }
@@ -909,11 +917,10 @@ void Biblio::installEventFilter(QObject *filterObj)
 
 void Biblio::updateView()
 {
-	for (int a = 0; a < Frame3->count(); a++)
+	for (int i = 0; i < Frame3->count(); i++)
 	{
-		BibView* bv = (BibView*)Frame3->widget(a);
-		QMap<QString, BibView::Elem>::Iterator itf;
-		for (itf = bv->objectMap.begin(); itf != bv->objectMap.end(); ++itf)
+		BibView* bv = (BibView*) Frame3->widget(i);
+		for (auto itf = bv->objectMap.begin(); itf != bv->objectMap.end(); ++itf)
 		{
 			if (itf.value().isDir)
 				itf.value().widgetItem->setHidden(conf_HideDirs->isChecked());
@@ -936,17 +943,19 @@ void Biblio::newLib()
 	if (fileName.isEmpty())
 		return;
 
-	for (int a = 0; a < Frame3->count(); a++)
+	for (int i = 0; i < Frame3->count(); i++)
 	{
-		BibView* bv = (BibView*)Frame3->widget(a);
+		BibView* bv = (BibView*) Frame3->widget(i);
 		if (fileName == bv->ScFilename)
 			return;
 	}
+
 	disconnect(activeBView, SIGNAL(objDropped(QString)), this, SLOT(objFromMenu(QString)));
 	disconnect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
 	disconnect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	disconnect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
 	disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+
 	QDir d(fileName);
 	activeBView = new BibView(this);
 	QFileInfo fd(fileName);
@@ -966,11 +975,13 @@ void Biblio::newLib()
 	activeBView->scrollToTop();
 	upButton->setEnabled(!((Frame3->currentIndex() == 0) || (Frame3->currentIndex() == 1)));
 	updateView();
+
 	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
 	connect(activeBView, SIGNAL(objDropped(QString)), this, SLOT(objFromMenu(QString)));
 	connect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
 	connect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	connect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(handleDoubleClick(QListWidgetItem*)));
+
 	emit scrapbookListChanged();
 }
 
@@ -982,19 +993,19 @@ void Biblio::Import()
 	                                         dirs->get("old_scrap_load", "."),
 	                                         tr("Scrapbook (*.scs *.SCS)"));
 	
-	if (!s.isEmpty())
-	{
-		dirs->set("old_scrap_load", s.left(s.lastIndexOf(QDir::toNativeSeparators("/"))));
+	if (s.isEmpty())
+		return;
+
+	dirs->set("old_scrap_load", s.left(s.lastIndexOf(QDir::toNativeSeparators("/"))));
 		
-		QFileInfo scrapbookFileInfoO(s);
-		if (scrapbookFileInfoO.exists())
-		{
-			readOldContents(s, activeBView->ScFilename);
-			readContents(activeBView->ScFilename);
-		}
-		activeBView->scrollToTop();
-		updateView();
+	QFileInfo scrapbookFileInfoO(s);
+	if (scrapbookFileInfoO.exists())
+	{
+		readOldContents(s, activeBView->ScFilename);
+		readContents(activeBView->ScFilename);
 	}
+	activeBView->scrollToTop();
+	updateView();
 }
 
 void Biblio::closeLib()
@@ -1009,6 +1020,7 @@ void Biblio::closeLib()
 	disconnect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	disconnect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
 	disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+
 	QFileInfo fi(activeBView->ScFilename);
 	ScCore->fileWatcher->removeDir(fi.absolutePath());
 	Frame3->removeItem(Frame3->indexOf(activeBView));
@@ -1016,11 +1028,13 @@ void Biblio::closeLib()
 	activeBView = (BibView*)Frame3->widget(0);
 	Frame3->setCurrentIndex(0);
 	upButton->setEnabled(!((Frame3->currentIndex() == 0) || (Frame3->currentIndex() == 1)));
+
 	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
 	connect(activeBView, SIGNAL(objDropped(QString)), this, SLOT(objFromMenu(QString)));
 	connect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
 	connect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	connect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
+
 	emit scrapbookListChanged();
 }
 
@@ -1030,8 +1044,10 @@ void Biblio::libChanged(int index)
 	disconnect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
 	disconnect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	disconnect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
+
 	activeBView = (BibView*)Frame3->widget(index);
 	upButton->setEnabled(!((Frame3->currentIndex() == 0) || (Frame3->currentIndex() == 1)));
+
 	connect(activeBView, SIGNAL(objDropped(QString)), this, SLOT(objFromMenu(QString)));
 	connect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
 	connect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
@@ -1041,18 +1057,21 @@ void Biblio::libChanged(int index)
 void Biblio::closeOnDel(const QString& libName)
 {
 	BibView* bv = nullptr;
+
 	int libIndex = 0;
-	for (int a = 0; a < Frame3->count(); a++)
+	for (int i = 0; i < Frame3->count(); i++)
 	{
-		bv = (BibView*)Frame3->widget(a);
+		bv = (BibView*) Frame3->widget(i);
 		if (libName == bv->ScFilename)
 		{
-			libIndex = a;
+			libIndex = i;
 			break;
 		}
 	}
+
 	if ((libIndex == 0) || (libIndex == 1))
 		return;
+
 	if (bv == activeBView)
 		closeLib();
 	else
@@ -1068,15 +1087,15 @@ void Biblio::closeOnDel(const QString& libName)
 
 void Biblio::reloadLib(const QString& fileName)
 {
-	for (int a = 0; a < Frame3->count(); a++)
+	for (int i = 0; i < Frame3->count(); i++)
 	{
-		BibView* bv = (BibView*)Frame3->widget(a);
+		BibView* bv = (BibView*) Frame3->widget(i);
 		if (bv->ScFilename == fileName)
 		{
 			bv->readContents(fileName);
 			bv->ScFilename = fileName;
 			QDir d(fileName);
-			if (a > 1)
+			if (i > 1)
 				bv->visibleName = d.dirName();
 			bv->scrollToTop();
 		}
@@ -1182,19 +1201,19 @@ void Biblio::handleMouse(QPoint p)
 		QMenu *pmenu3 = new QMenu( tr("Move To:"));
 		QSignalMapper *signalMapper2 = new QSignalMapper(this);
 		connect(signalMapper2, SIGNAL(mapped(int)), this, SLOT(moveObj(int)));
-		for (int a = 0; a < Frame3->count(); a++)
+		for (int i = 0; i < Frame3->count(); i++)
 		{
-			BibView* bv = (BibView*)Frame3->widget(a);
+			const BibView* bv = (BibView*) Frame3->widget(i);
 			if ((bv == activeBView) || (!bv->canWrite))
 				continue;
-			QAction *action = pmenu2->addAction(Frame3->itemText(Frame3->indexOf(Frame3->widget(a))));
+			QAction *action = pmenu2->addAction(Frame3->itemText(Frame3->indexOf(Frame3->widget(i))));
 			connect(action, SIGNAL(triggered()), signalMapper, SLOT(map()));
-			signalMapper->setMapping(action, a);
+			signalMapper->setMapping(action, i);
 			if (activeBView->canWrite)
 			{
-				QAction *action2 = pmenu3->addAction(Frame3->itemText(Frame3->indexOf(Frame3->widget(a))));
+				QAction *action2 = pmenu3->addAction(Frame3->itemText(Frame3->indexOf(Frame3->widget(i))));
 				connect(action2, SIGNAL(triggered()), signalMapper2, SLOT(map()));
-				signalMapper2->setMapping(action2, a);
+				signalMapper2->setMapping(action2, i);
 			}
 		}
 		pmenu->addMenu(pmenu2);
@@ -1235,7 +1254,7 @@ bool Biblio::copyObj(int id)
 	BibView* bv = (BibView*) Frame3->widget(id);
 	if (bv->objectMap.contains(nam))
 	{
-		Query dia(this, "tt", 1, tr("&Name:"), tr("New Entry"));
+		Query dia(this, "tt", true, tr("&Name:"), tr("New Entry"));
 		dia.setValidator(QRegExp("[\\w()]+"));
 		dia.setEditText(nam, true);
 		dia.setTestList(activeBView->objectMap.keys());
@@ -1244,11 +1263,12 @@ bool Biblio::copyObj(int id)
 		else
 			return false;
 	}
-	QPixmap pm;
+
 	QByteArray cf;
 	if (!loadRawText(QDir::cleanPath(activeBView->objectMap[ite->text()].Data), cf))
 		return false;
-	pm = activeBView->objectMap[ite->text()].Preview;
+
+	QPixmap pm = activeBView->objectMap[ite->text()].Preview;
 	QString dt = activeBView->objectMap[ite->text()].Data;
 	QDir thumbs(bv->ScFilename);
 	if (thumbs.exists())
@@ -1256,16 +1276,19 @@ bool Biblio::copyObj(int id)
 		if ((bv->canWrite) && (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews))
 			thumbs.mkdir(".ScribusThumbs");
 	}
+
 	QFileInfo fi(dt);
 	QFile f(QDir::cleanPath(QDir::toNativeSeparators(bv->ScFilename + "/" + nam + "." + fi.completeSuffix().toLower())));
 	if (!f.open(QIODevice::WriteOnly))
 		return false;
+
 	QDataStream s;
 	s.setDevice(&f);
 	s.writeRawData(cf.data(), cf.length());
 	f.close();
+
 	bv->addObject(nam, QDir::cleanPath(QDir::toNativeSeparators(bv->ScFilename + "/" + nam + "." + fi.completeSuffix().toLower())), pm);
-	pm.save(QDir::cleanPath(QDir::toNativeSeparators(bv->ScFilename + "/.ScribusThumbs/" + nam +".png")), "PNG");
+	pm.save(QDir::cleanPath(QDir::toNativeSeparators(bv->ScFilename + "/.ScribusThumbs/" + nam + ".png")), "PNG");
 	QFileInfo fiD(QDir::toNativeSeparators(activeBView->ScFilename + "/" + fi.baseName()));
 	if ((fiD.exists()) && (fiD.isDir()))
 	{
@@ -1284,6 +1307,7 @@ bool Biblio::copyObj(int id)
 		if (fiD.baseName() != nam)
 			adjustReferences(QDir::toNativeSeparators(bv->ScFilename + "/" + nam + "." + fi.completeSuffix().toLower()));
 	}
+
 	pm = pm.scaled(60, 60, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 	QPixmap pm2(60, 60);
 	pm2.fill(palette().color(QPalette::Base));
@@ -1291,9 +1315,11 @@ bool Biblio::copyObj(int id)
 	p.begin(&pm2);
 	p.drawPixmap(30 - pm.width() / 2, 30 - pm.height() / 2, pm);
 	p.end();
+
 	QListWidgetItem *item = new QListWidgetItem(QIcon(pm), nam, bv);
 	item->setToolTip(nam);
 	bv->objectMap[nam].widgetItem = item;
+
 	if (bv == tempBView)
 	{
 		m_tempCount++;
@@ -1349,12 +1375,15 @@ void Biblio::deleteObj()
 {
 	if (!activeBView->canWrite)
 		return;
+
 	QListWidgetItem *ite = actItem;
 	QString name = ite->text();
 	QFile::remove(activeBView->objectMap[name].Data);
+
 	QFileInfo fi(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + name + ".png"));
 	if (fi.exists())
 		QFile::remove(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + name + ".png"));
+
 	QFileInfo fiD(QDir::toNativeSeparators(activeBView->ScFilename + "/" + name));
 	if ((fiD.exists()) && (fiD.isDir()))
 	{
@@ -1369,6 +1398,7 @@ void Biblio::deleteObj()
 		}
 		dd.rmdir(name);
 	}
+
 	activeBView->objectMap.remove(name);
 	delete activeBView->takeItem(activeBView->row(ite));
 	if (activeBView == tempBView)
@@ -1386,8 +1416,8 @@ void Biblio::deleteAllObj()
 				QMessageBox::Yes);	// batch default
 	if (t == QMessageBox::No)
 		return;
-	QMap<QString,BibView::Elem>::Iterator it;
-	for (it = activeBView->objectMap.begin(); it != activeBView->objectMap.end(); ++it)
+
+	for (auto it = activeBView->objectMap.begin(); it != activeBView->objectMap.end(); ++it)
 	{
 		QFile f(it.value().Data);
 		f.remove();
@@ -1400,7 +1430,7 @@ void Biblio::deleteAllObj()
 		QFileInfo fiD(QDir::toNativeSeparators(activeBView->ScFilename + "/" + it.key()));
 		if ((fiD.exists()) && (fiD.isDir()))
 		{
-			QDir dd = QDir(QDir::toNativeSeparators(activeBView->ScFilename));
+			QDir dd(QDir::toNativeSeparators(activeBView->ScFilename));
 			QDir d(QDir::toNativeSeparators(activeBView->ScFilename + "/" + it.key()), "*", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
 			if ((d.exists()) && (d.count() != 0))
 			{
@@ -1423,28 +1453,29 @@ void Biblio::renameObj()
 {
 	if (!activeBView->canWrite)
 		return;
-	QString nam;
-	QString objData;
-	QPixmap objPreview;
+
 	QListWidgetItem *ite = actItem;
 	QString oldName = ite->text();
-	Query dia(this, "tt", 1, tr("&Name:"), tr("New Name"));
+
+	Query dia(this, "tt", true, tr("&Name:"), tr("New Name"));
 	dia.setValidator(QRegExp("[\\w()]+"));
 	dia.setEditText(ite->text(), true);
 	dia.setTestList(activeBView->objectMap.keys());
-	if (dia.exec())
-		nam = dia.getEditText();
-	else
+	if (!dia.exec())
 		return;
+	QString nam = dia.getEditText();
+
 	ite->setText(nam);
 	ite->setToolTip(nam);
-	objData = activeBView->objectMap[oldName].Data;
-	objPreview = activeBView->objectMap[oldName].Preview;
+	QString objData = activeBView->objectMap[oldName].Data;
+	QPixmap objPreview = activeBView->objectMap[oldName].Preview;
+
 	QDir d;
 	d.rename(objData, QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + ite->text() + ".sce")));
 	QFileInfo fi(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + oldName + ".png"));
 	if (fi.exists())
 		d.rename(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + oldName + ".png"), QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + ite->text() + ".png")));
+	
 	QFileInfo fiD(QDir::toNativeSeparators(activeBView->ScFilename + "/" + oldName));
 	if ((fiD.exists()) && (fiD.isDir()))
 	{
@@ -1452,6 +1483,7 @@ void Biblio::renameObj()
 		d.rename(QDir::toNativeSeparators(activeBView->ScFilename + "/" + oldName), QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + ite->text())));
 		adjustReferences(QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + ite->text() + ".sce")));
 	}
+
 	activeBView->objectMap.remove(oldName);
 	activeBView->addObject(ite->text(), QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + ite->text() + ".sce")), objPreview);
 	if (activeBView == tempBView)
@@ -1461,71 +1493,74 @@ void Biblio::renameObj()
 void Biblio::adjustReferences(const QString& nam)
 {
 	QByteArray cf;
-	if (loadRawText(nam, cf))
+	if (!loadRawText(nam, cf))
+		return;
+
+	QString f;
+	if (cf.left(16) == "<SCRIBUSELEMUTF8")
+		f = QString::fromUtf8(cf.data());
+	else
+		f = cf.data();
+
+	QDomDocument docu("scridoc");
+	docu.setContent(f);
+	QDomElement elem = docu.documentElement();
+	QDomNode node = elem.firstChild();
+	QFileInfo fid(nam);
+	while (!node.isNull())
 	{
-		QString f;
-		if (cf.left(16) == "<SCRIBUSELEMUTF8")
-			f = QString::fromUtf8(cf.data());
-		else
-			f = cf.data();
-		QDomDocument docu("scridoc");
-		docu.setContent(f);
-		QDomElement elem = docu.documentElement();
-		QDomNode node = elem.firstChild();
-		QFileInfo fid(nam);
-		while (!node.isNull())
+		QDomElement pg = node.toElement();
+		if (pg.tagName() == "ITEM")
 		{
-			QDomElement pg = node.toElement();
-			if (pg.tagName() == "ITEM")
+			auto itemType = static_cast<PageItem::ItemType>(pg.attribute("PTYPE").toInt());
+			if ((itemType == PageItem::ImageFrame) || (itemType == PageItem::TextFrame))
 			{
-				auto itemType = static_cast<PageItem::ItemType>(pg.attribute("PTYPE").toInt());
-				if ((itemType == PageItem::ImageFrame) || (itemType == PageItem::TextFrame))
+				QString Pfile = pg.attribute("PFILE");
+				if (!Pfile.isEmpty())
 				{
-					QString Pfile = pg.attribute("PFILE");
-					if (!Pfile.isEmpty())
-					{
-						QFileInfo fi(Pfile);
-						pg.setAttribute("PFILE", fid.baseName() + "/" + fi.fileName());
-					}
-					QString Pfile2 = pg.attribute("PFILE2","");
-					if (!Pfile2.isEmpty())
-					{
-						QFileInfo fi(Pfile2);
-						pg.setAttribute("PFILE2", fid.baseName() + "/" + fi.fileName());
-					}
-					QString Pfile3 = pg.attribute("PFILE3","");
-					if (!Pfile3.isEmpty())
-					{
-						QFileInfo fi(Pfile3);
-						pg.setAttribute("PFILE3", fid.baseName() + "/" + fi.fileName());
-					}
-					pg.setAttribute("relativePaths", 1);
+					QFileInfo fi(Pfile);
+					pg.setAttribute("PFILE", fid.baseName() + "/" + fi.fileName());
 				}
-				else if (itemType == PageItem::OSGFrame)
+				QString Pfile2 = pg.attribute("PFILE2","");
+				if (!Pfile2.isEmpty())
 				{
-					QString Pfile = pg.attribute("modelFile");
-					if (!Pfile.isEmpty())
-					{
-						QFileInfo fi(Pfile);
-						pg.setAttribute("modelFile", fid.baseName() + "/" + fi.fileName());
-					}
+					QFileInfo fi(Pfile2);
+					pg.setAttribute("PFILE2", fid.baseName() + "/" + fi.fileName());
 				}
-				else if (itemType == PageItem::Group)
+				QString Pfile3 = pg.attribute("PFILE3","");
+				if (!Pfile3.isEmpty())
 				{
-					adjustReferencesGroups(pg, fid);
+					QFileInfo fi(Pfile3);
+					pg.setAttribute("PFILE3", fid.baseName() + "/" + fi.fileName());
+				}
+				pg.setAttribute("relativePaths", 1);
+			}
+			else if (itemType == PageItem::OSGFrame)
+			{
+				QString Pfile = pg.attribute("modelFile");
+				if (!Pfile.isEmpty())
+				{
+					QFileInfo fi(Pfile);
+					pg.setAttribute("modelFile", fid.baseName() + "/" + fi.fileName());
 				}
 			}
-			node = node.nextSibling();
+			else if (itemType == PageItem::Group)
+			{
+				adjustReferencesGroups(pg, fid);
+			}
 		}
-		QFile fl(nam);
-		if (!fl.open(QIODevice::WriteOnly))
-			return ;
-		QDataStream s;
-		QByteArray cs = docu.toByteArray();
-		s.setDevice(&fl);
-		s.writeRawData(cs.data(), cs.length());
-		fl.close();
+		node = node.nextSibling();
 	}
+
+	QFile fl(nam);
+	if (!fl.open(QIODevice::WriteOnly))
+		return ;
+
+	QDataStream s;
+	QByteArray cs = docu.toByteArray();
+	s.setDevice(&fl);
+	s.writeRawData(cs.data(), cs.length());
+	fl.close();
 }
 
 void Biblio::adjustReferencesGroups(const QDomElement& elem, const QFileInfo& fid)
@@ -1620,14 +1655,15 @@ void Biblio::objFromFile(const QString& path, int testResult)
 		if (activeBView->objectMap.contains(nam))
 			nam += "("+ tmp.setNum(m_tempCount) + ")";
 	}
+
 	Query dia(this, "tt", true, tr("&Name:"), tr("New Entry"));
 	dia.setValidator(QRegExp("[\\w()]+"));
 	dia.setEditText(nam, true);
 	dia.setTestList(activeBView->objectMap.keys());
-	if (dia.exec())
-		nam = dia.getEditText();
-	else
+	if (!dia.exec())
 		return;
+	nam = dia.getEditText();
+
 	QImage img;
 	if (testResult == 9999)
 	{
@@ -1649,17 +1685,21 @@ void Biblio::objFromFile(const QString& path, int testResult)
 		}
 		isVector = true;
 	}
+
 	QByteArray cf;
 	if (!loadRawText(path, cf))
 		return;
+
 	QPixmap pm = QPixmap::fromImage(img);
 	QFile f(QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + nam + "." + fi.completeSuffix())));
 	if (!f.open(QIODevice::WriteOnly))
 		return;
+
 	QDataStream s;
 	s.setDevice(&f);
 	s.writeRawData(cf.data(), cf.length());
 	f.close();
+
 	if (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews)
 	{
 		QDir thumbs(activeBView->ScFilename);
@@ -1668,15 +1708,17 @@ void Biblio::objFromFile(const QString& path, int testResult)
 			if ((activeBView->canWrite) && (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews))
 				thumbs.mkdir(".ScribusThumbs");
 		}
-		img.save(QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + nam +".png")), "PNG");
+		img.save(QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + nam + ".png")), "PNG");
 	}
 	activeBView->addObject(nam, QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + nam + "." + fi.completeSuffix())), pm, false, isImage, isVector);
+	
 	QPixmap pm2(60, 60);
 	pm2.fill(palette().color(QPalette::Base));
 	QPainter p;
 	p.begin(&pm2);
 	p.drawPixmap(30 - pm.width() / 2, 30 - pm.height() / 2, pm);
 	p.end();
+
 	QListWidgetItem *item = new QListWidgetItem(QIcon(pm2), nam, activeBView);
 	item->setToolTip(nam);
 	activeBView->objectMap[nam].widgetItem = item;
@@ -1684,6 +1726,7 @@ void Biblio::objFromFile(const QString& path, int testResult)
 		item->setHidden(conf_HideImages->isChecked());
 	if (isVector)
 		item->setHidden(conf_HideVectors->isChecked());
+
 	if (Frame3->currentIndex() == 1)
 	{
 		if (tempBView->objectMap.count() > PrefsManager::instance().appPrefs.scrapbookPrefs.numScrapbookCopies)
@@ -1728,11 +1771,11 @@ void Biblio::objFromFile(const QString& path, int testResult)
 
 void Biblio::objFromMenu(QString text)
 {
-	QString nam = "";
 	QString tmp;
 	if (!activeBView->canWrite)
 		return;
-	nam = getObjectName(text);
+
+	QString nam(getObjectName(text));
 	if (Frame3->currentIndex() == 1)
 	{
 		if (nam.isEmpty())
@@ -1748,18 +1791,19 @@ void Biblio::objFromMenu(QString text)
 		if (activeBView->objectMap.contains(nam))
 			nam += "("+ tmp.setNum(m_tempCount) + ")";
 	}
-	Query dia(this, "tt", 1, tr("&Name:"), tr("New Entry"));
+
+	Query dia(this, "tt", true, tr("&Name:"), tr("New Entry"));
 	dia.setValidator(QRegExp("[\\w()]+"));
 	dia.setEditText(nam, true);
 	dia.setTestList(activeBView->objectMap.keys());
-	if (dia.exec())
-		nam = dia.getEditText();
-	else
+	if (!dia.exec())
 		return;
+	nam = dia.getEditText();
+
 	QString ff = text;
 	activeBView->checkAndChange(ff, QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + nam + ".sce")), QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename)));
-	ScPreview *pre = new ScPreview();
-	QPixmap pm = QPixmap::fromImage(pre->createPreview(ff));
+	
+	QPixmap pm = QPixmap::fromImage(ScPreview::create(ff));
 	activeBView->addObject(nam, QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + nam + ".sce")), pm);
 	if (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews)
 	{
@@ -1769,8 +1813,9 @@ void Biblio::objFromMenu(QString text)
 			if ((activeBView->canWrite) && (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews))
 				thumbs.mkdir(".ScribusThumbs");
 		}
-		pm.save(QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + nam +".png")), "PNG");
+		pm.save(QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + nam + ".png")), "PNG");
 	}
+
 	pm = pm.scaled(60, 60, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 	QPixmap pm2(60, 60);
 	pm2.fill(palette().color(QPalette::Base));
@@ -1778,10 +1823,10 @@ void Biblio::objFromMenu(QString text)
 	p.begin(&pm2);
 	p.drawPixmap(30 - pm.width() / 2, 30 - pm.height() / 2, pm);
 	p.end();
+
 	QListWidgetItem *item = new QListWidgetItem(QIcon(pm2), nam, activeBView);
 	item->setToolTip(nam);
 	activeBView->objectMap[nam].widgetItem = item;
-	delete pre;
 
 	if (Frame3->currentIndex() == 1)
 	{
@@ -1842,9 +1887,10 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 	if (tempBView->objectMap.contains(nam))
 		nam += "("+ tmp.setNum(m_tempCount) + ")";
 	m_tempCount++;
+
 	tempBView->checkAndChange(text, QDir::cleanPath(nativeTempScrapPath + nam + ".sce"), QDir::cleanPath(QDir::toNativeSeparators(tempBView->ScFilename)));
-	ScPreview *pre = new ScPreview();
-	QPixmap pm = QPixmap::fromImage(pre->createPreview(text));
+	
+	QPixmap pm = QPixmap::fromImage(ScPreview::create(text));
 	tempBView->addObject(nam, QDir::cleanPath(nativeTempScrapPath + nam + ".sce"), pm);
 	if (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews)
 	{
@@ -1854,7 +1900,7 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 			if ((tempBView->canWrite) && (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews))
 				thumbs.mkdir(".ScribusThumbs");
 		}
-		pm.save(QDir::cleanPath(nativeTempThumbsPath + nam +".png"), "PNG");
+		pm.save(QDir::cleanPath(nativeTempThumbsPath + nam + ".png"), "PNG");
 	}
 	pm = pm.scaled(60, 60, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 	QPixmap pm2(60, 60);
@@ -1863,10 +1909,11 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 	p.begin(&pm2);
 	p.drawPixmap(30 - pm.width() / 2, 30 - pm.height() / 2, pm);
 	p.end();
+
 	QListWidgetItem *item = new QListWidgetItem(QIcon(pm2), nam, tempBView);
 	item->setToolTip(nam);
 	tempBView->objectMap[nam].widgetItem = item;
-	delete pre;
+
 	if (tempBView->objectMap.count() > PrefsManager::instance().appPrefs.scrapbookPrefs.numScrapbookCopies)
 	{
 		QMap<QString,BibView::Elem>::Iterator it;
@@ -1907,7 +1954,6 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 
 void Biblio::objFromMainMenu(QString text, int scrapID)
 {
-	QString nam;
 	QString tmp;
 	int scID = scrapID;
 	if (scID > 0)
@@ -1915,23 +1961,25 @@ void Biblio::objFromMainMenu(QString text, int scrapID)
 	BibView* actBView = (BibView*)Frame3->widget(scID);
 	if (!actBView->canWrite)
 		return;
-	nam = getObjectName(text);
+
+	QString nam = getObjectName(text);
 	if (nam.isEmpty())
 		nam = tr("Object") + tmp.setNum(actBView->objectMap.count());
 	if (actBView->objectMap.contains(nam))
 		nam += "("+ tmp.setNum(m_tempCount) + ")";
-	Query dia(this, "tt", 1, tr("&Name:"), tr("New Entry"));
+
+	Query dia(this, "tt", true, tr("&Name:"), tr("New Entry"));
 	dia.setValidator(QRegExp("[\\w()]+"));
 	dia.setEditText(nam, true);
 	dia.setTestList(activeBView->objectMap.keys());
-	if (dia.exec())
-		nam = dia.getEditText();
-	else
+	if (!dia.exec())
 		return;
+	nam = dia.getEditText();
+
 	QString ff = text;
 	actBView->checkAndChange(ff, QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename + "/" + nam + ".sce")), QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename)));
-	ScPreview *pre = new ScPreview();
-	QPixmap pm = QPixmap::fromImage(pre->createPreview(ff));
+
+	QPixmap pm = QPixmap::fromImage(ScPreview::create(ff));
 	actBView->addObject(nam, QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename + "/" + nam + ".sce")), pm);
 	if (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews)
 	{
@@ -1941,7 +1989,7 @@ void Biblio::objFromMainMenu(QString text, int scrapID)
 			if ((actBView->canWrite) && (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews))
 				thumbs.mkdir(".ScribusThumbs");
 		}
-		pm.save(QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename + "/.ScribusThumbs/" + nam +".png")), "PNG");
+		pm.save(QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename + "/.ScribusThumbs/" + nam + ".png")), "PNG");
 	}
 	pm = pm.scaled(60, 60, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 	QPixmap pm2(60, 60);
@@ -1950,10 +1998,11 @@ void Biblio::objFromMainMenu(QString text, int scrapID)
 	p.begin(&pm2);
 	p.drawPixmap(30 - pm.width() / 2, 30 - pm.height() / 2, pm);
 	p.end();
+
 	QListWidgetItem *item = new QListWidgetItem(QIcon(pm2), nam, actBView);
 	item->setToolTip(nam);
 	actBView->objectMap[nam].widgetItem = item;
-	delete pre;
+
 	reloadLib(actBView->ScFilename);
 }
 
@@ -1966,8 +2015,7 @@ void Biblio::cleanUpTemp()
 	QString nativeScrapPath = QDir::toNativeSeparators(tempBView->ScFilename + "/");
 	QString nativeThumbsPath = QDir::toNativeSeparators(tempBView->ScFilename + "/.ScribusThumbs/");
 
-	QMap<QString,BibView::Elem>::Iterator it;
-	for (it = tempBView->objectMap.begin(); it != tempBView->objectMap.end(); ++it)
+	for (auto it = tempBView->objectMap.begin(); it != tempBView->objectMap.end(); ++it)
 	{
 		QFile f(it.value().Data);
 		f.remove();
@@ -1986,7 +2034,7 @@ void Biblio::cleanUpTemp()
 		QFileInfo fiD(nativeScrapPath + it.key());
 		if ((fiD.exists()) && (fiD.isDir()))
 		{
-			QDir dd = QDir(QDir::toNativeSeparators(tempBView->ScFilename));
+			QDir dd(QDir::toNativeSeparators(tempBView->ScFilename));
 			QDir d(nativeScrapPath + it.key(), "*", QDir::Name, QDir::Files | QDir::Readable | QDir::NoSymLinks);
 			if ((d.exists()) && (d.count() != 0))
 			{
