@@ -46,7 +46,7 @@ void ShadeButton::setShade(QAction *act)
 	
 	if (c == 0)
 	{
-		Query dia(this, "New", 1, tr("&Shade:"), tr("Shade"));
+		Query dia(this, "New", true, tr("&Shade:"), tr("Shade"));
 		if (dia.exec())
 		{
 			c = dia.getEditText().toInt(&ok);
