@@ -153,7 +153,7 @@ void SMParagraphStyle::selected(const QStringList &styleNames)
 	{
 		index = m_tmpStyles.find(styleNames[i]);
 		//FIXME: #7133: Use .isDefaultStyle() instead here rather than relying on tr text comparison
-		if (index<0 && styleNames[i]==CommonStrings::trDefaultParagraphStyle)
+		if (index < 0 && styleNames[i] == CommonStrings::trDefaultParagraphStyle)
 			index = m_tmpStyles.find(CommonStrings::DefaultParagraphStyle);
 		if (index > -1)
 			m_selection.append(&m_tmpStyles[index]);
@@ -185,7 +185,7 @@ QString SMParagraphStyle::fromSelection() const
 	for (int i = 0; i < m_doc->m_Selection->count(); ++i)
 	{
 		// FIXME: wth is going on here
-		PageItem *item = m_doc->m_Selection->itemAt(i);
+		const PageItem *item = m_doc->m_Selection->itemAt(i);
 
 		QString tmpName = item->itemText.defaultStyle().parent();
 
@@ -240,8 +240,8 @@ QString SMParagraphStyle::newStyle(const QString &fromStyle)
 	//#7179, do our name switch yet again to handle this properly for default styles
 	//FIXME: use isDefaultStyle somehow
 	QString copiedStyleName(fromStyle);
-	if (fromStyle==CommonStrings::trDefaultParagraphStyle)
-		copiedStyleName=CommonStrings::DefaultParagraphStyle;
+	if (fromStyle == CommonStrings::trDefaultParagraphStyle)
+		copiedStyleName = CommonStrings::DefaultParagraphStyle;
 
 	Q_ASSERT(m_tmpStyles.resolve(copiedStyleName));
 	if (!m_tmpStyles.resolve(copiedStyleName))
@@ -296,12 +296,12 @@ void SMParagraphStyle::editMode(bool isOn)
 bool SMParagraphStyle::isDefaultStyle(const QString &stylename) const
 {
 	int index = m_tmpStyles.find(stylename);
-	bool b=false;
+	bool b = false;
 	if (index > -1)
 		b = m_tmpStyles[index].isDefaultStyle();
 	else
 	{
-		if (CommonStrings::trDefaultParagraphStyle==stylename)
+		if (CommonStrings::trDefaultParagraphStyle == stylename)
 		{
 			index = m_tmpStyles.find(CommonStrings::DefaultParagraphStyle);
 			if (index > -1)
@@ -332,7 +332,7 @@ QString SMParagraphStyle::shortcut(const QString &stylename) const
 	else
 	{
 		//FIXME: Use isDefaultStyle somehow
-		if (CommonStrings::trDefaultParagraphStyle==stylename)
+		if (CommonStrings::trDefaultParagraphStyle == stylename)
 		{
 			index = m_tmpStyles.find(CommonStrings::DefaultParagraphStyle);
 			if (index > -1)
@@ -432,8 +432,7 @@ void SMParagraphStyle::nameChanged(const QString &newName)
 			m_tmpStyles[j].setParent(newName);
 	}
 
-	QList<RemoveItem>::iterator it;
-	for (it = m_deleted.begin(); it != m_deleted.end(); ++it)
+	for (auto it = m_deleted.begin(); it != m_deleted.end(); ++it)
 	{
 		if (it->second == oldName)
 		{
@@ -745,6 +744,7 @@ void SMParagraphStyle::slotSpaceBelow()
 void SMParagraphStyle::slotAlignment()
 {
 	ParagraphStyle::AlignmentType style = static_cast<ParagraphStyle::AlignmentType>(m_pwidget->alignment->getStyle());
+
 	if (m_pwidget->alignment->useParentValue())
 		for (int i = 0; i < m_selection.count(); ++i)
 			m_selection[i]->resetAlignment();
@@ -1005,9 +1005,9 @@ void SMParagraphStyle::slotNumName(const QString &str)
 			m_selection[i]->setNumName(str);
 		m_pwidget->numComboBox->setCurrentItem(m_pwidget->numComboBox->findText(m_selection[0]->numName()));
 		m_pwidget->numLevelSpin->setValue(m_selection[0]->numLevel()+1);
-		NumStruct * numS = m_doc->numerations.value(m_selection[0]->numName());
+		const NumStruct * numS = m_doc->numerations.value(m_selection[0]->numName());
 		if (numS)
-			m_pwidget->numLevelSpin->setMaximum(numS->m_counters.count()+1);
+			m_pwidget->numLevelSpin->setMaximum(numS->m_counters.count() + 1);
 		else
 			m_pwidget->numLevelSpin->setMaximum(1);
 		m_doc->flag_NumUpdateRequest = true;
@@ -1935,6 +1935,7 @@ QList<StyleName> SMCharacterStyle::styles(bool reloadFromDoc)
 			tmpList << StyleName(styleName, parentName);
 		}
 	}
+	std::sort(tmpList.begin(), tmpList.end(), sortingQPairOfStrings);
 
 	return tmpList;
 }
@@ -1960,7 +1961,7 @@ void SMCharacterStyle::selected(const QStringList &styleNames)
 	{
 		int index = m_tmpStyles.find(styleNames[i]);
 		//FIXME: #7133: Use .isDefaultStyle() instead here rather than relying on tr text comparison
-		if (index<0 && styleNames[i]==CommonStrings::trDefaultCharacterStyle)
+		if (index < 0 && styleNames[i] == CommonStrings::trDefaultCharacterStyle)
 			index = m_tmpStyles.find(CommonStrings::DefaultCharacterStyle);
 		if (index > -1)
 			m_selection.append(&m_tmpStyles[index]);
@@ -1979,7 +1980,7 @@ QString SMCharacterStyle::fromSelection() const
 	for (int i = 0; i < m_doc->m_Selection->count(); ++i)
 	{
 		// FIXME: wth is going on here
-		PageItem *item = m_doc->m_Selection->itemAt(i);
+		const PageItem *item = m_doc->m_Selection->itemAt(i);
 
 		QString tmpName = item->itemText.defaultStyle().charStyle().parent();
 
@@ -2034,8 +2035,8 @@ QString SMCharacterStyle::newStyle(const QString &fromStyle)
 	//#7179, do our name switch yet again to handle this properly for default styles
 	//FIXME: use isDefaultStyle somehow
 	QString copiedStyleName(fromStyle);
-	if (fromStyle==CommonStrings::trDefaultCharacterStyle)
-		copiedStyleName=CommonStrings::DefaultCharacterStyle;
+	if (fromStyle == CommonStrings::trDefaultCharacterStyle)
+		copiedStyleName = CommonStrings::DefaultCharacterStyle;
 
 	Q_ASSERT(m_tmpStyles.resolve(copiedStyleName));
 	if (!m_tmpStyles.resolve(copiedStyleName))
@@ -2087,12 +2088,12 @@ void SMCharacterStyle::editMode(bool isOn)
 bool SMCharacterStyle::isDefaultStyle(const QString &stylename) const
 {
 	int index = m_tmpStyles.find(stylename);
-	bool b=false;
+	bool b = false;
 	if (index > -1)
 		b = m_tmpStyles[index].isDefaultStyle();
 	else
 	{
-		if (CommonStrings::trDefaultCharacterStyle==stylename)
+		if (CommonStrings::trDefaultCharacterStyle == stylename)
 		{
 			index = m_tmpStyles.find(CommonStrings::DefaultCharacterStyle);
 			if (index > -1)
@@ -2122,7 +2123,7 @@ QString SMCharacterStyle::shortcut(const QString &stylename) const
 	else
 	{
 		//FIXME: Use isDefaultStyle somehow
-		if (CommonStrings::trDefaultCharacterStyle==stylename)
+		if (CommonStrings::trDefaultCharacterStyle == stylename)
 		{
 			index = m_tmpStyles.find(CommonStrings::DefaultCharacterStyle);
 			if (index > -1)
@@ -2221,8 +2222,7 @@ void SMCharacterStyle::nameChanged(const QString &newName)
 			m_tmpStyles[j].setParent(newName);
 	}
 
-	QList<RemoveItem>::iterator it;
-	for (it = m_deleted.begin(); it != m_deleted.end(); ++it)
+	for (auto it = m_deleted.begin(); it != m_deleted.end(); ++it)
 	{
 		if (it->second == oldName)
 		{
@@ -2552,7 +2552,7 @@ void SMCharacterStyle::slotLanguage()
 	{
 		QString tl(LanguageManager::instance()->getAbbrevFromLang(m_page->language_->currentText(), false));
 		if (!tl.isEmpty())
-			language=tl;
+			language = tl;
 		for (int i = 0; i < m_selection.count(); ++i)
 			m_selection[i]->setLanguage(language);
 	}
