@@ -47,7 +47,7 @@ class TransactionData;
 class UndoTransaction;
 
 /** @brief Key is the doc name, value is it's undo stack */
-typedef QMap<QString, UndoStack> StackMap;
+using StackMap = QMap<QString, UndoStack>;
 
 class SCRIBUS_API TransactionSettings
 {
@@ -579,6 +579,14 @@ public:
 	static QString GradValStroke;
 	static QString GradCol;
 	static QString GradTypeStroke;
+	static QString GradExtent;
+	static QString GradExtentStroke;
+	static QString PatternVal;
+	static QString PatternValStroke;
+	static QString PatternValMask;
+	static QString PatternStrokeToPath;
+	static QString PatternTransform;
+	static QString PatternFlip;
 	static QString MultipleDuplicate;
 	static QString Duplicate;
 	static QString Transform;
@@ -821,7 +829,7 @@ signals:
 
 };
 
-typedef UndoManager Um;
+using Um = UndoManager;
 
 class SCRIBUS_API UndoBlocker
 {
