@@ -25,12 +25,14 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 #include <zlib.h>
 #include <qglobal.h>
+
 #include <QApplication>
 #include <QCryptographicHash>
 #include <QDomElement>
 #include <QMessageBox>
 #include <QProcess>
 #include <QSignalBlocker>
+#include <QTextCodec>
 
 #include "pageitem.h"
 #include "pageitem_table.h"
@@ -41,7 +43,7 @@ for which a new license (GPL+exception) is in place.
 
 #include <csignal>
 
-#if !defined(_WIN32) && !defined(Q_OS_MAC) 
+#if !defined(_WIN32) && !defined(Q_OS_MACOS) 
 #include <execinfo.h>
 #include <cxxabi.h>
 #endif
@@ -60,6 +62,55 @@ QString cleanupLang(const QString& lang)
 	return lang.left(dotIndex);
 }
 
+// Code below is copied from Qt 5.15's QProcess::splitCommand()
+QStringList splitCommandLineArgs(const QString& command)
+{
+	int quoteCount = 0;
+	bool inQuote = false;
+	QStringList args;
+	QString tmp;
+
+	// handle quoting. tokens can be surrounded by double quotes
+	// "hello world". three consecutive double quotes represent
+	// the quote character itself.
+	for (int i = 0; i < command.size(); ++i)
+	{
+		if (command.at(i) == QLatin1Char('"'))
+		{
+			++quoteCount;
+			if (quoteCount == 3)
+			{
+				// third consecutive quote
+				quoteCount = 0;
+				tmp += command.at(i);
+			}
+			continue;
+		}
+		if (quoteCount)
+		{
+			if (quoteCount == 1)
+				inQuote = !inQuote;
+			quoteCount = 0;
+		}
+		if (!inQuote && command.at(i).isSpace())
+		{
+			if (!tmp.isEmpty())
+			{
+				args += tmp;
+				tmp.clear();
+			}
+		}
+		else
+		{
+			tmp += command.at(i);
+		}
+	}
+
+	if (!tmp.isEmpty())
+		args += tmp;
+	return args;
+}
+
 int System(const QString& exename, const QStringList & args, const QString& fileStdErr, const QString& fileStdOut, const bool* cancel)
 {
 	QProcess proc;
@@ -251,7 +302,8 @@ QString CompressStr(QString *in)
 				qDebug("compress2 failed with code %i", errcode);
 				out = *in;
 			}
-			else {
+			else
+			{
 				for (uint cl = 0; cl < exlen; ++cl)
 					out += QChar(bc[cl]);
 			}
@@ -499,14 +551,8 @@ bool compareQStrings(const QString& s1, const QString& s2)
 
 QStringList sortQStringList(QStringList aList)
 {
-	std::vector<QString> sortList;
-	QStringList retList;
-	QStringList::Iterator it;
-	for (it = aList.begin(); it != aList.end(); ++it)
-		sortList.push_back(*it);
-	std::sort(sortList.begin(), sortList.end(), compareQStrings);
-	for (uint i = 0; i < sortList.size(); i++)
-		retList.append(sortList[i]);
+	QStringList retList = aList;
+	std::sort(retList.begin(), retList.end(), compareQStrings);
 	return retList;
 }
 
@@ -521,15 +567,15 @@ QString checkFileExtension(const QString &currName, const QString &extension)
 {
 	QString newName(currName);
 	//If filename ends with a period, just add the extension
-	if (newName.right(1)==".")
+	if (newName.right(1) == ".")
 	{
-		newName+=extension.toLower();
+		newName += extension.toLower();
 		return newName;
 	}
 	//If filename doesn't end with the period+extension, add it on
 	QString dotExt("." + extension.toLower());
 	if (!newName.endsWith(dotExt, Qt::CaseInsensitive))
-		newName+=dotExt;
+		newName += dotExt;
 	return newName;
 }
 
@@ -537,11 +583,11 @@ QString getFileNameByPage(ScribusDoc* currDoc, uint pageNo, const QString& exten
 {
 	uint number = pageNo + currDoc->FirstPnum;
 	QString defaultName;
-	if (!prefix.isNull())
-		defaultName=prefix;
+	if (!prefix.isEmpty())
+		defaultName = prefix;
 	else
-		defaultName=currDoc->documentFileName();
-	if (defaultName.isNull())
+		defaultName = currDoc->documentFileName();
+	if (defaultName.isEmpty())
 		defaultName = "export";
 	else
 	{
@@ -562,10 +608,10 @@ QString getStringFromSequence(NumFormat type, uint position, const QString& aste
 	switch (type)
 	{
 		case Type_1_2_3:
-			retVal=QString::number(position);
+			retVal = QString::number(position);
 			break;
 		case Type_1_2_3_ar:
-			retVal=QLocale("ar").toString(position);
+			retVal = QLocale("ar").toString(position);
 			break;
 		case Type_A_B_C:
 			retVal = numberToLetterSequence(english, position).toUpper();
@@ -591,11 +637,12 @@ QString getStringFromSequence(NumFormat type, uint position, const QString& aste
 			retVal = numberToRoman(position).toLower();
 			break;
 		case Type_asterix:
-			for (uint a=1; a <= position; ++a)
+			for (uint a = 1; a <= position; ++a)
 				retVal.append(asterix);
 			break;
 		case Type_CJK:
 			retVal = numberToCJK(position);
+			break;
 		case Type_None:
 			break;
 		default:
@@ -832,6 +879,14 @@ void setCurrentComboItemFromData(QComboBox *box, const QString& data)
 		box->setCurrentIndex(ind);
 }
 
+void setCurrentComboItemFromData(QComboBox* box, quint64 data)
+{
+	QSignalBlocker signalBlocker(box);
+	int ind = box->findData(data);
+	if (ind > -1)
+		box->setCurrentIndex(ind);
+}
+
 void removeComboItem(QComboBox *box, const QString& text)
 {
 	QSignalBlocker signalBlocker(box);
@@ -845,13 +900,22 @@ QString readAdobeUniCodeString(QDataStream &s)
 	QString ret;
 	quint32 len;
 	s >> len;
-	for (quint32 i = 0; i < len; i++)
-	{
-		quint16 ch;
-		s >> ch;
-		if (ch != 0)
-			ret.append(QChar(ch));
-	}
+
+	quint32 bytesLen = 2 * len;
+	QByteArray strData(bytesLen, 0);
+	if (strData.size() != bytesLen)
+		return QString();
+
+	int bytesRead = s.readRawData(strData.data(), bytesLen);
+	if (bytesRead <= 0 || bytesRead != bytesLen)
+		return QString();
+
+	const QTextCodec* utf16Codec = (s.byteOrder() == QDataStream::BigEndian) ?
+	                                QTextCodec::codecForName("UTF-16BE") :
+		                            QTextCodec::codecForName("UTF-16LE");
+	ret = utf16Codec->toUnicode(strData);
+	ret.remove(QChar(0));
+
 	return ret;
 }
 
@@ -1243,35 +1307,35 @@ QString numberToHebrew(uint i)
 QString numberToCJK(uint i)
 {
 	QString result;
-	if (i<10)
+	if (i < 10)
 		result = QString(cjkDigit(i));
 
-	if (i>9 && i<=99)
+	if (i > 9 && i <= 99)
 	{
-		int tens=i/10;
-		int ones=i%10;
-		if (tens!=1)
+		int tens = i / 10;
+		int ones = i % 10;
+		if (tens != 1)
 			result.append(cjkDigit(tens));
 		result.append(cjkDigit(10));
-		if (ones!=0)
+		if (ones != 0)
 			result.append(cjkDigit(ones));
 	}
 
-	if (i>99 && i<=999)
+	if (i > 99 && i <= 999)
 	{
-		int hundreds=i/100;
-		int tens=(i-hundreds*100)/10;
-		int ones=i%10;
+		int hundreds = i / 100;
+		int tens = (i - hundreds * 100) / 10;
+		int ones = i % 10;
 		result.append(cjkDigit(hundreds));
 		result.append(cjkDigit(100));
-		if (tens!=0)
+		if (tens != 0)
 		{
 			result.append(cjkDigit(tens));
 			result.append(cjkDigit(10));
 		}
-		else if (ones!=0)
+		else if (ones != 0)
 			result.append(cjkDigit(0));
-		if (ones!=0)
+		if (ones != 0)
 			result.append(cjkDigit(ones));
 	}
 	return result;
